import re

# Right now, keeping this file as is. Might help during future extensions and testing.
_RE_COMBINE_WHITESPACE = re.compile(r"\s+")

WIKILINK = {
    "name": "wikilink",
    "tag": "a",
    "attribute": {"rel": "mw:WikiLink"},
    "type": {"1": "standard", "2": "redlink", "3": "transcluded", "4": "interwiki"},
}

CATEGORY = {
    "name": "category",
    "tag": "link",
    "attribute": {"rel": "mw:PageProp/Category"},
    "type": {"1": "standard", "2": "transcluded"},
}

# static dump based on utils.get_namespaces()
NAMESPACES = {
    "ab": {
        "Амедиа": -2,
        "Цастәи": -1,
        "Ахцәажәара": 1,
        "Алахәыла": 2,
        "Алахәыла ахцәажәара": 3,
        "Авикипедиа": 4,
        "Авикипедиа ахцәажәара": 5,
        "Афаил": 6,
        "Афаил ахцәажәара": 7,
        "Амедиавики": 8,
        "Амедиавики ахцәажәара": 9,
        "Ашаблон": 10,
        "Ашаблон ахцәажәара": 11,
        "Ацхыраара": 12,
        "Ацхыраара ахцәажәара": 13,
        "Акатегориа": 14,
        "Акатегориа ахцәажәара": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Амодуль": 828,
        "Амодуль ахцәажәара": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "ace": {
        "Alat": -2,
        "Kusuih": -1,
        "Marit": 1,
        "Ureuëng Ngui": 2,
        "Marit Ureuëng Ngui": 3,
        "Wikipedia": 4,
        "Marit Wikipedia": 5,
        "Beureukaih": 6,
        "Marit Beureukaih": 7,
        "MediaWiki": 8,
        "Marit MediaWiki": 9,
        "Seunaleuëk": 10,
        "Marit Seunaleuëk": 11,
        "Beunantu": 12,
        "Marit Beunantu": 13,
        "Kawan": 14,
        "Marit Kawan": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pembicaraan Modul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ady": {
        "Медиа": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Википедие": 4,
        "Википедием и тегущыӀэн": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "af": {
        "Media": -2,
        "Spesiaal": -1,
        "Bespreking": 1,
        "Gebruiker": 2,
        "Gebruikerbespreking": 3,
        "Wikipedia": 4,
        "Wikipediabespreking": 5,
        "Lêer": 6,
        "Lêerbespreking": 7,
        "MediaWiki": 8,
        "MediaWikibespreking": 9,
        "Sjabloon": 10,
        "Sjabloonbespreking": 11,
        "Hulp": 12,
        "Hulpbespreking": 13,
        "Kategorie": 14,
        "Kategoriebespreking": 15,
        "Portaal": 100,
        "Portaalbespreking": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ak": {
        "Media": -2,
        "Soronko": -1,
        "Nkɔmmɔ": 1,
        "Odwumanyɛni": 2,
        "Odwumanyɛni nkɔmmɔbea": 3,
        "Wikipedia": 4,
        "Wikipedia nkɔmmɔ": 5,
        "File": 6,
        "File nkɔmmɔ": 7,
        "MediaWiki": 8,
        "MediaWiki nkɔmmɔ": 9,
        "Nhwɛsode": 10,
        "Nhwɛsode nkɔmmɔbea": 11,
        "Boa": 12,
        "Mmoa nkɔmmɔbea": 13,
        "Nkyekyem": 14,
        "Nkyekyem nkɔmmɔbea": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "als": {
        "Medium": -2,
        "Spezial": -1,
        "Diskussion": 1,
        "Benutzer": 2,
        "Benutzer Diskussion": 3,
        "Wikipedia": 4,
        "Wikipedia Diskussion": 5,
        "Datei": 6,
        "Datei Diskussion": 7,
        "MediaWiki": 8,
        "MediaWiki Diskussion": 9,
        "Vorlage": 10,
        "Vorlage Diskussion": 11,
        "Hilfe": 12,
        "Hilfe Diskussion": 13,
        "Kategorie": 14,
        "Kategorie Diskussion": 15,
        "Portal": 100,
        "Portal Diskussion": 101,
        "Buech": 102,
        "Buech Diskussion": 103,
        "Wort": 104,
        "Wort Diskussion": 105,
        "Text": 106,
        "Text Diskussion": 107,
        "Spruch": 108,
        "Spruch Diskussion": 109,
        "Nochricht": 110,
        "Nochricht Diskussion": 111,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussion": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "alt": {
        "Медиа": -2,
        "Аҥылу": -1,
        "Шӱӱжӱ": 1,
        "Туружаачы": 2,
        "Туружаачыны шӱӱжери": 3,
        "Википедия": 4,
        "Википедияти шӱӱжери": 5,
        "Файл": 6,
        "Файлды шӱӱжери": 7,
        "MediaWiki": 8,
        "MediaWiki-ни шӱӱжери": 9,
        "Ӱлекер": 10,
        "Ӱлекерди шӱӱжери": 11,
        "Болуш": 12,
        "Болушты шӱӱжери": 13,
        "Категория": 14,
        "Категорияны шӱӱжери": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Модульды шӱӱжери": 829,
        "Гаджет": 2300,
        "Гаджетти шӱӱжери": 2301,
        "Гаджетти аайлары": 2302,
        "Гаджеттиҥ аайларын шӱӱжери": 2303,
    },
    "am": {
        "ፋይል": -2,
        "ልዩ": -1,
        "ውይይት": 1,
        "አባል": 2,
        "አባል ውይይት": 3,
        "ውክፔዲያ": 4,
        "ውክፔዲያ ውይይት": 5,
        "ስዕል": 6,
        "ስዕል ውይይት": 7,
        "መልዕክት": 8,
        "መልዕክት ውይይት": 9,
        "መለጠፊያ": 10,
        "መለጠፊያ ውይይት": 11,
        "እርዳታ": 12,
        "እርዳታ ውይይት": 13,
        "መደብ": 14,
        "መደብ ውይይት": 15,
        "በር": 100,
        "በር ውይይት": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ami": {
        "Mitiya": -2,
        "Kasi’iked": -1,
        "Kasasowal": 1,
        "Midemakay": 2,
        "Kasasowal no midemakay": 3,
        "Wikipedia": 4,
        "Wikipedia a kasasowal": 5,
        "Faylo": 6,
        "Masasowal to faylo": 7,
        "MediaWiki": 8,
        "Masasowal to MediaWiki": 9,
        "Masalipa": 10,
        "Masalipaay a kasasowal": 11,
        "Nipadama’": 12,
        "Mipadama’ a masasowal": 13,
        "Kasasiwasiw": 14,
        "Masasowal to kasasiwasiw": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "an": {
        "Media": -2,
        "Especial": -1,
        "Descusión": 1,
        "Usuario": 2,
        "Descusión usuario": 3,
        "Wikipedia": 4,
        "Descusión Wikipedia": 5,
        "Imachen": 6,
        "Descusión imachen": 7,
        "MediaWiki": 8,
        "Descusión MediaWiki": 9,
        "Plantilla": 10,
        "Descusión plantilla": 11,
        "Aduya": 12,
        "Descusión aduya": 13,
        "Categoría": 14,
        "Descusión categoría": 15,
        "Portal": 100,
        "Descusión Portal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Descusión módulo": 829,
        "Accesorio": 2300,
        "Descusión accesorio": 2301,
        "Accesorio definición": 2302,
        "Descusión definición accesorio": 2303,
    },
    "ang": {
        "Media": -2,
        "Syndrig": -1,
        "Mōtung": 1,
        "Brūcend": 2,
        "Brūcendmōtung": 3,
        "Wikipǣdia": 4,
        "Wikipǣdiamōtung": 5,
        "Ymele": 6,
        "Ymelmōtung": 7,
        "MediaWiki": 8,
        "MediaWikimōtung": 9,
        "Bysen": 10,
        "Bysenmōtung": 11,
        "Help": 12,
        "Helpmōtung": 13,
        "Flocc": 14,
        "Floccmōtung": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ar": {
        "ميديا": -2,
        "خاص": -1,
        "نقاش": 1,
        "مستخدم": 2,
        "نقاش المستخدم": 3,
        "ويكيبيديا": 4,
        "نقاش ويكيبيديا": 5,
        "ملف": 6,
        "نقاش الملف": 7,
        "ميدياويكي": 8,
        "نقاش ميدياويكي": 9,
        "قالب": 10,
        "نقاش القالب": 11,
        "مساعدة": 12,
        "نقاش المساعدة": 13,
        "تصنيف": 14,
        "نقاش التصنيف": 15,
        "بوابة": 100,
        "نقاش البوابة": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "وحدة": 828,
        "نقاش الوحدة": 829,
        "إضافة": 2300,
        "نقاش الإضافة": 2301,
        "تعريف الإضافة": 2302,
        "نقاش تعريف الإضافة": 2303,
        "موضوع": 2600,
    },
    "arc": {
        "ܡܝܕܝܐ": -2,
        "ܕܝܠܢܝܐ": -1,
        "ܡܡܠܠܐ": 1,
        "ܡܦܠܚܢܐ": 2,
        "ܡܡܠܠܐ ܕܡܦܠܚܢܐ": 3,
        "ܘܝܩܝܦܕܝܐ": 4,
        "ܡܡܠܠܐ ܕܘܝܩܝܦܕܝܐ": 5,
        "ܠܦܦܐ": 6,
        "ܡܡܠܠܐ ܕܠܦܦܐ": 7,
        "ܡܝܕܝܐܘܝܩܝ": 8,
        "ܡܡܠܠܐ ܕܡܝܕܝܐܘܝܩܝ": 9,
        "ܩܠܒܐ": 10,
        "ܡܡܠܠܐ ܕܩܠܒܐ": 11,
        "ܥܘܕܪܢܐ": 12,
        "ܡܡܠܠܐ ܕܥܘܕܪܢܐ": 13,
        "ܣܕܪܐ": 14,
        "ܡܡܠܠܐ ܕܣܕܪܐ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ary": {
        "ميديا": -2,
        "خاص": -1,
        "نقاش": 1,
        "مستخدم": 2,
        "نقاش المستخدم": 3,
        "ويكيپيديا": 4,
        "نقاش ويكيپيديا": 5,
        "ملف": 6,
        "نقاش الملف": 7,
        "ميدياويكي": 8,
        "نقاش ميدياويكي": 9,
        "قالب": 10,
        "نقاش القالب": 11,
        "مساعدة": 12,
        "نقاش المساعدة": 13,
        "تصنيف": 14,
        "نقاش التصنيف": 15,
        "قيسارية": 100,
        "لمداكرة د لقيسارية": 101,
        "واساخ": 118,
        "لمداكرة د لواساخ": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "وحدة": 828,
        "نقاش الوحدة": 829,
        "إضافة": 2300,
        "نقاش الإضافة": 2301,
        "تعريف الإضافة": 2302,
        "نقاش تعريف الإضافة": 2303,
    },
    "arz": {
        "ميديا": -2,
        "خاص": -1,
        "نقاش": 1,
        "مستخدم": 2,
        "نقاش المستخدم": 3,
        "ويكيبيديا": 4,
        "نقاش ويكيبيديا": 5,
        "ملف": 6,
        "نقاش الملف": 7,
        "ميدياويكى": 8,
        "نقاش ميدياويكى": 9,
        "قالب": 10,
        "نقاش القالب": 11,
        "مساعدة": 12,
        "نقاش المساعدة": 13,
        "تصنيف": 14,
        "نقاش التصنيف": 15,
        "بوابة": 100,
        "مناقشة بوابة": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "وحدة": 828,
        "نقاش الوحدة": 829,
        "إضافة": 2300,
        "نقاش الإضافة": 2301,
        "تعريف الإضافة": 2302,
        "نقاش تعريف الإضافة": 2303,
    },
    "as": {
        "মাধ্যম": -2,
        "বিশেষ": -1,
        "বাৰ্তা": 1,
        "সদস্য": 2,
        "সদস্য বাৰ্তা": 3,
        "ৱিকিপিডিয়া": 4,
        "ৱিকিপিডিয়া বাৰ্তা": 5,
        "চিত্ৰ": 6,
        "চিত্ৰ বাৰ্তা": 7,
        "মিডিয়াৱিকি": 8,
        "মিডিয়াৱিকি আলোচনা": 9,
        "সাঁচ": 10,
        "সাঁচ বাৰ্তা": 11,
        "সহায়": 12,
        "সহায় বাৰ্তা": 13,
        "শ্ৰেণী": 14,
        "শ্ৰেণী বাৰ্তা": 15,
        "ৱিকিচ'ৰা": 100,
        "ৱিকিচ'ৰা আলোচনা": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ast": {
        "Medios": -2,
        "Especial": -1,
        "Alderique": 1,
        "Usuariu": 2,
        "Usuariu alderique": 3,
        "Wikipedia": 4,
        "Wikipedia alderique": 5,
        "Ficheru": 6,
        "Ficheru alderique": 7,
        "MediaWiki": 8,
        "MediaWiki alderique": 9,
        "Plantía": 10,
        "Plantía alderique": 11,
        "Ayuda": 12,
        "Ayuda alderique": 13,
        "Categoría": 14,
        "Categoría alderique": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulu": 828,
        "Módulu alderique": 829,
        "Accesoriu": 2300,
        "Accesoriu alderique": 2301,
        "Accesoriu definición": 2302,
        "Accesoriu definición alderique": 2303,
    },
    "atj": {
        "Tipatcimoctakewin": -2,
        "Kotakahi": -1,
        "Ke ici aimihitonaniwok": 1,
        "Ka notcitatc": 2,
        "Ke ici aimihitonaniwok notcita iriniw": 3,
        "Wikipetcia": 4,
        "Ke ici aimihitonaniwok Wikipetcia": 5,
        "Natisinahikaniwoc": 6,
        "Ke ici aimihitonaniwok natisinihikaniwoc": 7,
        "MediaWiki": 8,
        "Ke ici aimihitonaniwok MediaWiki": 9,
        "Tipapitcikesinihikan": 10,
        "Ke ici arimotcikatek tipapitcikesinihikan": 11,
        "Witcihikoiin": 12,
        "Ke ici aimihitonaniwok witcihewinik": 13,
        "Tipanictawin": 14,
        "Ke ici aimihitonaniwok tipanictawin": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Aitapihikewin": 828,
        "Aitapihikan ke ici aimihitonaniwok": 829,
        "Gadget": 2300,
        "Ka ici aimihitonaniwok gadget": 2301,
        "Tipatcitcikan e icinakok gadget": 2302,
        "Ka ici aimihitonaniwok tipatcitcikan gadget otci": 2303,
    },
    "av": {
        "Медиа": -2,
        "Хъулухъалъулаб": -1,
        "БахӀс": 1,
        "ГӀахьалчи": 2,
        "ГӀахьалчиясул бахӀс": 3,
        "Википедия": 4,
        "Википедиялъул бахӀс": 5,
        "Файл": 6,
        "Файлалъул бахӀс": 7,
        "MediaWiki": 8,
        "MediaWiki-ялъул бахӀс": 9,
        "Халип": 10,
        "Халипалъул бахӀс": 11,
        "Кумек": 12,
        "Кумекалъул бахӀс": 13,
        "Категория": 14,
        "Категориялъул бахӀс": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Гаджеталъул бахӀс": 2301,
        "Гаджеталъул баян чӀезаби": 2302,
        "Гаджеталъул баян чӀезабиялъул бахӀс": 2303,
    },
    "avk": {
        "Kanaca": -2,
        "Aptaca": -1,
        "Prilara": 1,
        "Favesik": 2,
        "Favesikprilara": 3,
        "Wikipedia": 4,
        "Wikipedia prilara": 5,
        "Iyeltak": 6,
        "Iyeltakprilara": 7,
        "MediaWiki": 8,
        "MediaWiki prilara": 9,
        "Teza": 10,
        "Tezaprilara": 11,
        "Pomara": 12,
        "Pomaraprilara": 13,
        "Loma": 14,
        "Lomaprilara": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Siba": 828,
        "Sibaprilara": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "awa": {
        "मीडिया": -2,
        "खास": -1,
        "बातचीत": 1,
        "यूजर": 2,
        "यूजर बातचीत": 3,
        "विकिपीडिया": 4,
        "विकिपीडिया बातचीत": 5,
        "फाइल": 6,
        "फाइल बातचीत": 7,
        "मीडियाविकी": 8,
        "मीडियाविकी बातचीत": 9,
        "खाँचा": 10,
        "खाँचा बातचीत": 11,
        "मदद": 12,
        "मदद बातचीत": 13,
        "श्रेणी": 14,
        "श्रेणी बातचीत": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "गैजेट": 2300,
        "गैजेट वार्ता": 2301,
        "गैजेट परिभाषा": 2302,
        "गैजेट परिभाषा वार्ता": 2303,
    },
    "ay": {
        "Medio": -2,
        "Especial": -1,
        "Discusión": 1,
        "Usuario": 2,
        "Usuario discusión": 3,
        "Wikipidiya": 4,
        "Wikipidiyan Aruskipäwi": 5,
        "Archivo": 6,
        "Archivo discusión": 7,
        "MediaWiki": 8,
        "MediaWiki discusión": 9,
        "Plantilla": 10,
        "Plantilla discusión": 11,
        "Ayuda": 12,
        "Ayuda discusión": 13,
        "Categoría": 14,
        "Categoría discusión": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo discusión": 829,
        "Accesorio": 2300,
        "Accesorio discusión": 2301,
        "Accesorio definición": 2302,
        "Accesorio definición discusión": 2303,
    },
    "az": {
        "Media": -2,
        "Xüsusi": -1,
        "Müzakirə": 1,
        "İstifadəçi": 2,
        "İstifadəçi müzakirəsi": 3,
        "Vikipediya": 4,
        "Vikipediya müzakirəsi": 5,
        "Fayl": 6,
        "Fayl müzakirəsi": 7,
        "MediaViki": 8,
        "MediaViki müzakirəsi": 9,
        "Şablon": 10,
        "Şablon müzakirəsi": 11,
        "Kömək": 12,
        "Kömək müzakirəsi": 13,
        "Kateqoriya": 14,
        "Kateqoriya müzakirəsi": 15,
        "Portal": 100,
        "Portal müzakirəsi": 101,
        "Qaralama": 118,
        "Qaralama müzakirəsi": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul müzakirəsi": 829,
        "Qadcet": 2300,
        "Qadcet müzakirəsi": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "azb": {
        "مدیا": -2,
        "اؤزل": -1,
        "دانیشیق": 1,
        "ایشلدن": 2,
        "ایشلدن دانیشیغی": 3,
        "ویکی\u200cپدیا": 4,
        "ویکی\u200cپدیا دانیشیغی": 5,
        "فایل": 6,
        "فایل دانیشیغی": 7,
        "مدیاویکی": 8,
        "مدیاویکی دانیشیغی": 9,
        "شابلون": 10,
        "شابلون دانیشیغی": 11,
        "کؤمک": 12,
        "کؤمک دانیشیغی": 13,
        "بؤلمه": 14,
        "بؤلمه دانیشیغی": 15,
        "پوْرتال": 100,
        "پوْرتال دانیشیغی": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "ماژول": 828,
        "ماژول دانیشیغی": 829,
        "آلت": 2300,
        "آلت دانیشیغی": 2301,
        "آلت آچیقلاماسی": 2302,
        "آلت آچیقلاماسی دانیشیغی": 2303,
    },
    "ba": {
        "Медиа": -2,
        "Махсус": -1,
        "Фекерләшеү": 1,
        "Ҡатнашыусы": 2,
        "Ҡатнашыусы менән һөйләшеү": 3,
        "Википедия": 4,
        "Википедия буйынса фекерләшеү": 5,
        "Файл": 6,
        "Файл буйынса фекерләшеү": 7,
        "MediaWiki": 8,
        "MediaWiki буйынса фекерләшеү": 9,
        "Ҡалып": 10,
        "Ҡалып буйынса фекерләшеү": 11,
        "Белешмә": 12,
        "Белешмә буйынса фекерләшеү": 13,
        "Категория": 14,
        "Категория буйынса фекерләшеү": 15,
        "Портал": 100,
        "Портал буйынса фекерләшеү": 101,
        "Проект": 102,
        "Проект буйынса фекерләшеү": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Модуль буйынса фекерләшеү": 829,
        "Гаджет": 2300,
        "Гаджет буйынса фекерләшеү": 2301,
        "Гаджет билдәһе": 2302,
        "Гаджет билдәһе буйынса фекерләшеү": 2303,
    },
    "ban": {
        "Média": -2,
        "Kusus": -1,
        "Pabligbagan": 1,
        "Sang Anganggé": 2,
        "Pabligbagan Sang Anganggé": 3,
        "Wikipédia": 4,
        "Pabligbagan Wikipédia": 5,
        "Berkas": 6,
        "Pabligbagan Berkas": 7,
        "MédiaWiki": 8,
        "Pabligbagan MédiaWiki": 9,
        "Mal": 10,
        "Pabligbagan Mal": 11,
        "Wantuan": 12,
        "Pabligbagan Wantuan": 13,
        "Kategori": 14,
        "Pabligbagan Kategori": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pabligbagan Modul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bar": {
        "Media": -2,
        "Spezial": -1,
        "Dischkrian": 1,
        "Nutza": 2,
        "Nutza Dischkrian": 3,
        "Wikipedia": 4,
        "Wikipedia Dischkrian": 5,
        "Datei": 6,
        "Datei Dischkrian": 7,
        "MediaWiki": 8,
        "MediaWiki Dischkrian": 9,
        "Vorlog": 10,
        "Vorlog Dischkrian": 11,
        "Huif": 12,
        "Huif Dischkrian": 13,
        "Kategorie": 14,
        "Kategorie Dischkrian": 15,
        "Portal": 100,
        "Portal Dischkrian": 101,
        "Buach": 102,
        "Buach Dischkrian": 103,
        "Woat": 104,
        "Woat Dischkrian": 105,
        "Text": 106,
        "Text Dischkrian": 107,
        "Spruch": 108,
        "Spruch Dischkrian": 109,
        "Nochricht": 110,
        "Nochricht Dischkrian": 111,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussion": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "bat-smg": {
        "Medėjė": -2,
        "Specēlos": -1,
        "Aptarėms": 1,
        "Nauduotuos": 2,
        "Nauduotuojė aptarėms": 3,
        "Vikipedėjė": 4,
        "Vikipedėjės aptarėms": 5,
        "Abruozdielis": 6,
        "Abruozdielė aptarėms": 7,
        "MediaWiki": 8,
        "MediaWiki aptarėms": 9,
        "Šabluons": 10,
        "Šabluona aptarėms": 11,
        "Pagelba": 12,
        "Pagelbas aptarėms": 13,
        "Kateguorėjė": 14,
        "Kateguorėjės aptarėms": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bcl": {
        "Medio": -2,
        "Espesyal": -1,
        "Olay": 1,
        "Paragamit": 2,
        "Olay kan paragamit": 3,
        "Wikipedia": 4,
        "Olay sa Wikipedia": 5,
        "Ladawan": 6,
        "Olay sa ladawan": 7,
        "MediaWiki": 8,
        "Olay sa MediaWiki": 9,
        "Plantilya": 10,
        "Olay sa plantilya": 11,
        "Tabang": 12,
        "Olay sa tabang": 13,
        "Kategorya": 14,
        "Olay sa kategorya": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "be": {
        "Мультымедыя": -2,
        "Адмысловае": -1,
        "Размовы": 1,
        "Удзельнік": 2,
        "Размовы з удзельнікам": 3,
        "Вікіпедыя": 4,
        "Размовы пра Вікіпедыю": 5,
        "Файл": 6,
        "Размовы пра файл": 7,
        "MediaWiki": 8,
        "Размовы пра MediaWiki": 9,
        "Шаблон": 10,
        "Размовы пра шаблон": 11,
        "Даведка": 12,
        "Размовы пра даведку": 13,
        "Катэгорыя": 14,
        "Размовы пра катэгорыю": 15,
        "Партал": 100,
        "Размовы пра партал": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Размовы пра модуль": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "be-tarask": {
        "Мэдыя": -2,
        "Спэцыяльныя": -1,
        "Абмеркаваньне": 1,
        "Удзельнік": 2,
        "Гутаркі ўдзельніка": 3,
        "Вікіпэдыя": 4,
        "Абмеркаваньне Вікіпэдыі": 5,
        "Файл": 6,
        "Абмеркаваньне файла": 7,
        "MediaWiki": 8,
        "Абмеркаваньне MediaWiki": 9,
        "Шаблён": 10,
        "Абмеркаваньне шаблёну": 11,
        "Дапамога": 12,
        "Абмеркаваньне дапамогі": 13,
        "Катэгорыя": 14,
        "Абмеркаваньне катэгорыі": 15,
        "Партал": 100,
        "Абмеркаваньне парталу": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Абмеркаваньне модулю": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bg": {
        "Медия": -2,
        "Специални": -1,
        "Беседа": 1,
        "Потребител": 2,
        "Потребител беседа": 3,
        "Уикипедия": 4,
        "Уикипедия беседа": 5,
        "Файл": 6,
        "Файл беседа": 7,
        "МедияУики": 8,
        "МедияУики беседа": 9,
        "Шаблон": 10,
        "Шаблон беседа": 11,
        "Помощ": 12,
        "Помощ беседа": 13,
        "Категория": 14,
        "Категория беседа": 15,
        "Портал": 100,
        "Портал беседа": 101,
        "Чернова": 118,
        "Чернова беседа": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модул": 828,
        "Модул беседа": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bh": {
        "मीडिया": -2,
        "विशेष": -1,
        "वार्तालाप": 1,
        "प्रयोगकर्ता": 2,
        "प्रयोगकर्ता वार्ता": 3,
        "विकिपीडिया": 4,
        "विकिपीडिया वार्ता": 5,
        "चित्र": 6,
        "चित्र वार्ता": 7,
        "मीडियाविकि": 8,
        "मीडियाविकि वार्ता": 9,
        "टेम्पलेट": 10,
        "टेम्पलेट वार्ता": 11,
        "मदद": 12,
        "मदद वार्ता": 13,
        "श्रेणी": 14,
        "श्रेणी वार्ता": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bi": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bjn": {
        "Media": -2,
        "Istimiwa": -1,
        "Pamandiran": 1,
        "Pamakai": 2,
        "Pamandiran Pamakai": 3,
        "Wikipidia": 4,
        "Pamandiran Wikipidia": 5,
        "Barakas": 6,
        "Pamandiran Barakas": 7,
        "MediaWiki": 8,
        "Pamandiran MediaWiki": 9,
        "Citakan": 10,
        "Pamandiran Citakan": 11,
        "Patulung": 12,
        "Pamandiran Patulung": 13,
        "Tumbung": 14,
        "Pamandiran Tumbung": 15,
        "Lawang": 100,
        "Pamandiran Lawang": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pembicaraan Modul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bm": {
        "Média": -2,
        "Spécial": -1,
        "Discussion": 1,
        "Utilisateur": 2,
        "Discussion utilisateur": 3,
        "Wikipedia": 4,
        "Discussion Wikipedia": 5,
        "Fichier": 6,
        "Discussion fichier": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèle": 10,
        "Discussion modèle": 11,
        "Aide": 12,
        "Discussion aide": 13,
        "Catégorie": 14,
        "Discussion catégorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "bn": {
        "মিডিয়া": -2,
        "বিশেষ": -1,
        "আলাপ": 1,
        "ব্যবহারকারী": 2,
        "ব্যবহারকারী আলাপ": 3,
        "উইকিপিডিয়া": 4,
        "উইকিপিডিয়া আলোচনা": 5,
        "চিত্র": 6,
        "চিত্র আলোচনা": 7,
        "মিডিয়াউইকি": 8,
        "মিডিয়াউইকি আলোচনা": 9,
        "টেমপ্লেট": 10,
        "টেমপ্লেট আলোচনা": 11,
        "সাহায্য": 12,
        "সাহায্য আলোচনা": 13,
        "বিষয়শ্রেণী": 14,
        "বিষয়শ্রেণী আলোচনা": 15,
        "প্রবেশদ্বার": 100,
        "প্রবেশদ্বার আলোচনা": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "মডিউল": 828,
        "মডিউল আলাপ": 829,
        "গ্যাজেট": 2300,
        "গ্যাজেট আলোচনা": 2301,
        "গ্যাজেট সংজ্ঞা": 2302,
        "গ্যাজেট সংজ্ঞার আলোচনা": 2303,
    },
    "bo": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bpy": {
        "মিডিয়া": -2,
        "বিশেষ": -1,
        "য়্যারী": 1,
        "আতাকুরা": 2,
        "আতাকুরার য়্যারী": 3,
        "উইকিপিডিয়া": 4,
        "উইকিপিডিয়া য়্যারী": 5,
        "ছবি": 6,
        "ছবি য়্যারী": 7,
        "মিডিয়াউইকি": 8,
        "মিডিয়াউইকির য়্যারী": 9,
        "মডেল": 10,
        "মডেলর য়্যারী": 11,
        "পাংলাক": 12,
        "পাংলাকর য়্যারী": 13,
        "থাক": 14,
        "থাকর য়্যারী": 15,
        "হমিলদুৱার": 100,
        "হমিলদুৱার য়্যারী": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "মডিউল": 828,
        "মডিউল আলাপ": 829,
        "গ্যাজেট": 2300,
        "গ্যাজেট আলোচনা": 2301,
        "গ্যাজেট সংজ্ঞা": 2302,
        "গ্যাজেট সংজ্ঞার আলোচনা": 2303,
    },
    "br": {
        "Media": -2,
        "Dibar": -1,
        "Kaozeal": 1,
        "Implijer": 2,
        "Kaozeadenn Implijer": 3,
        "Wikipedia": 4,
        "Kaozeadenn Wikipedia": 5,
        "Restr": 6,
        "Kaozeadenn Restr": 7,
        "MediaWiki": 8,
        "Kaozeadenn MediaWiki": 9,
        "Patrom": 10,
        "Kaozeadenn Patrom": 11,
        "Skoazell": 12,
        "Kaozeadenn Skoazell": 13,
        "Rummad": 14,
        "Kaozeadenn Rummad": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulenn": 828,
        "Kaozeadenn modulenn": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bs": {
        "Mediji": -2,
        "Posebno": -1,
        "Razgovor": 1,
        "Korisnik": 2,
        "Razgovor s korisnikom": 3,
        "Wikipedia": 4,
        "Razgovor o Wikipediji": 5,
        "Datoteka": 6,
        "Razgovor o datoteci": 7,
        "MediaWiki": 8,
        "Razgovor o MediaWikiju": 9,
        "Šablon": 10,
        "Razgovor o šablonu": 11,
        "Pomoć": 12,
        "Razgovor o pomoći": 13,
        "Kategorija": 14,
        "Razgovor o kategoriji": 15,
        "Portal": 100,
        "Razgovor o portalu": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Razgovor o modulu": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Topic": 2600,
    },
    "bug": {
        "Media": -2,
        "Istimewa": -1,
        "Pembicaraan": 1,
        "Pengguna": 2,
        "Pembicaraan Pengguna": 3,
        "Wikipedia": 4,
        "Pembicaraan Wikipedia": 5,
        "Berkas": 6,
        "Pembicaraan Berkas": 7,
        "MediaWiki": 8,
        "Pembicaraan MediaWiki": 9,
        "Templat": 10,
        "Pembicaraan Templat": 11,
        "Bantuan": 12,
        "Pembicaraan Bantuan": 13,
        "Kategori": 14,
        "Pembicaraan Kategori": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pembicaraan Modul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "bxr": {
        "Меди": -2,
        "Тусхай": -1,
        "Хэлэлсэхэ": 1,
        "Хэрэглэгшэ": 2,
        "Хэрэглэгшые хэлэлсэхэ": 3,
        "Википеэди": 4,
        "Википеэди тухай хэлэлсэхэ": 5,
        "Файл": 6,
        "Файл хэлэлсэхэ": 7,
        "MediaWiki": 8,
        "MediaWiki хэлэлсэхэ": 9,
        "Загбар": 10,
        "Загбар хэлэлсэхэ": 11,
        "Туһаламжа": 12,
        "Туһаламжа хэлэлсэл": 13,
        "Категори": 14,
        "Категори хэлэлсэхэ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "ca": {
        "Media": -2,
        "Especial": -1,
        "Discussió": 1,
        "Usuari": 2,
        "Usuari Discussió": 3,
        "Viquipèdia": 4,
        "Viquipèdia Discussió": 5,
        "Fitxer": 6,
        "Fitxer Discussió": 7,
        "MediaWiki": 8,
        "MediaWiki Discussió": 9,
        "Plantilla": 10,
        "Plantilla Discussió": 11,
        "Ajuda": 12,
        "Ajuda Discussió": 13,
        "Categoria": 14,
        "Categoria Discussió": 15,
        "Portal": 100,
        "Portal Discussió": 101,
        "Viquiprojecte": 102,
        "Viquiprojecte Discussió": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Mòdul": 828,
        "Mòdul Discussió": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Tema": 2600,
    },
    "cbk-zam": {
        "Medio": -2,
        "Especial": -1,
        "Discusión": 1,
        "Usuario": 2,
        "Usuario discusión": 3,
        "Wikipedia": 4,
        "Wikipedia discusión": 5,
        "Archivo": 6,
        "Archivo discusión": 7,
        "MediaWiki": 8,
        "MediaWiki discusión": 9,
        "Plantilla": 10,
        "Plantilla discusión": 11,
        "Ayuda": 12,
        "Ayuda discusión": 13,
        "Categoría": 14,
        "Categoría discusión": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo discusión": 829,
        "Accesorio": 2300,
        "Accesorio discusión": 2301,
        "Accesorio definición": 2302,
        "Accesorio definición discusión": 2303,
    },
    "cdo": {
        "媒體": -2,
        "特殊": -1,
        "討論": 1,
        "用戶": 2,
        "用戶討論": 3,
        "Wikipedia": 4,
        "Wikipedia討論": 5,
        "文件": 6,
        "文件討論": 7,
        "MediaWiki": 8,
        "MediaWiki討論": 9,
        "模板": 10,
        "模板討論": 11,
        "幫助": 12,
        "幫助討論": 13,
        "分類": 14,
        "分類討論": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ce": {
        "Медиа": -2,
        "Белхан": -1,
        "Дийцаре": 1,
        "Декъашхо": 2,
        "Декъашхочун дийцаре": 3,
        "Википеди": 4,
        "Википедин дийцаре": 5,
        "Файл": 6,
        "Файлан дийцаре": 7,
        "MediaWiki": 8,
        "MediaWiki дийцаре": 9,
        "Кеп": 10,
        "Кепан дийцаре": 11,
        "ГӀо": 12,
        "ГӀо дийцаре": 13,
        "Категори": 14,
        "Категорин дийцаре": 15,
        "Ков": 100,
        "Ков дийцаре": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Модулин дийцаре": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "ceb": {
        "Medya": -2,
        "Espesyal": -1,
        "Hisgot": 1,
        "Gumagamit": 2,
        "Hisgot sa Gumagamit": 3,
        "Wikipedia": 4,
        "Hisgot sa Wikipedia": 5,
        "Payl": 6,
        "Hisgot sa Payl": 7,
        "MediaWiki": 8,
        "Hisgot sa MediaWiki": 9,
        "Plantilya": 10,
        "Hisgot sa Plantilya": 11,
        "Tabang": 12,
        "Hisgot sa Tabang": 13,
        "Kategoriya": 14,
        "Hisgot sa Kategoriya": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ch": {
        "Media": -2,
        "Espesiat": -1,
        "Kombetsasion": 1,
        "Muna'sesetbi": 2,
        "Kombetsasion ni muna'sesetbi": 3,
        "Wikipedia": 4,
        "Kombetsasion nu Wikipedia": 5,
        "Litratu": 6,
        "Kombetsasion ni litratu": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Ayudo": 12,
        "Kombetsasion ni ayudo": 13,
        "Katigoria": 14,
        "Kombetsasion ni katigoria": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "chr": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "chy": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ckb": {
        "میدیا": -2,
        "تایبەت": -1,
        "وتووێژ": 1,
        "بەکارھێنەر": 2,
        "لێدوانی بەکارھێنەر": 3,
        "ویکیپیدیا": 4,
        "لێدوانی ویکیپیدیا": 5,
        "پەڕگە": 6,
        "وتووێژی پەڕگە": 7,
        "میدیاویکی": 8,
        "وتووێژی میدیاویکی": 9,
        "داڕێژە": 10,
        "وتووێژی داڕێژە": 11,
        "یارمەتی": 12,
        "وتووێژی یارمەتی": 13,
        "پۆل": 14,
        "وتووێژی پۆل": 15,
        "دەروازە": 100,
        "لێدوانی دەروازە": 101,
        "ویکیپرۆژە": 102,
        "لێدوانی ویکیپرۆژە": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "مۆدیوول": 828,
        "لێدوانی مۆدیوول": 829,
        "ئامراز": 2300,
        "وتووێژی ئامراز": 2301,
        "پێناسه\u200cی ئامراز": 2302,
        "وتووێژی پێناسه\u200cی ئامراز": 2303,
    },
    "co": {
        "Media": -2,
        "Speciale": -1,
        "Discussione": 1,
        "Utente": 2,
        "Discussioni utente": 3,
        "Wikipedia": 4,
        "Discussioni Wikipedia": 5,
        "File": 6,
        "Discussioni file": 7,
        "MediaWiki": 8,
        "Discussioni MediaWiki": 9,
        "Template": 10,
        "Discussioni template": 11,
        "Aiuto": 12,
        "Discussioni aiuto": 13,
        "Categoria": 14,
        "Discussioni categoria": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Discussioni modulo": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "cr": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "crh": {
        "Media": -2,
        "Mahsus": -1,
        "Muzakere": 1,
        "Qullanıcı": 2,
        "Qullanıcı muzakeresi": 3,
        "Vikipediya": 4,
        "Vikipediya muzakeresi": 5,
        "Fayl": 6,
        "Fayl muzakeresi": 7,
        "MediaViki": 8,
        "MediaViki muzakeresi": 9,
        "Şablon": 10,
        "Şablon muzakeresi": 11,
        "Yardım": 12,
        "Yardım muzakeresi": 13,
        "Kategoriya": 14,
        "Kategoriya muzakeresi": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul muzakeresi": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "cs": {
        "Média": -2,
        "Speciální": -1,
        "Diskuse": 1,
        "Wikipedista": 2,
        "Diskuse s wikipedistou": 3,
        "Wikipedie": 4,
        "Diskuse k Wikipedii": 5,
        "Soubor": 6,
        "Diskuse k souboru": 7,
        "MediaWiki": 8,
        "Diskuse k MediaWiki": 9,
        "Šablona": 10,
        "Diskuse k šabloně": 11,
        "Nápověda": 12,
        "Diskuse k nápovědě": 13,
        "Kategorie": 14,
        "Diskuse ke kategorii": 15,
        "Portál": 100,
        "Diskuse k portálu": 101,
        "Rejstřík": 102,
        "Diskuse k rejstříku": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Diskuse k modulu": 829,
        "Udělátko": 2300,
        "Diskuse k udělátku": 2301,
        "Definice udělátka": 2302,
        "Diskuse k definici udělátka": 2303,
        "Téma": 2600,
    },
    "csb": {
        "Media": -2,
        "Specjalnô": -1,
        "Diskùsëjô": 1,
        "Brëkòwnik": 2,
        "Diskùsëjô brëkòwnika": 3,
        "Wiki": 4,
        "Diskùsëjô Wiki": 5,
        "Òbrôzk": 6,
        "Diskùsëjô òbrôzków": 7,
        "MediaWiki": 8,
        "Diskùsëjô MediaWiki": 9,
        "Szablóna": 10,
        "Diskùsëjô Szablónë": 11,
        "Pòmòc": 12,
        "Diskùsëjô Pòmòcë": 13,
        "Kategòrëjô": 14,
        "Diskùsëjô Kategòrëji": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Moduł": 828,
        "Dyskusja modułu": 829,
        "Gadżet": 2300,
        "Dyskusja gadżetu": 2301,
        "Definicja gadżetu": 2302,
        "Dyskusja definicji gadżetu": 2303,
    },
    "cu": {
        "Срѣдьства": -2,
        "Нарочьна": -1,
        "Бєсѣда": 1,
        "Польꙃєватєл҄ь": 2,
        "Польꙃєватєлꙗ бєсѣда": 3,
        "Википєдїꙗ": 4,
        "Википєдїѩ бєсѣда": 5,
        "Дѣло": 6,
        "Дѣла бєсѣда": 7,
        "MediaWiki": 8,
        "MediaWiki бєсѣда": 9,
        "Обраꙁьць": 10,
        "Обраꙁьца бєсѣда": 11,
        "Помощь": 12,
        "Помощи бєсѣда": 13,
        "Катигорїꙗ": 14,
        "Катигорїѩ бєсѣда": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "cv": {
        "Медиа": -2,
        "Ятарлă": -1,
        "Сӳтсе явасси": 1,
        "Хутшăнакан": 2,
        "Хутшăнаканăн канашлу страници": 3,
        "Википеди": 4,
        "Википеди сӳтсе явмалли": 5,
        "Ӳкерчĕк": 6,
        "Ӳкерчĕке сӳтсе явмалли": 7,
        "MediaWiki": 8,
        "MediaWiki сӳтсе явмалли": 9,
        "Шаблон": 10,
        "Шаблона сӳтсе явмалли": 11,
        "Пулăшу": 12,
        "Пулăшăва сӳтсе явмалли": 13,
        "Категори": 14,
        "Категорине сӳтсе явмалли": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "cy": {
        "Media": -2,
        "Arbennig": -1,
        "Sgwrs": 1,
        "Defnyddiwr": 2,
        "Sgwrs Defnyddiwr": 3,
        "Wicipedia": 4,
        "Sgwrs Wicipedia": 5,
        "Delwedd": 6,
        "Sgwrs Delwedd": 7,
        "MediaWici": 8,
        "Sgwrs MediaWici": 9,
        "Nodyn": 10,
        "Sgwrs Nodyn": 11,
        "Cymorth": 12,
        "Sgwrs Cymorth": 13,
        "Categori": 14,
        "Sgwrs Categori": 15,
        "Porth": 100,
        "Sgwrs Porth": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modiwl": 828,
        "Sgwrs modiwl": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "da": {
        "Media": -2,
        "Speciel": -1,
        "Diskussion": 1,
        "Bruger": 2,
        "Brugerdiskussion": 3,
        "Wikipedia": 4,
        "Wikipedia-diskussion": 5,
        "Fil": 6,
        "Fildiskussion": 7,
        "MediaWiki": 8,
        "MediaWiki-diskussion": 9,
        "Skabelon": 10,
        "Skabelondiskussion": 11,
        "Hjælp": 12,
        "Hjælp-diskussion": 13,
        "Kategori": 14,
        "Kategoridiskussion": 15,
        "Portal": 100,
        "Portaldiskussion": 101,
        "Artikeldata": 102,
        "Artikeldatadiskussion": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Moduldiskussion": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "dag": {
        "Miidiya": -2,
        "Diŋ'gahim": -1,
        "Yɛltɔɣa": 1,
        "Ŋun su": 2,
        "Ŋun su yɛltɔɣa": 3,
        "Wikipedia": 4,
        "Wikipedia yɛltɔɣa": 5,
        "Lahabali kɔligu": 6,
        "Lahabali kɔligu yɛltɔɣa": 7,
        "MiidiyaWiki": 8,
        "MiidiyaWiki yɛltɔɣa": 9,
        "Tɛmplet": 10,
        "Tɛmplet yɛltɔɣa": 11,
        "Sɔŋsim": 12,
        "Sɔŋsim yɛltɔɣa": 13,
        "Pubu": 14,
        "Pubu yɛltɔɣa": 15,
        "Salima": 104,
        "Salima yɛltɔɣa": 105,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "de": {
        "Medium": -2,
        "Spezial": -1,
        "Diskussion": 1,
        "Benutzer": 2,
        "Benutzer Diskussion": 3,
        "Wikipedia": 4,
        "Wikipedia Diskussion": 5,
        "Datei": 6,
        "Datei Diskussion": 7,
        "MediaWiki": 8,
        "MediaWiki Diskussion": 9,
        "Vorlage": 10,
        "Vorlage Diskussion": 11,
        "Hilfe": 12,
        "Hilfe Diskussion": 13,
        "Kategorie": 14,
        "Kategorie Diskussion": 15,
        "Portal": 100,
        "Portal Diskussion": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussion": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "din": {
        "Ciɛl": -2,
        "Këcëweek": -1,
        "Jam": 1,
        "Dulooi": 2,
        "Jam kekë dulooi": 3,
        "Wikipedia": 4,
        "Jam wɛ̈t ë Wikipedia": 5,
        "Apamduööt": 6,
        "Jam wɛ̈t ë apamduööt": 7,
        "MediaWiki": 8,
        "Jam wɛ̈t ë MediaWiki": 9,
        "Macuëc": 10,
        "Jam wɛ̈t ë macuëc": 11,
        "Kuɔny": 12,
        "Jam wɛ̈t ë kuɔny": 13,
        "Bekätakthook": 14,
        "Jam wɛ̈t ë bekätakthook": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Mukääcëtök": 828,
        "Jam wɛ̈t ë mukääcëtök": 829,
        "Muluuitet": 2300,
        "Jam wɛ̈t ë muluuitet": 2301,
        "Wɛ̈tdic ë muluuitet": 2302,
        "Jam wɛ̈t ë wɛ̈tdic ë muluuitet": 2303,
    },
    "diq": {
        "Medya": -2,
        "Bağse": -1,
        "Vaten": 1,
        "Karber": 2,
        "Karber vaten": 3,
        "Wikipedia": 4,
        "Wikipedia vaten": 5,
        "Dosya": 6,
        "Dosya vaten": 7,
        "MediaWiki": 8,
        "MediaWiki vaten": 9,
        "Şablon": 10,
        "Şablon vaten": 11,
        "Desteg": 12,
        "Desteg vaten": 13,
        "Kategori": 14,
        "Kategori vaten": 15,
        "Portal": 100,
        "Portal vaten": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul vaten": 829,
        "Halet": 2300,
        "Halet vaten": 2301,
        "Halet şınasnayış": 2302,
        "Halet şınasnayış vaten": 2303,
    },
    "dsb": {
        "Medija": -2,
        "Specialne": -1,
        "Diskusija": 1,
        "Wužywaŕ": 2,
        "Diskusija wužywarja": 3,
        "Wikipedija": 4,
        "Wikipedija diskusija": 5,
        "Dataja": 6,
        "Diskusija wó dataji": 7,
        "MediaWiki": 8,
        "MediaWiki diskusija": 9,
        "Pśedłoga": 10,
        "Diskusija wó pśedłoze": 11,
        "Pomoc": 12,
        "Diskusija wó pomocy": 13,
        "Kategorija": 14,
        "Diskusija wó kategoriji": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul diskusija": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "dty": {
        "मिडिया": -2,
        "बिशेष": -1,
        "कुरणि": 1,
        "प्रयोगकर्ता": 2,
        "प्रयोगकर्ता कुरणि": 3,
        "विकिपिडिया": 4,
        "विकिपिडिया वार्ता": 5,
        "चित्र": 6,
        "चित्र कुरणि": 7,
        "मिडियाविकि": 8,
        "मिडियाविकि कुरणि": 9,
        "ढाँचा": 10,
        "ढाँचा कुरणि": 11,
        "मद्दत": 12,
        "मद्दत कुरणि": 13,
        "श्रेणी": 14,
        "श्रेणी कुरणि": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "मोड्युल": 828,
        "मोड्युल कुरणि": 829,
        "ग्याजेट": 2300,
        "ग्याजेट कुरणि": 2301,
        "ग्याजेट परिभाषा": 2302,
        "ग्याजेट परिभाषा कुरणि": 2303,
    },
    "dv": {
        "މީޑިއާ": -2,
        "ޚާއްސަ": -1,
        "ޚިޔާލު": 1,
        "މެމްބަރު": 2,
        "މެމްބަރުގެ ވާހަކަ": 3,
        "ވިކިޕީޑިއާ": 4,
        "ވިކިޕީޑިއާ ޚިޔާލު": 5,
        "ފައިލު": 6,
        "ފައިލުގެ ޚިޔާލު": 7,
        "މީޑިއާވިކީ": 8,
        "މިޑިއާވިކީ ޚިޔާލު": 9,
        "ފަންވަތް": 10,
        "ފަންވަތުގެ ޚިޔާލު": 11,
        "އެހީ": 12,
        "އެހީގެ ޚިޔާލު": 13,
        "ޤިސްމު": 14,
        "ޤިސްމުގެ ޚިޔާލު": 15,
        "ނެރު": 100,
        "ނެރު ޚިޔާލު": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "މޮޑިއުލް": 828,
        "މޮޑިއުލް ޚިޔާލު": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "dz": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ee": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "el": {
        "Μέσο": -2,
        "Ειδικό": -1,
        "Συζήτηση": 1,
        "Χρήστης": 2,
        "Συζήτηση χρήστη": 3,
        "Βικιπαίδεια": 4,
        "Συζήτηση Βικιπαίδεια": 5,
        "Αρχείο": 6,
        "Συζήτηση αρχείου": 7,
        "MediaWiki": 8,
        "Συζήτηση MediaWiki": 9,
        "Πρότυπο": 10,
        "Συζήτηση προτύπου": 11,
        "Βοήθεια": 12,
        "Συζήτηση βοήθειας": 13,
        "Κατηγορία": 14,
        "Συζήτηση κατηγορίας": 15,
        "Πύλη": 100,
        "Συζήτηση πύλης": 101,
        "Education Program": 446,
        "Education Program talk": 447,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Topic": 2600,
    },
    "eml": {
        "Media": -2,
        "Speciale": -1,
        "Discussione": 1,
        "Utente": 2,
        "Discussioni utente": 3,
        "Wikipedia": 4,
        "Discussioni Wikipedia": 5,
        "File": 6,
        "Discussioni file": 7,
        "MediaWiki": 8,
        "Discussioni MediaWiki": 9,
        "Template": 10,
        "Discussioni template": 11,
        "Aiuto": 12,
        "Discussioni aiuto": 13,
        "Categoria": 14,
        "Discussioni categoria": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Mòdul": 828,
        "Discusiòun dal Mòdul": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "en": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "Portal": 100,
        "Portal talk": 101,
        "Draft": 118,
        "Draft talk": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "eo": {
        "Aŭdvidaĵo": -2,
        "Specialaĵo": -1,
        "Diskuto": 1,
        "Uzanto": 2,
        "Uzanto-Diskuto": 3,
        "Vikipedio": 4,
        "Vikipedia diskuto": 5,
        "Dosiero": 6,
        "Dosiero-Diskuto": 7,
        "MediaWiki": 8,
        "MediaWiki-Diskuto": 9,
        "Ŝablono": 10,
        "Ŝablono-Diskuto": 11,
        "Helpo": 12,
        "Helpo-Diskuto": 13,
        "Kategorio": 14,
        "Kategorio-Diskuto": 15,
        "Portalo": 100,
        "Portala diskuto": 101,
        "Projekto": 102,
        "Projekta diskuto": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Modulo-Diskuto": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Topic": 2600,
    },
    "es": {
        "Medio": -2,
        "Especial": -1,
        "Discusión": 1,
        "Usuario": 2,
        "Usuario discusión": 3,
        "Wikipedia": 4,
        "Wikipedia discusión": 5,
        "Archivo": 6,
        "Archivo discusión": 7,
        "MediaWiki": 8,
        "MediaWiki discusión": 9,
        "Plantilla": 10,
        "Plantilla discusión": 11,
        "Ayuda": 12,
        "Ayuda discusión": 13,
        "Categoría": 14,
        "Categoría discusión": 15,
        "Portal": 100,
        "Portal discusión": 101,
        "Wikiproyecto": 102,
        "Wikiproyecto discusión": 103,
        "Anexo": 104,
        "Anexo discusión": 105,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo discusión": 829,
        "Accesorio": 2300,
        "Accesorio discusión": 2301,
        "Accesorio definición": 2302,
        "Accesorio definición discusión": 2303,
    },
    "et": {
        "Meedia": -2,
        "Eri": -1,
        "Arutelu": 1,
        "Kasutaja": 2,
        "Kasutaja arutelu": 3,
        "Vikipeedia": 4,
        "Vikipeedia arutelu": 5,
        "Fail": 6,
        "Faili arutelu": 7,
        "MediaWiki": 8,
        "MediaWiki arutelu": 9,
        "Mall": 10,
        "Malli arutelu": 11,
        "Juhend": 12,
        "Juhendi arutelu": 13,
        "Kategooria": 14,
        "Kategooria arutelu": 15,
        "Portaal": 100,
        "Portaali arutelu": 101,
        "Mustand": 102,
        "Mustandi arutelu": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Moodul": 828,
        "Mooduli arutelu": 829,
        "Tööriist": 2300,
        "Tööriista arutelu": 2301,
        "Tööriista määratlus": 2302,
        "Tööriista määratluse arutelu": 2303,
    },
    "eu": {
        "Media": -2,
        "Berezi": -1,
        "Eztabaida": 1,
        "Lankide": 2,
        "Lankide eztabaida": 3,
        "Wikipedia": 4,
        "Wikipedia eztabaida": 5,
        "Fitxategi": 6,
        "Fitxategi eztabaida": 7,
        "MediaWiki": 8,
        "MediaWiki eztabaida": 9,
        "Txantiloi": 10,
        "Txantiloi eztabaida": 11,
        "Laguntza": 12,
        "Laguntza eztabaida": 13,
        "Kategoria": 14,
        "Kategoria eztabaida": 15,
        "Atari": 100,
        "Atari eztabaida": 101,
        "Wikiproiektu": 102,
        "Wikiproiektu eztabaida": 103,
        "Txikipedia": 104,
        "Txikipedia eztabaida": 105,
        "Zerrenda": 106,
        "Zerrenda eztabaida": 107,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulu": 828,
        "Modulu eztabaida": 829,
        "Gadget": 2300,
        "Gadget eztabaida": 2301,
        "Gadget definizio": 2302,
        "Gadget definizio eztabaida": 2303,
        "Topic": 2600,
    },
    "ext": {
        "Mediu": -2,
        "Especial": -1,
        "Caraba": 1,
        "Usuario": 2,
        "Usuario caraba": 3,
        "Güiquipeya": 4,
        "Güiquipeya caraba": 5,
        "Archivu": 6,
        "Archivu caraba": 7,
        "MediaWiki": 8,
        "MediaWiki caraba": 9,
        "Prantilla": 10,
        "Prantilla caraba": 11,
        "Ayua": 12,
        "Ayua caraba": 13,
        "Categoría": 14,
        "Categoría caraba": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo discusión": 829,
        "Accesorio": 2300,
        "Accesorio discusión": 2301,
        "Accesorio definición": 2302,
        "Accesorio definición discusión": 2303,
    },
    "fa": {
        "مدیا": -2,
        "ویژه": -1,
        "بحث": 1,
        "کاربر": 2,
        "بحث کاربر": 3,
        "ویکی\u200cپدیا": 4,
        "بحث ویکی\u200cپدیا": 5,
        "پرونده": 6,
        "بحث پرونده": 7,
        "مدیاویکی": 8,
        "بحث مدیاویکی": 9,
        "الگو": 10,
        "بحث الگو": 11,
        "راهنما": 12,
        "بحث راهنما": 13,
        "رده": 14,
        "بحث رده": 15,
        "درگاه": 100,
        "بحث درگاه": 101,
        "پیش\u200cنویس": 118,
        "بحث پیش\u200cنویس": 119,
        "Education Program": 446,
        "Education Program talk": 447,
        "TimedText": 710,
        "TimedText talk": 711,
        "پودمان": 828,
        "بحث پودمان": 829,
        "ابزار": 2300,
        "بحث ابزار": 2301,
        "توضیحات ابزار": 2302,
        "بحث توضیحات ابزار": 2303,
        "مبحث": 2600,
    },
    "ff": {
        "Média": -2,
        "Spécial": -1,
        "Discussion": 1,
        "Utilisateur": 2,
        "Discussion utilisateur": 3,
        "Wikipedia": 4,
        "Discussion Wikipedia": 5,
        "Fichier": 6,
        "Discussion fichier": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèle": 10,
        "Discussion modèle": 11,
        "Aide": 12,
        "Discussion aide": 13,
        "Catégorie": 14,
        "Discussion catégorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "fi": {
        "Media": -2,
        "Toiminnot": -1,
        "Keskustelu": 1,
        "Käyttäjä": 2,
        "Keskustelu käyttäjästä": 3,
        "Wikipedia": 4,
        "Keskustelu Wikipediasta": 5,
        "Tiedosto": 6,
        "Keskustelu tiedostosta": 7,
        "Järjestelmäviesti": 8,
        "Keskustelu järjestelmäviestistä": 9,
        "Malline": 10,
        "Keskustelu mallineesta": 11,
        "Ohje": 12,
        "Keskustelu ohjeesta": 13,
        "Luokka": 14,
        "Keskustelu luokasta": 15,
        "Teemasivu": 100,
        "Keskustelu teemasivusta": 101,
        "Metasivu": 102,
        "Keskustelu metasivusta": 103,
        "Kirja": 104,
        "Keskustelu kirjasta": 105,
        "Wikiprojekti": 106,
        "Keskustelu wikiprojektista": 107,
        "TimedText": 710,
        "TimedText talk": 711,
        "Moduuli": 828,
        "Keskustelu moduulista": 829,
        "Pienoisohjelma": 2300,
        "Keskustelu pienoisohjelmasta": 2301,
        "Pienoisohjelman määritys": 2302,
        "Keskustelu pienoisohjelman määrityksestä": 2303,
        "Aihe": 2600,
    },
    "fiu-vro": {
        "Meediä": -2,
        "Tallituslehekülg": -1,
        "Arotus": 1,
        "Pruukja": 2,
        "Pruukja arotus": 3,
        "Wikipedia": 4,
        "Wikipedia arotus": 5,
        "Pilt": 6,
        "Pildi arotus": 7,
        "MediaWiki": 8,
        "MediaWiki arotus": 9,
        "Näüdüs": 10,
        "Näüdüse arotus": 11,
        "Oppus": 12,
        "Oppusõ arotus": 13,
        "Katõgooria": 14,
        "Katõgooria arotus": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Moodul": 828,
        "Mooduli arutelu": 829,
        "Tööriist": 2300,
        "Tööriista arutelu": 2301,
        "Tööriista määratlus": 2302,
        "Tööriista määratluse arutelu": 2303,
    },
    "fj": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "fo": {
        "Miðil": -2,
        "Serstakt": -1,
        "Kjak": 1,
        "Brúkari": 2,
        "Brúkarakjak": 3,
        "Wikipedia": 4,
        "Wikipedia-kjak": 5,
        "Mynd": 6,
        "Myndakjak": 7,
        "MediaWiki": 8,
        "MediaWiki-kjak": 9,
        "Fyrimynd": 10,
        "Fyrimyndakjak": 11,
        "Hjálp": 12,
        "Hjálparkjak": 13,
        "Bólkur": 14,
        "Bólkakjak": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "fr": {
        "Média": -2,
        "Spécial": -1,
        "Discussion": 1,
        "Utilisateur": 2,
        "Discussion utilisateur": 3,
        "Wikipédia": 4,
        "Discussion Wikipédia": 5,
        "Fichier": 6,
        "Discussion fichier": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèle": 10,
        "Discussion modèle": 11,
        "Aide": 12,
        "Discussion aide": 13,
        "Catégorie": 14,
        "Discussion catégorie": 15,
        "Portail": 100,
        "Discussion Portail": 101,
        "Projet": 102,
        "Discussion Projet": 103,
        "Référence": 104,
        "Discussion Référence": 105,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
        "Sujet": 2600,
    },
    "frp": {
        "Mèdia": -2,
        "Spèciâl": -1,
        "Discussion": 1,
        "Utilisator": 2,
        "Discussion utilisator": 3,
        "Vouiquipèdia": 4,
        "Discussion Vouiquipèdia": 5,
        "Fichiér": 6,
        "Discussion fichiér": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèlo": 10,
        "Discussion modèlo": 11,
        "Éde": 12,
        "Discussion éde": 13,
        "Catègorie": 14,
        "Discussion catègorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "frr": {
        "Medium": -2,
        "Spezial": -1,
        "Diskussion": 1,
        "Benutzer": 2,
        "Benutzer Diskussion": 3,
        "Wikipedia": 4,
        "Wikipedia Diskussion": 5,
        "Datei": 6,
        "Datei Diskussion": 7,
        "MediaWiki": 8,
        "MediaWiki Diskussion": 9,
        "Vorlage": 10,
        "Vorlage Diskussion": 11,
        "Hilfe": 12,
        "Hilfe Diskussion": 13,
        "Kategorie": 14,
        "Kategorie Diskussion": 15,
        "Seite": 102,
        "Seite Diskussion": 103,
        "Index": 104,
        "Index Diskussion": 105,
        "Text": 106,
        "Text Diskussion": 107,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussion": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "fur": {
        "Media": -2,
        "Speciâl": -1,
        "Discussion": 1,
        "Utent": 2,
        "Discussion utent": 3,
        "Vichipedie": 4,
        "Discussion Vichipedie": 5,
        "Figure": 6,
        "Discussion figure": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Model": 10,
        "Discussion model": 11,
        "Jutori": 12,
        "Discussion jutori": 13,
        "Categorie": 14,
        "Discussion categorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Discussioni modulo": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "fy": {
        "Media": -2,
        "Wiki": -1,
        "Oerlis": 1,
        "Meidogger": 2,
        "Meidogger oerlis": 3,
        "Wikipedy": 4,
        "Wikipedy oerlis": 5,
        "Ofbyld": 6,
        "Ofbyld oerlis": 7,
        "MediaWiki": 8,
        "MediaWiki oerlis": 9,
        "Berjocht": 10,
        "Berjocht oerlis": 11,
        "Hulp": 12,
        "Hulp oerlis": 13,
        "Kategory": 14,
        "Kategory oerlis": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ga": {
        "Meán": -2,
        "Speisialta": -1,
        "Plé": 1,
        "Úsáideoir": 2,
        "Plé úsáideora": 3,
        "Vicipéid": 4,
        "Plé Vicipéide": 5,
        "Íomhá": 6,
        "Plé íomhá": 7,
        "MediaWiki": 8,
        "Plé MediaWiki": 9,
        "Teimpléad": 10,
        "Plé teimpléid": 11,
        "Cabhair": 12,
        "Plé cabhrach": 13,
        "Catagóir": 14,
        "Plé catagóire": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "gag": {
        "Mediya": -2,
        "Maasus": -1,
        "Dartışma": 1,
        "Kullanıcı": 2,
        "Kullanıcı dartışma": 3,
        "Vikipediya": 4,
        "Vikipediyanın laflanması": 5,
        "Dosye": 6,
        "Dosye dartışma": 7,
        "MediaWiki": 8,
        "MediaWiki dartışma": 9,
        "Şablon": 10,
        "Şablon dartışma": 11,
        "Yardım": 12,
        "Yardım dartışma": 13,
        "Kategoriya": 14,
        "Kategoriya dartışma": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modül": 828,
        "Modül tartışma": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "gan": {
        "媒體": -2,
        "特別": -1,
        "談詑": 1,
        "用戶": 2,
        "用戶・談詑": 3,
        "Wikipedia": 4,
        "Wikipedia・談詑": 5,
        "文檔": 6,
        "文檔・談詑": 7,
        "MediaWiki": 8,
        "MediaWiki・談詑": 9,
        "模板": 10,
        "模板・談詑": 11,
        "幫助": 12,
        "幫助・談詑": 13,
        "分類": 14,
        "分類・談詑": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "gcr": {
        "Médja": -2,
        "Èspésyal": -1,
        "Diskisyon": 1,
        "Itilizatò": 2,
        "Diskisyon itilizatò": 3,
        "Wikipédja": 4,
        "Diskisyon Wikipédja": 5,
        "Fiché": 6,
        "Diskisyon fiché": 7,
        "MediaWiki": 8,
        "Diskisyon MediaWiki": 9,
        "Modèl": 10,
        "Diskisyon modèl": 11,
        "Lèd": 12,
        "Diskisyon lèd": 13,
        "Katégori": 14,
        "Diskisyon katégori": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modjoul": 828,
        "Diskisyon modjoul": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "gd": {
        "Meadhan": -2,
        "Sònraichte": -1,
        "Deasbaireachd": 1,
        "Cleachdaiche": 2,
        "Deasbaireachd a' chleachdaiche": 3,
        "Uicipeid": 4,
        "An deasbaireachd aig Uicipeid": 5,
        "Faidhle": 6,
        "Deasbaireachd an fhaidhle": 7,
        "MediaWiki": 8,
        "Deasbaireachd MediaWiki": 9,
        "Teamplaid": 10,
        "Deasbaireachd na teamplaid": 11,
        "Cobhair": 12,
        "Deasbaireachd na cobharach": 13,
        "Roinn-seòrsa": 14,
        "Deasbaireachd na roinn-seòrsa": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Mòideal": 828,
        "Deasbaireachd mòideil": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "gl": {
        "Media": -2,
        "Especial": -1,
        "Conversa": 1,
        "Usuario": 2,
        "Conversa usuario": 3,
        "Wikipedia": 4,
        "Conversa Wikipedia": 5,
        "Ficheiro": 6,
        "Conversa ficheiro": 7,
        "MediaWiki": 8,
        "Conversa MediaWiki": 9,
        "Modelo": 10,
        "Conversa modelo": 11,
        "Axuda": 12,
        "Conversa axuda": 13,
        "Categoría": 14,
        "Conversa categoría": 15,
        "Portal": 100,
        "Conversa portal": 101,
        "Libro": 102,
        "Conversa libro": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Conversa módulo": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "glk": {
        "مديا": -2,
        "خاص": -1,
        "گب": 1,
        "کارگير": 2,
        "کارگيرˇ گب": 3,
        "Wikipedia": 4,
        "مدي Wikipedia": 5,
        "فاىل": 6,
        "فاىلˇ گب": 7,
        "مدياويکي": 8,
        "مدياويکي گب": 9,
        "قالب": 10,
        "قالبˇ گب": 11,
        "رانما": 12,
        "رانما گب": 13,
        "جرگه": 14,
        "جرگه گب": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "پودمان": 828,
        "بحث پودمان": 829,
        "ابزار": 2300,
        "بحث ابزار": 2301,
        "توضیحات ابزار": 2302,
        "بحث توضیحات ابزار": 2303,
    },
    "gn": {
        "Medio": -2,
        "Mba'echĩchĩ": -1,
        "Myangekõi": 1,
        "Puruhára": 2,
        "Puruhára myangekõi": 3,
        "Vikipetã": 4,
        "Vikipetã myangekõi": 5,
        "Ta'ãnga": 6,
        "Ta'ãnga myangekõi": 7,
        "MediaWiki": 8,
        "MediaWiki myangekõi": 9,
        "Tembiecharã": 10,
        "Tembiecharã myangekõi": 11,
        "Pytyvõ": 12,
        "Pytyvõ myangekõi": 13,
        "Ñemohenda": 14,
        "Ñemohenda myangekõi": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo discusión": 829,
        "Accesorio": 2300,
        "Accesorio discusión": 2301,
        "Accesorio definición": 2302,
        "Accesorio definición discusión": 2303,
    },
    "gom": {
        "माध्यम": -2,
        "विशेश": -1,
        "चर्चा": 1,
        "वापरपी": 2,
        "वापरपी चर्चा": 3,
        "विकिपीडिया": 4,
        "विकिपीडिया चर्चा": 5,
        "फायल": 6,
        "फायल चर्चा": 7,
        "मिडियाविकी": 8,
        "मिडियाविकी चर्चा": 9,
        "सांचो": 10,
        "सांचो चर्चा": 11,
        "आदार": 12,
        "आदार चर्चा": 13,
        "वर्ग": 14,
        "वर्ग चर्चा": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "एकक": 828,
        "एकक चर्चा": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "विशय": 2600,
    },
    "gor": {
        "Media": -2,
        "Spesial": -1,
        "Lo'iya": 1,
        "Ta ohu'uwo": 2,
        "Lo'iya ta ohu'uwo": 3,
        "Wikipedia": 4,
        "Lo'iya Wikipedia": 5,
        "Berkas": 6,
        "Lo'iya berkas": 7,
        "MediaWiki": 8,
        "Lo'iya MediaWiki": 9,
        "Templat": 10,
        "Lo'iya templat": 11,
        "Wubodu": 12,
        "Lo'iya wubodu": 13,
        "Dalala": 14,
        "Lo'iya dalala": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pembicaraan Modul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "got": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐍃": 2,
        "𐌽𐌹𐌿𐍄𐌰𐌽𐌳𐌹𐍃 𐌲𐌰𐍅𐌰𐌿𐍂𐌳𐌾𐌰": 3,
        "Wikipedia": 4,
        "𐌸𐌹𐍃 Wikipedia 𐌲𐌰𐍅𐌰𐌿𐍂𐌳𐌾𐌰": 5,
        "𐍆𐌴𐌹𐌻𐌰": 6,
        "𐍆𐌴𐌹𐌻𐌹𐌽𐍃 𐌲𐌰𐍅𐌰𐌿𐍂𐌳𐌾𐌰": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "𐍆𐌰𐌿𐍂𐌰𐌼𐌴𐌻𐌴𐌹𐌽𐍃": 10,
        "𐍆𐌰𐌿𐍂𐌰𐌼𐌴𐌻𐌴𐌹𐌽𐌰𐌹𐍃 𐌲𐌰𐍅𐌰𐌿𐍂𐌳𐌾𐌰": 11,
        "𐌷𐌹𐌻𐍀𐌰": 12,
        "𐌷𐌹𐌻𐍀𐍉𐍃 𐌲𐌰𐍅𐌰𐌿𐍂𐌳𐌾𐌰": 13,
        "𐌷𐌰𐌽𐍃𐌰": 14,
        "𐌷𐌰𐌽𐍃𐍉𐍃 𐌲𐌰𐍅𐌰𐌿𐍂𐌳𐌾𐌰": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "gu": {
        "દ્રશ્ય-શ્રાવ્ય (મિડિયા)": -2,
        "વિશેષ": -1,
        "ચર્ચા": 1,
        "સભ્ય": 2,
        "સભ્યની ચર્ચા": 3,
        "વિકિપીડિયા": 4,
        "વિકિપીડિયા ચર્ચા": 5,
        "ચિત્ર": 6,
        "ચિત્રની ચર્ચા": 7,
        "મીડિયાવિકિ": 8,
        "મીડિયાવિકિ ચર્ચા": 9,
        "ઢાંચો": 10,
        "ઢાંચાની ચર્ચા": 11,
        "મદદ": 12,
        "મદદની ચર્ચા": 13,
        "શ્રેણી": 14,
        "શ્રેણીની ચર્ચા": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "વિભાગ": 828,
        "વિભાગ ચર્ચા": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "guw": {
        "Media": -2,
        "Vonọtaun": -1,
        "Hodidọ": 1,
        "Zinzantọ": 2,
        "Zinzantọ hodidọ": 3,
        "Wikipedia": 4,
        "Wikipedia hodidọ": 5,
        "Wepo": 6,
        "Wepo hodidọ": 7,
        "MediaWiki": 8,
        "MediaWiki hodidọ": 9,
        "Ohia": 10,
        "Ohia hodidọ": 11,
        "Alọgọ": 12,
        "Alọgọ hodidọ": 13,
        "Adà": 14,
        "Adà hodidọ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "gv": {
        "Meanyn": -2,
        "Er lheh": -1,
        "Resooney": 1,
        "Ymmydeyr": 2,
        "Resooney ymmydeyr": 3,
        "Wikipedia": 4,
        "Resooney Wikipedia": 5,
        "Coadan": 6,
        "Resooney coadan": 7,
        "MediaWiki": 8,
        "Resooney MediaWiki": 9,
        "Clowan": 10,
        "Resooney clowan": 11,
        "Cooney": 12,
        "Resooney cooney": 13,
        "Ronney": 14,
        "Resooney ronney": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ha": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "hak": {
        "媒體": -2,
        "特殊": -1,
        "討論": 1,
        "用戶": 2,
        "用戶討論": 3,
        "Wikipedia": 4,
        "Wikipedia討論": 5,
        "檔案": 6,
        "檔案討論": 7,
        "MediaWiki": 8,
        "MediaWiki討論": 9,
        "模板": 10,
        "模板討論": 11,
        "幫助": 12,
        "幫助討論": 13,
        "分類": 14,
        "分類討論": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "haw": {
        "Pāpaho": -2,
        "Papa nui": -1,
        "Kūkākūkā": 1,
        "Mea hoʻohana": 2,
        "Kūkākūkā o mea hoʻohana": 3,
        "Wikipedia": 4,
        "Kūkākūkā o Wikipikia": 5,
        "Waihona": 6,
        "Kūkākūkā o waihona": 7,
        "MediaWiki": 8,
        "Kūkākūkā o MediaWiki": 9,
        "Anakuhi": 10,
        "Kūkākūkā o anakuhi": 11,
        "Kōkua": 12,
        "Kūkākūkā o kōkua": 13,
        "Māhele": 14,
        "Kūkākūkā o māhele": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "he": {
        "מדיה": -2,
        "מיוחד": -1,
        "שיחה": 1,
        "משתמש": 2,
        "שיחת משתמש": 3,
        "ויקיפדיה": 4,
        "שיחת ויקיפדיה": 5,
        "קובץ": 6,
        "שיחת קובץ": 7,
        "מדיה ויקי": 8,
        "שיחת מדיה ויקי": 9,
        "תבנית": 10,
        "שיחת תבנית": 11,
        "עזרה": 12,
        "שיחת עזרה": 13,
        "קטגוריה": 14,
        "שיחת קטגוריה": 15,
        "פורטל": 100,
        "שיחת פורטל": 101,
        "ספר": 108,
        "שיחת ספר": 109,
        "טיוטה": 118,
        "שיחת טיוטה": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "יחידה": 828,
        "שיחת יחידה": 829,
        "גאדג'ט": 2300,
        "שיחת גאדג'ט": 2301,
        "הגדרת גאדג'ט": 2302,
        "שיחת הגדרת גאדג'ט": 2303,
        "נושא": 2600,
    },
    "hi": {
        "मीडिया": -2,
        "विशेष": -1,
        "वार्ता": 1,
        "सदस्य": 2,
        "सदस्य वार्ता": 3,
        "विकिपीडिया": 4,
        "विकिपीडिया वार्ता": 5,
        "चित्र": 6,
        "चित्र वार्ता": 7,
        "मीडियाविकि": 8,
        "मीडियाविकि वार्ता": 9,
        "साँचा": 10,
        "साँचा वार्ता": 11,
        "सहायता": 12,
        "सहायता वार्ता": 13,
        "श्रेणी": 14,
        "श्रेणी वार्ता": 15,
        "प्रवेशद्वार": 100,
        "प्रवेशद्वार वार्ता": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "गैजेट": 2300,
        "गैजेट वार्ता": 2301,
        "गैजेट परिभाषा": 2302,
        "गैजेट परिभाषा वार्ता": 2303,
    },
    "hif": {
        "saadhan": -2,
        "khaas": -1,
        "baat": 1,
        "sadasya": 2,
        "sadasya ke baat": 3,
        "Wikipedia": 4,
        "Wikipedia baat": 5,
        "file": 6,
        "file ke baat": 7,
        "MediaWiki": 8,
        "Mediawiki ke baat": 9,
        "Template": 10,
        "Template ke baat": 11,
        "madat": 12,
        "madat ke baat": 13,
        "vibhag": 14,
        "voibhag ke baat": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "hr": {
        "Mediji": -2,
        "Posebno": -1,
        "Razgovor": 1,
        "Suradnik": 2,
        "Razgovor sa suradnikom": 3,
        "Wikipedija": 4,
        "Razgovor Wikipedija": 5,
        "Datoteka": 6,
        "Razgovor o datoteci": 7,
        "MediaWiki": 8,
        "MediaWiki razgovor": 9,
        "Predložak": 10,
        "Razgovor o predlošku": 11,
        "Pomoć": 12,
        "Razgovor o pomoći": 13,
        "Kategorija": 14,
        "Razgovor o kategoriji": 15,
        "Portal": 100,
        "Razgovor o portalu": 101,
        "Dodatak": 102,
        "Razgovor o dodatku": 103,
        "Nacrt": 118,
        "Razgovor o nacrtu": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Razgovor o modulu": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "hsb": {
        "Media": -2,
        "Specialnje": -1,
        "Diskusija": 1,
        "Wužiwar": 2,
        "Diskusija z wužiwarjom": 3,
        "Wikipedija": 4,
        "Wikipedija diskusija": 5,
        "Dataja": 6,
        "Diskusija k dataji": 7,
        "MediaWiki": 8,
        "MediaWiki diskusija": 9,
        "Předłoha": 10,
        "Diskusija k předłoze": 11,
        "Pomoc": 12,
        "Pomoc diskusija": 13,
        "Kategorija": 14,
        "Diskusija ke kategoriji": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul diskusija": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "ht": {
        "Medya": -2,
        "Espesyal": -1,
        "Diskite": 1,
        "Itilizatè": 2,
        "Diskisyon Itilizatè": 3,
        "Wikipedya": 4,
        "Diskisyon Wikipedya": 5,
        "Fichye": 6,
        "Diskisyon Fichye": 7,
        "MedyaWiki": 8,
        "Diskisyon MedyaWiki": 9,
        "Modèl": 10,
        "Diskisyon Modèl": 11,
        "Èd": 12,
        "Diskisyon Èd": 13,
        "Kategori": 14,
        "Diskisyon Kategori": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "hu": {
        "Média": -2,
        "Speciális": -1,
        "Vita": 1,
        "Szerkesztő": 2,
        "Szerkesztővita": 3,
        "Wikipédia": 4,
        "Wikipédia-vita": 5,
        "Fájl": 6,
        "Fájlvita": 7,
        "MediaWiki": 8,
        "MediaWiki-vita": 9,
        "Sablon": 10,
        "Sablonvita": 11,
        "Segítség": 12,
        "Segítségvita": 13,
        "Kategória": 14,
        "Kategóriavita": 15,
        "Szál": 90,
        "Szálvita": 91,
        "Összefoglaló": 92,
        "Összefoglaló-vita": 93,
        "Portál": 100,
        "Portálvita": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modulvita": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "hy": {
        "Մեդիա": -2,
        "Սպասարկող": -1,
        "Քննարկում": 1,
        "Մասնակից": 2,
        "Մասնակցի քննարկում": 3,
        "Վիքիպեդիա": 4,
        "Վիքիպեդիայի քննարկում": 5,
        "Պատկեր": 6,
        "Պատկերի քննարկում": 7,
        "MediaWiki": 8,
        "MediaWiki քննարկում": 9,
        "Կաղապար": 10,
        "Կաղապարի քննարկում": 11,
        "Օգնություն": 12,
        "Օգնության քննարկում": 13,
        "Կատեգորիա": 14,
        "Կատեգորիայի քննարկում": 15,
        "Պորտալ": 100,
        "Պորտալի քննարկում": 101,
        "Վիքինախագիծ": 102,
        "Վիքինախագծի քննարկում": 103,
        "Սևագիր": 118,
        "Սևագրի քննարկում": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "Մոդուլ": 828,
        "Մոդուլի քննարկում": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "hyw": {
        "Մեդիա": -2,
        "Սպասարկող": -1,
        "Քննարկում": 1,
        "Մասնակից": 2,
        "Մասնակցի քննարկում": 3,
        "Ուիքիփետիա": 4,
        "Ուիքիփետիայի քննարկում": 5,
        "Պատկեր": 6,
        "Պատկերի քննարկում": 7,
        "MediaWiki": 8,
        "MediaWiki քննարկում": 9,
        "Կաղապար": 10,
        "Կաղապարի քննարկում": 11,
        "Օգնություն": 12,
        "Օգնության քննարկում": 13,
        "Ստորոգութիւն": 14,
        "Կատեգորիայի քննարկում": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Մոդուլ": 828,
        "Մոդուլի քննարկում": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ia": {
        "Multimedia": -2,
        "Special": -1,
        "Discussion": 1,
        "Usator": 2,
        "Discussion Usator": 3,
        "Wikipedia": 4,
        "Discussion Wikipedia": 5,
        "File": 6,
        "Discussion File": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Patrono": 10,
        "Discussion Patrono": 11,
        "Adjuta": 12,
        "Discussion Adjuta": 13,
        "Categoria": 14,
        "Discussion Categoria": 15,
        "Portal": 100,
        "Discussion Portal": 101,
        "Appendice": 102,
        "Discussion Appendice": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "id": {
        "Media": -2,
        "Istimewa": -1,
        "Pembicaraan": 1,
        "Pengguna": 2,
        "Pembicaraan Pengguna": 3,
        "Wikipedia": 4,
        "Pembicaraan Wikipedia": 5,
        "Berkas": 6,
        "Pembicaraan Berkas": 7,
        "MediaWiki": 8,
        "Pembicaraan MediaWiki": 9,
        "Templat": 10,
        "Pembicaraan Templat": 11,
        "Bantuan": 12,
        "Pembicaraan Bantuan": 13,
        "Kategori": 14,
        "Pembicaraan Kategori": 15,
        "Portal": 100,
        "Pembicaraan Portal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pembicaraan Modul": 829,
        "Story": 1704,
        "StoryTalk": 1705,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Topik": 2600,
    },
    "ie": {
        "Media": -2,
        "Special": -1,
        "Discussion": 1,
        "Usator": 2,
        "Usator Discussion": 3,
        "Wikipedia": 4,
        "Wikipedia Discussion": 5,
        "File": 6,
        "File Discussion": 7,
        "MediaWiki": 8,
        "MediaWiki Discussion": 9,
        "Avise": 10,
        "Avise Discussion": 11,
        "Auxilie": 12,
        "Auxilie Discussion": 13,
        "Categorie": 14,
        "Categorie Discussion": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ig": {
        "Midia": -2,
        "Ihü kárírí": -1,
        "Okwu": 1,
        "Ọbanife": 2,
        "Okwu ọbanife": 3,
        "Wikipedia": 4,
        "Okwu Wikipedia": 5,
        "Usòrò": 6,
        "Okwu usòrò": 7,
        "MidiaWiki": 8,
        "Okwu MidiaWiki": 9,
        "Àtụ": 10,
        "Okwu àtụ": 11,
        "Nkwadọ": 12,
        "Okwu nkwadọ": 13,
        "Òtù": 14,
        "Okwu òtù": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ik": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ilo": {
        "Midia": -2,
        "Espesial": -1,
        "Tungtungan": 1,
        "Agar-aramat": 2,
        "Agar-aramat tungtungan": 3,
        "Wikipedia": 4,
        "Wikipedia tungtungan": 5,
        "Papeles": 6,
        "Papeles tungtungan": 7,
        "MediaWiki": 8,
        "MediaWiki tungtungan": 9,
        "Plantilia": 10,
        "Plantilia tungtungan": 11,
        "Tulong": 12,
        "Tulong tungtungan": 13,
        "Kategoria": 14,
        "Kategoria tungtungan": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Modulo tungtungan": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "inh": {
        "Медиа": -2,
        "Гӏулакха": -1,
        "Ювцар": 1,
        "Доакъашхо": 2,
        "Доакъашхочун дувцар": 3,
        "Википеди": 4,
        "Википеди ювцар": 5,
        "Файл": 6,
        "Файл ювцар": 7,
        "MediaWiki": 8,
        "MediaWiki ювцар": 9,
        "Ло": 10,
        "Ло бувцар": 11,
        "Новкъостал": 12,
        "Новкъостал дувцар": 13,
        "ОагӀат": 14,
        "ОагӀат ювцар": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Модуль ювцар": 829,
        "Гаджет": 2300,
        "Гаджет ювцар": 2301,
        "Гаджета къоастадар": 2302,
        "Гаджета къоастадар дувцар": 2303,
    },
    "io": {
        "Media": -2,
        "Specala": -1,
        "Debato": 1,
        "Uzanto": 2,
        "Uzanto Debato": 3,
        "Wikipedio": 4,
        "Wikipedio Debato": 5,
        "Arkivo": 6,
        "Arkivo Debato": 7,
        "MediaWiki": 8,
        "MediaWiki Debato": 9,
        "Shablono": 10,
        "Shablono Debato": 11,
        "Helpo": 12,
        "Helpo Debato": 13,
        "Kategorio": 14,
        "Kategorio Debato": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Modulo-Diskuto": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "is": {
        "Miðill": -2,
        "Kerfissíða": -1,
        "Spjall": 1,
        "Notandi": 2,
        "Notandaspjall": 3,
        "Wikipedia": 4,
        "Wikipediaspjall": 5,
        "Mynd": 6,
        "Myndaspjall": 7,
        "Melding": 8,
        "Meldingarspjall": 9,
        "Snið": 10,
        "Sniðaspjall": 11,
        "Hjálp": 12,
        "Hjálparspjall": 13,
        "Flokkur": 14,
        "Flokkaspjall": 15,
        "Gátt": 100,
        "Gáttaspjall": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Smától": 2300,
        "Smátólaspjall": 2301,
        "Smátóla skilgreining": 2302,
        "Smátóla skilgreiningarspjall": 2303,
    },
    "it": {
        "Media": -2,
        "Speciale": -1,
        "Discussione": 1,
        "Utente": 2,
        "Discussioni utente": 3,
        "Wikipedia": 4,
        "Discussioni Wikipedia": 5,
        "File": 6,
        "Discussioni file": 7,
        "MediaWiki": 8,
        "Discussioni MediaWiki": 9,
        "Template": 10,
        "Discussioni template": 11,
        "Aiuto": 12,
        "Discussioni aiuto": 13,
        "Categoria": 14,
        "Discussioni categoria": 15,
        "Portale": 100,
        "Discussioni portale": 101,
        "Progetto": 102,
        "Discussioni progetto": 103,
        "Bozza": 118,
        "Discussioni bozza": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Discussioni modulo": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "iu": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "ᐅᐃᑭᐱᑎᐊ": 4,
        "ᐅᐃᑭᐱᑎᐊ talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ja": {
        "メディア": -2,
        "特別": -1,
        "ノート": 1,
        "利用者": 2,
        "利用者‐会話": 3,
        "Wikipedia": 4,
        "Wikipedia‐ノート": 5,
        "ファイル": 6,
        "ファイル‐ノート": 7,
        "MediaWiki": 8,
        "MediaWiki‐ノート": 9,
        "Template": 10,
        "Template‐ノート": 11,
        "Help": 12,
        "Help‐ノート": 13,
        "Category": 14,
        "Category‐ノート": 15,
        "Portal": 100,
        "Portal‐ノート": 101,
        "プロジェクト": 102,
        "プロジェクト‐ノート": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "モジュール": 828,
        "モジュール‐ノート": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "jam": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipidia": 4,
        "Wikipidia diskoshan": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "Puotal": 100,
        "Puotal diskoshan": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "jbo": {
        "velsku": -2,
        "rirci": -1,
        "casnu": 1,
        "pilno": 2,
        "casnu lo pilno": 3,
        "uikipedi'as": 4,
        "casnu la .uikipedi'as.": 5,
        "datnyvei": 6,
        "casnu lo datnyvei": 7,
        "medi'auikis": 8,
        "casnu la .medi'auikis.": 9,
        "termo'a": 10,
        "casnu lo termo'a": 11,
        "nundju": 12,
        "casnu lo nundju": 13,
        "klesi": 14,
        "casnu lo klesi": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "jv": {
        "Médhia": -2,
        "Mirunggan": -1,
        "Parembugan": 1,
        "Naraguna": 2,
        "Parembugan Naraguna": 3,
        "Wikipédia": 4,
        "Parembugan Wikipédia": 5,
        "Barkas": 6,
        "Parembugan Barkas": 7,
        "MédhiaWiki": 8,
        "Parembugan MédhiaWiki": 9,
        "Cithakan": 10,
        "Parembugan Cithakan": 11,
        "Pitulung": 12,
        "Parembugan Pitulung": 13,
        "Kategori": 14,
        "Parembugan Kategori": 15,
        "Gapura": 100,
        "Parembugan Gapura": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modhul": 828,
        "Parembugan Modhul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ka": {
        "მედია": -2,
        "სპეციალური": -1,
        "განხილვა": 1,
        "მომხმარებელი": 2,
        "მომხმარებლის განხილვა": 3,
        "ვიკიპედია": 4,
        "ვიკიპედია განხილვა": 5,
        "ფაილი": 6,
        "ფაილის განხილვა": 7,
        "მედიავიკი": 8,
        "მედიავიკის განხილვა": 9,
        "თარგი": 10,
        "თარგის განხილვა": 11,
        "დახმარება": 12,
        "დახმარების განხილვა": 13,
        "კატეგორია": 14,
        "კატეგორიის განხილვა": 15,
        "პორტალი": 100,
        "პორტალი განხილვა": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "მოდული": 828,
        "მოდულის განხილვა": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "kaa": {
        "Media": -2,
        "Arnawlı": -1,
        "Sa'wbet": 1,
        "Paydalanıwshı": 2,
        "Paydalanıwshı sa'wbeti": 3,
        "Wikipedia": 4,
        "Wikipedia sa'wbeti": 5,
        "Su'wret": 6,
        "Su'wret sa'wbeti": 7,
        "MediaWiki": 8,
        "MediaWiki sa'wbeti": 9,
        "Shablon": 10,
        "Shablon sa'wbeti": 11,
        "Anıqlama": 12,
        "Anıqlama sa'wbeti": 13,
        "Kategoriya": 14,
        "Kategoriya sa'wbeti": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "kab": {
        "Media": -2,
        "Uslig": -1,
        "Mmeslay": 1,
        "Amseqdac": 2,
        "Amyannan umsqedac": 3,
        "Wikipedia": 4,
        "Amyannan n Wikipedia": 5,
        "Tugna": 6,
        "Amyannan n tugna": 7,
        "MediaWiki": 8,
        "Amyannan n MediaWiki": 9,
        "Talɣa": 10,
        "Amyannan n talɣa": 11,
        "Tallat": 12,
        "Amyannan n tallat": 13,
        "Taggayt": 14,
        "Amyannan n taggayt": 15,
        "Awwur": 100,
        "Amyannan uwwur": 101,
        "Asenfaṛ": 102,
        "Amyannan usenfaṛ": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
        "Sujet": 2600,
    },
    "kbd": {
        "Медиа": -2,
        "Служебная": -1,
        "Тепсэлъэхьыгъуэ": 1,
        "ЦӀыхухэт": 2,
        "ЦӀыхухэт тепсэлъэхьыгъуэ": 3,
        "Уикипедиэ": 4,
        "Уикипедиэм и тепсэлъыхьыгъуэ": 5,
        "Файл": 6,
        "Файл тепсэлъэхьыгъуэ": 7,
        "MediaWiki": 8,
        "MediaWiki тепсэлъэхьыгъуэ": 9,
        "Шаблон": 10,
        "Шаблон тепсэлъэхьыгъуэ": 11,
        "ДэӀэпыкъуэгъуэ": 12,
        "ДэӀэпыкъуэгъуэ тепсэлъэхьыгъуэ": 13,
        "Категориэ": 14,
        "Категориэ тепсэлъэхьыгъуэ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "kbp": {
        "Média": -2,
        "Spécial": -1,
        "Discussion": 1,
        "Utilisateur": 2,
        "Discussion utilisateur": 3,
        "Wikipediya": 4,
        "Wikipediya ndɔnjɔɔlɩyɛ": 5,
        "Fichier": 6,
        "Discussion fichier": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèle": 10,
        "Discussion modèle": 11,
        "Aide": 12,
        "Discussion aide": 13,
        "Catégorie": 14,
        "Discussion catégorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "kcg": {
        "Media": -2,
        "Wat khwo": -1,
        "A\u200c̱lyiat": 1,
        "A\u200c̱tyunta̱m": 2,
        "A\u200c̱lyiat a\u200c̱tyunta\u200c̱m": 3,
        "Wukipedia": 4,
        "A\u200c̱lyiat Wukipedia": 5,
        "Fail": 6,
        "A\u200c̱lyiat fail": 7,
        "MediaWiki": 8,
        "A\u200c̱lyiat MediaWiki": 9,
        "Ta\u200c̱mpi\u200c̱let": 10,
        "A\u200c̱lyiat ta\u200c̱mpi\u200c̱let": 11,
        "Beang": 12,
        "A\u200c̱lyiat beang": 13,
        "Sa": 14,
        "A\u200c̱lyiat nsa": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "kg": {
        "Media": -2,
        "Special": -1,
        "Disolo": 1,
        "Kisadi": 2,
        "Disolo kisadi": 3,
        "Wikipedia": 4,
        "Disolo Wikipedia": 5,
        "Fisye": 6,
        "Disolo fisye": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Lusadisu": 12,
        "Disolo lusadisu": 13,
        "Kalasi": 14,
        "Disolo kalasi": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ki": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "kk": {
        "Таспа": -2,
        "Арнайы": -1,
        "Талқылау": 1,
        "Қатысушы": 2,
        "Қатысушы талқылауы": 3,
        "Уикипедия": 4,
        "Уикипедия талқылауы": 5,
        "Сурет": 6,
        "Сурет талқылауы": 7,
        "МедиаУики": 8,
        "МедиаУики талқылауы": 9,
        "Үлгі": 10,
        "Үлгі талқылауы": 11,
        "Анықтама": 12,
        "Анықтама талқылауы": 13,
        "Санат": 14,
        "Санат талқылауы": 15,
        "Портал": 100,
        "Портал талқылауы": 101,
        "Жоба": 102,
        "Жоба талқылауы": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Topic": 2600,
    },
    "kl": {
        "Media": -2,
        "Immikkut": -1,
        "Oqallinneq": 1,
        "Atuisoq": 2,
        "Atuisup oqalliffia": 3,
        "Wikipedia": 4,
        "Wikipedia-p oqalliffia": 5,
        "Fiileq": 6,
        "Fiilip oqalliffia": 7,
        "MediaWiki": 8,
        "Mediawikip oqalliffia": 9,
        "Ilisserut": 10,
        "Ilisserummi oqallinneq": 11,
        "Ikiuutit": 12,
        "Ikiuutini oqallinneq": 13,
        "Sumut atassuseq": 14,
        "Sumut atassusermi oqallinneq": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Moduldiskussion": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "km": {
        "មេឌា": -2,
        "ពិសេស": -1,
        "ការពិភាក្សា": 1,
        "អ្នកប្រើប្រាស់": 2,
        "ការពិភាក្សារបស់អ្នកប្រើប្រាស់": 3,
        "វិគីភីឌា": 4,
        "ការពិភាក្សាអំពីវិគីភីឌា": 5,
        "ឯកសារ": 6,
        "ការពិភាក្សាអំពីឯកសារ": 7,
        "មេឌាវិគី": 8,
        "ការពិភាក្សាអំពីមេឌាវិគី": 9,
        "ទំព័រគំរូ": 10,
        "ការពិភាក្សាអំពីទំព័រគំរូ": 11,
        "ជំនួយ": 12,
        "ការពិភាក្សាអំពីជំនួយ": 13,
        "ចំណាត់ថ្នាក់ក្រុម": 14,
        "ការពិភាក្សាអំពីចំណាត់ថ្នាក់ក្រុម": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "kn": {
        "ಮೀಡಿಯ": -2,
        "ವಿಶೇಷ": -1,
        "ಚರ್ಚೆಪುಟ": 1,
        "ಸದಸ್ಯ": 2,
        "ಸದಸ್ಯರ ಚರ್ಚೆಪುಟ": 3,
        "ವಿಕಿಪೀಡಿಯ": 4,
        "ವಿಕಿಪೀಡಿಯ ಚರ್ಚೆ": 5,
        "ಚಿತ್ರ": 6,
        "ಚಿತ್ರ ಚರ್ಚೆಪುಟ": 7,
        "ಮೀಡಿಯವಿಕಿ": 8,
        "ಮೀಡೀಯವಿಕಿ ಚರ್ಚೆ": 9,
        "ಟೆಂಪ್ಲೇಟು": 10,
        "ಟೆಂಪ್ಲೇಟು ಚರ್ಚೆ": 11,
        "ಸಹಾಯ": 12,
        "ಸಹಾಯ ಚರ್ಚೆ": 13,
        "ವರ್ಗ": 14,
        "ವರ್ಗ ಚರ್ಚೆ": 15,
        "ಕರಡು": 118,
        "ಕರಡು ಚರ್ಚೆ": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "ಮಾಡ್ಯೂಲ್": 828,
        "ಮಾಡ್ಯೂಲ್ ಚರ್ಚೆ": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ko": {
        "미디어": -2,
        "특수": -1,
        "토론": 1,
        "사용자": 2,
        "사용자토론": 3,
        "위키백과": 4,
        "위키백과토론": 5,
        "파일": 6,
        "파일토론": 7,
        "미디어위키": 8,
        "미디어위키토론": 9,
        "틀": 10,
        "틀토론": 11,
        "도움말": 12,
        "도움말토론": 13,
        "분류": 14,
        "분류토론": 15,
        "포털": 100,
        "포털토론": 101,
        "위키프로젝트": 102,
        "위키프로젝트토론": 103,
        "초안": 118,
        "초안토론": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "모듈": 828,
        "모듈토론": 829,
        "소도구": 2300,
        "소도구토론": 2301,
        "소도구정의": 2302,
        "소도구정의토론": 2303,
    },
    "koi": {
        "Медиа": -2,
        "Служебная": -1,
        "Обсуждение": 1,
        "Участник": 2,
        "Обсуждение участника": 3,
        "Википедия": 4,
        "Баитам Википедия йылiсь": 5,
        "Файл": 6,
        "Обсуждение файла": 7,
        "MediaWiki": 8,
        "Обсуждение MediaWiki": 9,
        "Шаблон": 10,
        "Обсуждение шаблона": 11,
        "Справка": 12,
        "Обсуждение справки": 13,
        "Категория": 14,
        "Обсуждение категории": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "krc": {
        "Медиа": -2,
        "Къуллукъ": -1,
        "Сюзюу": 1,
        "Къошулуучу": 2,
        "Къошулуучуну сюзюу": 3,
        "Википедия": 4,
        "Википедия сюзюу": 5,
        "Файл": 6,
        "Файлны сюзюу": 7,
        "MediaWiki": 8,
        "MediaWiki-ни сюзюу": 9,
        "Шаблон": 10,
        "Шаблонну сюзюу": 11,
        "Болушлукъ": 12,
        "Болушлукъну сюзюу": 13,
        "Категория": 14,
        "Категорияны сюзюу": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "ks": {
        "میڈیا": -2,
        "خاص": -1,
        "کَتھ": 1,
        "رُکُن": 2,
        "رُکُن کَتھ": 3,
        "وِکیٖپیٖڈیا": 4,
        "وِکیٖپیٖڈیا کَتھ": 5,
        "فَیِل": 6,
        "فَیِل کَتھ": 7,
        "میٖڈیاوِکی": 8,
        "میٖڈیاوِکی کَتھ": 9,
        "فرما": 10,
        "فرما کَتھ": 11,
        "مَدَتھ": 12,
        "مَدَتھ کَتھ": 13,
        "زٲژ": 14,
        "زٲژ کَتھ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ksh": {
        "Medie": -2,
        "Extra": -1,
        "Klaaf": 1,
        "Metmaacher": 2,
        "Metmaacher Klaaf": 3,
        "Wikipedia": 4,
        "Wikipedia Klaaf": 5,
        "Datei": 6,
        "Dateie Klaaf": 7,
        "MediaWiki": 8,
        "MediaWiki Klaaf": 9,
        "Schablon": 10,
        "Schablone Klaaf": 11,
        "Hölp": 12,
        "Hölp Klaaf": 13,
        "Saachjrupp": 14,
        "Saachjruppe Klaaf": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussion": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "ku": {
        "Medya": -2,
        "Taybet": -1,
        "Gotûbêj": 1,
        "Bikarhêner": 2,
        "Gotûbêja bikarhêner": 3,
        "Wîkîpediya": 4,
        "Gotûbêja Wîkîpediyayê": 5,
        "Wêne": 6,
        "Gotûbêja wêneyî": 7,
        "MediaWiki": 8,
        "Gotûbêja MediaWiki": 9,
        "Şablon": 10,
        "Gotûbêja şablonê": 11,
        "Alîkarî": 12,
        "Gotûbêja alîkariyê": 13,
        "Kategorî": 14,
        "Gotûbêja kategoriyê": 15,
        "Portal": 100,
        "Gotûbêja portalê": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Gotûbêja modulê": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "kv": {
        "Медиа": -2,
        "Отсасян": -1,
        "Сёрнитанiн": 1,
        "Пырысь": 2,
        "Пырыськӧд сёрнитанiн": 3,
        "Википедия": 4,
        "Википедия донъялӧм": 5,
        "Файл": 6,
        "Файл донъялӧм": 7,
        "МедиаВики": 8,
        "МедиаВики донъялӧм": 9,
        "Шаблон": 10,
        "Шаблон донъялӧм": 11,
        "Справка": 12,
        "Обсуждение справки": 13,
        "Категория": 14,
        "Обсуждение категории": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "kw": {
        "Media": -2,
        "Arbennek": -1,
        "Keskows": 1,
        "Devnydhyer": 2,
        "Keskows Devnydhyer": 3,
        "Wikipedia": 4,
        "Keskows Wikipedia": 5,
        "Restren": 6,
        "Keskows Restren": 7,
        "MediaWiki": 8,
        "Keskows MediaWiki": 9,
        "Skantlyn": 10,
        "Keskows Skantlyn": 11,
        "Gweres": 12,
        "Keskows Gweres": 13,
        "Klass": 14,
        "Keskows Klass": 15,
        "Porth": 100,
        "Keskows Porth": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ky": {
        "Медиа": -2,
        "Атайын": -1,
        "Талкуу": 1,
        "Колдонуучу": 2,
        "Колдонуучунун баарлашуулары": 3,
        "Википедия": 4,
        "Википедияны талкуулоо": 5,
        "Файл": 6,
        "Файлды талкуулоо": 7,
        "МедиаВики": 8,
        "МедиаВикини талкуулоо": 9,
        "Калып": 10,
        "Калыпты талкуулоо": 11,
        "Жардам": 12,
        "Жардамды талкуулоо": 13,
        "Категория": 14,
        "Категорияны талкуулоо": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Модулду талкуулоо": 829,
        "Гаджет": 2300,
        "Гаджетти талкуулоо": 2301,
        "Гаджеттин түшүндүрмөсү": 2302,
        "Гаджеттин түшүндүрмөсүн талкуулоо": 2303,
    },
    "la": {
        "Media": -2,
        "Specialis": -1,
        "Disputatio": 1,
        "Usor": 2,
        "Disputatio Usoris": 3,
        "Vicipaedia": 4,
        "Disputatio Vicipaediae": 5,
        "Fasciculus": 6,
        "Disputatio Fasciculi": 7,
        "MediaWiki": 8,
        "Disputatio MediaWiki": 9,
        "Formula": 10,
        "Disputatio Formulae": 11,
        "Auxilium": 12,
        "Disputatio Auxilii": 13,
        "Categoria": 14,
        "Disputatio Categoriae": 15,
        "Porta": 100,
        "Disputatio Portae": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "lad": {
        "Medya": -2,
        "Especial": -1,
        "Diskusyón": 1,
        "Usador": 2,
        "Messaje de Usador": 3,
        "Vikipedya": 4,
        "Diskusyón de Vikipedya": 5,
        "Dosya": 6,
        "Diskusyón de Dosya": 7,
        "MedyaViki": 8,
        "Diskusyón de MedyaViki": 9,
        "Xablón": 10,
        "Diskusyón de Xablón": 11,
        "Ayudo": 12,
        "Diskusyón de Ayudo": 13,
        "Kateggoría": 14,
        "Diskusyón de Kateggoría": 15,
        "Portal": 100,
        "Diskusyón de Portal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo discusión": 829,
        "Accesorio": 2300,
        "Accesorio discusión": 2301,
        "Accesorio definición": 2302,
        "Accesorio definición discusión": 2303,
    },
    "lb": {
        "Media": -2,
        "Spezial": -1,
        "Diskussioun": 1,
        "Benotzer": 2,
        "Benotzer Diskussioun": 3,
        "Wikipedia": 4,
        "Wikipedia Diskussioun": 5,
        "Fichier": 6,
        "Fichier Diskussioun": 7,
        "MediaWiki": 8,
        "MediaWiki Diskussioun": 9,
        "Schabloun": 10,
        "Schabloun Diskussioun": 11,
        "Hëllef": 12,
        "Hëllef Diskussioun": 13,
        "Kategorie": 14,
        "Kategorie Diskussioun": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussioun": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "lbe": {
        "Медиа": -2,
        "Къуллугъирал лажин": -1,
        "Ихтилат": 1,
        "Гьуртту хьума": 2,
        "Гьуртту хьуминнал ихтилат": 3,
        "Википедия": 4,
        "Википедиялиясса ихтилат": 5,
        "Сурат": 6,
        "Суратраясса ихтилат": 7,
        "MediaWiki": 8,
        "MediaWikiлиясса ихтилат": 9,
        "Шаблон": 10,
        "Шаблондалиясса ихтилат": 11,
        "Кумаг": 12,
        "Кумаграясса ихтилат": 13,
        "Категория": 14,
        "Категориялиясса ихтилат": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "lez": {
        "Медиа": -2,
        "Служебная": -1,
        "Веревирд авун": 1,
        "Уртах": 2,
        "Уртахдин веревирд авун": 3,
        "Википедия": 4,
        "Википедия веревирд авун": 5,
        "Файл": 6,
        "Файл веревирд авун": 7,
        "MediaWiki": 8,
        "MediaWiki веревирд авун": 9,
        "Шаблон": 10,
        "Шаблон веревирд авун": 11,
        "Справка": 12,
        "Обсуждение справки": 13,
        "Категория": 14,
        "Категория веревирд авун": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "lfn": {
        "Media": -2,
        "Spesial": -1,
        "Discute": 1,
        "Usor": 2,
        "Usor Discute": 3,
        "Vicipedia": 4,
        "Vicipedia Discute": 5,
        "Fix": 6,
        "Fix Discute": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Model": 10,
        "Model Discute": 11,
        "Aida": 12,
        "Aida Discute": 13,
        "Categoria": 14,
        "Categoria Discute": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Modulo Discute": 829,
        "Macineta": 2300,
        "Macineta Discute": 2301,
        "Defini de macineta": 2302,
        "Defini de macineta Discute": 2303,
    },
    "lg": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "li": {
        "Media": -2,
        "Speciaal": -1,
        "Euverlèk": 1,
        "Gebroeker": 2,
        "Euverlèk gebroeker": 3,
        "Wikipedia": 4,
        "Euverlèk Wikipedia": 5,
        "Plaetje": 6,
        "Euverlèk plaetje": 7,
        "MediaWiki": 8,
        "Euverlèk MediaWiki": 9,
        "Sjabloon": 10,
        "Euverlèk sjabloon": 11,
        "Help": 12,
        "Euverlèk help": 13,
        "Categorie": 14,
        "Euverlèk categorie": 15,
        "Portaol": 100,
        "Euverlèk portaol": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Overleg module": 829,
        "Uitbreiding": 2300,
        "Overleg uitbreiding": 2301,
        "Uitbreidingsdefinitie": 2302,
        "Overleg uitbreidingsdefinitie": 2303,
    },
    "lij": {
        "Media": -2,
        "Speçiale": -1,
        "Discûscion": 1,
        "Utente": 2,
        "Discûscioîn ûtente": 3,
        "Wikipedia": 4,
        "Discûscioîn Wikipedia": 5,
        "Immaggine": 6,
        "Discûscioîn immaggine": 7,
        "MediaWiki": 8,
        "Discûscioîn MediaWiki": 9,
        "Template": 10,
        "Discûscioîn template": 11,
        "Agiûtto": 12,
        "Discûscioîn agiûtto": 13,
        "Categorîa": 14,
        "Discûscioîn categorîa": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Discussioni modulo": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "lld": {
        "Media": -2,
        "Speciale": -1,
        "Discussione": 1,
        "Utente": 2,
        "Discussioni utente": 3,
        "Wikipedia": 4,
        "Discussioni Wikipedia": 5,
        "File": 6,
        "Discussioni file": 7,
        "MediaWiki": 8,
        "Discussioni MediaWiki": 9,
        "Template": 10,
        "Discussioni template": 11,
        "Aiuto": 12,
        "Discussioni aiuto": 13,
        "Categoria": 14,
        "Discussioni categoria": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Discussioni modulo": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "lmo": {
        "Media": -2,
        "Special": -1,
        "Ciciarada": 1,
        "Utent": 2,
        "Ciciarada Utent": 3,
        "Wikipedia": 4,
        "Ciciarada Wikipedia": 5,
        "Archivi": 6,
        "Ciciarada Archivi": 7,
        "MediaWiki": 8,
        "Ciciarada MediaWiki": 9,
        "Modell": 10,
        "Ciciarada Modell": 11,
        "Jut": 12,
        "Ciciarada Jut": 13,
        "Categoria": 14,
        "Ciciarada Categoria": 15,
        "Portal": 100,
        "Descüssiú Portal": 101,
        "Purtaal": 102,
        "Descüssiun Purtaal": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Mòdul": 828,
        "Ciciarada Mòdul": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "ln": {
        "Média": -2,
        "Spécial": -1,
        "Discussion": 1,
        "Utilisateur": 2,
        "Discussion utilisateur": 3,
        "Wikipedia": 4,
        "Discussion Wikipedia": 5,
        "Fichier": 6,
        "Discussion fichier": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèle": 10,
        "Discussion modèle": 11,
        "Aide": 12,
        "Discussion aide": 13,
        "Catégorie": 14,
        "Discussion catégorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "lo": {
        "ສື່": -2,
        "ພິເສດ": -1,
        "ສົນທະນາ": 1,
        "ຜູ້ໃຊ້": 2,
        "ສົນທະນາຂອງຜູ້ໃຊ້": 3,
        "ວິກິພີເດຍ": 4,
        "ສົນທະນາກ່ຽວກັບວິກິພີເດຍ": 5,
        "ຮູບ": 6,
        "ສົນທະນາກ່ຽວກັບຮູບ": 7,
        "ມີເດຍວິກິ": 8,
        "ສົນທະນາກ່ຽວກັບມີເດຍວິກິ": 9,
        "ແມ່ແບບ": 10,
        "ສົນທະນາກ່ຽວກັບແມ່ແບບ": 11,
        "ຊ່ວຍເຫຼືອ": 12,
        "ສົນທະນາກ່ຽວກັບຊ່ວຍເຫຼືອ": 13,
        "ໝວດ": 14,
        "ສົນທະນາກ່ຽວກັບໝວດ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "lt": {
        "Medija": -2,
        "Specialus": -1,
        "Aptarimas": 1,
        "Naudotojas": 2,
        "Naudotojo aptarimas": 3,
        "Vikipedija": 4,
        "Vikipedijos aptarimas": 5,
        "Vaizdas": 6,
        "Vaizdo aptarimas": 7,
        "MediaWiki": 8,
        "MediaWiki aptarimas": 9,
        "Šablonas": 10,
        "Šablono aptarimas": 11,
        "Pagalba": 12,
        "Pagalbos aptarimas": 13,
        "Kategorija": 14,
        "Kategorijos aptarimas": 15,
        "Vikisritis": 100,
        "Vikisrities aptarimas": 101,
        "Vikiprojektas": 102,
        "Vikiprojekto aptarimas": 103,
        "Sąrašas": 104,
        "Sąrašo aptarimas": 105,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ltg": {
        "Medeja": -2,
        "Seviškuo": -1,
        "Sprīža": 1,
        "Lītuotuojs": 2,
        "Sprīža ap lītuotuoju": 3,
        "Vikipedeja": 4,
        "Vikipedejis sprīža": 5,
        "Fails": 6,
        "Sprīža ap failu": 7,
        "MediaWiki": 8,
        "Sprīža ap MediaWiki": 9,
        "Taiss": 10,
        "Sprīža ap taisu": 11,
        "Paleigs": 12,
        "Sprīža ap paleigu": 13,
        "Kategoreja": 14,
        "Sprīža ap kategoreju": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulis": 828,
        "Moduļa diskusija": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "lv": {
        "Media": -2,
        "Special": -1,
        "Diskusija": 1,
        "Dalībnieks": 2,
        "Dalībnieka diskusija": 3,
        "Vikipēdija": 4,
        "Vikipēdijas diskusija": 5,
        "Attēls": 6,
        "Attēla diskusija": 7,
        "MediaWiki": 8,
        "MediaWiki diskusija": 9,
        "Veidne": 10,
        "Veidnes diskusija": 11,
        "Palīdzība": 12,
        "Palīdzības diskusija": 13,
        "Kategorija": 14,
        "Kategorijas diskusija": 15,
        "Portāls": 100,
        "Portāla diskusija": 101,
        "Vikiprojekts": 102,
        "Vikiprojekta diskusija": 103,
        "Education Program": 446,
        "Education Program talk": 447,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulis": 828,
        "Moduļa diskusija": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Tēma": 2600,
    },
    "mad": {
        "Mèḍia": -2,
        "Spesial": -1,
        "Pakanḍhâ'ân": 1,
        "Pangangghuy": 2,
        "Pakanḍhâ'ânna pangangghuy": 3,
        "Wikipèḍia": 4,
        "Pakanḍhâ'ânna Wikipèḍia": 5,
        "Bhengkek": 6,
        "Pakanḍhâ'ânna bhengkek": 7,
        "MèḍiaWiki": 8,
        "Pakanḍhâ'ânna MèḍiaWiki": 9,
        "Cèṭa'an": 10,
        "Pakanḍhâ'ânna cèṭa'an": 11,
        "Bhântowan": 12,
        "Pakanḍhâ'ânna bhântowan": 13,
        "Bhângsa": 14,
        "Pakanḍhâ'ânna bhângsa": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pembicaraan Modul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "mai": {
        "मेडिया": -2,
        "विशेष": -1,
        "वार्ता": 1,
        "प्रयोगकर्ता": 2,
        "प्रयोगकर्ता वार्ता": 3,
        "विकिपिडिया": 4,
        "विकिपिडिया वार्ता": 5,
        "फाइल": 6,
        "फाइल वार्ता": 7,
        "मेडियाविकि": 8,
        "मेडियाविकि वार्ता": 9,
        "आकृति": 10,
        "आकृति वार्ता": 11,
        "मद्दत": 12,
        "मद्दत वार्ता": 13,
        "श्रेणी": 14,
        "श्रेणी वार्ता": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "मोड्युल": 828,
        "मोड्युल वार्ता": 829,
        "गैजेट": 2300,
        "गैजेट वार्ता": 2301,
        "गैजेट परिभाषा": 2302,
        "गैजेट परिभाषा वार्ता": 2303,
    },
    "map-bms": {
        "Médhia": -2,
        "Mirunggan": -1,
        "Parembugan": 1,
        "Naraguna": 2,
        "Parembugan Naraguna": 3,
        "Wikipedia": 4,
        "Parembugan Wikipedia": 5,
        "Barkas": 6,
        "Parembugan Barkas": 7,
        "MédhiaWiki": 8,
        "Parembugan MédhiaWiki": 9,
        "Cithakan": 10,
        "Parembugan Cithakan": 11,
        "Pitulung": 12,
        "Parembugan Pitulung": 13,
        "Kategori": 14,
        "Parembugan Kategori": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modhul": 828,
        "Parembugan Modhul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "mdf": {
        "Медиа": -2,
        "Башка": -1,
        "Корхнема": 1,
        "Тиись": 2,
        "Тиись корхнема": 3,
        "Википедиесь": 4,
        "Википедиесь корхнема": 5,
        "Няйф": 6,
        "Няйф корхнема": 7,
        "МедиаВики": 8,
        "МедиаВики корхнема": 9,
        "Шаблон": 10,
        "Шаблон корхнема": 11,
        "Лезкс": 12,
        "Лезкс корхнема": 13,
        "Категорие": 14,
        "Категорие корхнема": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "mg": {
        "Rakitra": -2,
        "Manokana": -1,
        "Dinika": 1,
        "Mpikambana": 2,
        "Dinika amin'ny mpikambana": 3,
        "Wikipedia": 4,
        "Dinika amin'ny Wikipedia": 5,
        "Sary": 6,
        "Dinika amin'ny sary": 7,
        "MediaWiki": 8,
        "Dinika amin'ny MediaWiki": 9,
        "Endrika": 10,
        "Dinika amin'ny endrika": 11,
        "Fanoroana": 12,
        "Dinika amin'ny fanoroana": 13,
        "Sokajy": 14,
        "Dinika amin'ny sokajy": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "mhr": {
        "Медиа": -2,
        "Лӱмын ыштыме": -1,
        "Каҥашымаш": 1,
        "Пайдаланыше": 2,
        "Пайдаланышын каҥашымашыже": 3,
        "Википедий": 4,
        "Википедийын каҥашымашыже": 5,
        "Файл": 6,
        "Файл шотышто каҥашымаш": 7,
        "MediaWiki": 8,
        "MediaWiki-м кӓнгӓшӹмӓш": 9,
        "Кышкар": 10,
        "Кышкар шотышто каҥашымаш": 11,
        "Полшык": 12,
        "Полшык шотышто каҥашымаш": 13,
        "Категорий": 14,
        "Категорий шотышто каҥашымаш": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "mi": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "min": {
        "Media": -2,
        "Istimewa": -1,
        "Rundiang": 1,
        "Pangguno": 2,
        "Rundiang Pangguno": 3,
        "Wikipedia": 4,
        "Rundiang Wikipedia": 5,
        "Berkas": 6,
        "Rundiang Berkas": 7,
        "MediaWiki": 8,
        "Rundiang MediaWiki": 9,
        "Templat": 10,
        "Rundiang Templat": 11,
        "Bantuan": 12,
        "Rundiang Bantuan": 13,
        "Kategori": 14,
        "Rundiang Kategori": 15,
        "Portal": 100,
        "Diskusi Portal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Rundiang Modul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "mk": {
        "Медиум": -2,
        "Специјална": -1,
        "Разговор": 1,
        "Корисник": 2,
        "Разговор со корисник": 3,
        "Википедија": 4,
        "Разговор за Википедија": 5,
        "Податотека": 6,
        "Разговор за податотека": 7,
        "МедијаВики": 8,
        "Разговор за МедијаВики": 9,
        "Предлошка": 10,
        "Разговор за предлошка": 11,
        "Помош": 12,
        "Разговор за помош": 13,
        "Категорија": 14,
        "Разговор за категорија": 15,
        "Портал": 100,
        "Разговор за Портал": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модул": 828,
        "Разговор за модул": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ml": {
        "മീഡിയ": -2,
        "പ്രത്യേകം": -1,
        "സംവാദം": 1,
        "ഉപയോക്താവ്": 2,
        "ഉപയോക്താവിന്റെ സംവാദം": 3,
        "വിക്കിപീഡിയ": 4,
        "വിക്കിപീഡിയ സംവാദം": 5,
        "പ്രമാണം": 6,
        "പ്രമാണത്തിന്റെ സംവാദം": 7,
        "മീഡിയവിക്കി": 8,
        "മീഡിയവിക്കി സംവാദം": 9,
        "ഫലകം": 10,
        "ഫലകത്തിന്റെ സംവാദം": 11,
        "സഹായം": 12,
        "സഹായത്തിന്റെ സംവാദം": 13,
        "വർഗ്ഗം": 14,
        "വർഗ്ഗത്തിന്റെ സംവാദം": 15,
        "കവാടം": 100,
        "കവാടത്തിന്റെ സംവാദം": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "ഘടകം": 828,
        "ഘടകത്തിന്റെ സംവാദം": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "mn": {
        "Медиа": -2,
        "Тусгай": -1,
        "Хэлэлцүүлэг": 1,
        "Хэрэглэгч": 2,
        "Хэрэглэгчийн яриа": 3,
        "Wikipedia": 4,
        "Wikipedia-н хэлэлцүүлэг": 5,
        "Файл": 6,
        "Файлын хэлэлцүүлэг": 7,
        "МедиаВики": 8,
        "МедиаВикигийн хэлэлцүүлэг": 9,
        "Загвар": 10,
        "Загварын хэлэлцүүлэг": 11,
        "Тусламж": 12,
        "Тусламжийн хэлэлцүүлэг": 13,
        "Ангилал": 14,
        "Ангиллын хэлэлцүүлэг": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "mni": {
        "ꯃꯦꯗꯤꯌꯥ": -2,
        "ꯑꯈꯟꯅꯕ": -1,
        "ꯋꯥ ꯍꯥꯏꯐꯝ": 1,
        "ꯁꯤꯖꯤꯟꯅꯔꯤꯕ": 2,
        "ꯁꯤꯖꯤꯟꯅꯔꯤꯕ ꯋꯥ ꯍꯥꯏꯐꯝ": 3,
        "ꯋꯤꯀꯤꯄꯦꯗꯤꯌꯥ": 4,
        "ꯋꯤꯀꯤꯄꯦꯗꯤꯌꯥ ꯋꯥ ꯍꯥꯏꯐꯝ": 5,
        "ꯐꯥꯏꯜ": 6,
        "ꯐꯥꯏꯜ ꯋꯥ ꯍꯥꯏꯐꯝ": 7,
        "ꯃꯦꯗꯤꯌꯥꯋꯤꯀꯤ": 8,
        "ꯃꯦꯗꯤꯌꯥꯋꯤꯀꯤ ꯋꯥ ꯍꯥꯏꯐꯝ": 9,
        "ꯇꯦꯝꯄ꯭ꯂꯦꯠ": 10,
        "ꯇꯦꯝꯄ꯭ꯂꯦꯠ ꯋꯥ ꯍꯥꯏꯐꯝ": 11,
        "ꯃꯇꯦꯡ": 12,
        "ꯃꯇꯦꯡ ꯋꯥ ꯍꯥꯏꯐꯝ": 13,
        "ꯃꯆꯥꯈꯥꯏꯕ": 14,
        "ꯃꯆꯥꯈꯥꯏꯕ ꯋꯥ ꯍꯥꯏꯐꯝ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "mnw": {
        "မဳဒဳယာ": -2,
        "တၟေင်": -1,
        "ဓရီုကျာ": 1,
        "ညးလွပ်": 2,
        "ညးလွပ် ဓရီုကျာ": 3,
        "ဝဳကဳပဳဒဳယာ": 4,
        "ဝဳကဳပဳဒဳယာ ဓရီုကျာ": 5,
        "ဝှာင်": 6,
        "ဝှာင် ဓရီုကျာ": 7,
        "မဳဒဳယာဝဳကဳ": 8,
        "မဳဒဳယာဝဳကဳ ဓရီုကျာ": 9,
        "ထာမ်ပလိက်": 10,
        "ထာမ်ပလိက် ဓရီုကျာ": 11,
        "ရီု": 12,
        "ရီု ဓရီုကျာ": 13,
        "ကဏ္ဍ": 14,
        "ကဏ္ဍ ဓရီုကျာ": 15,
        "ပါင်မုက်": 100,
        "ပါင်မုက် ဓရီုကျာ": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "မဝ်ဂျူ": 828,
        "မဝ်ဂျူ ဓရီုကျာ": 829,
        "ကိရိယာငယ်": 2300,
        "ကိရိယာငယ် ဆွေးနွေးချက်": 2301,
        "ကိရိယာငယ် အဓိပ္ပာယ်": 2302,
        "ကိရိယာငယ် အဓိပ္ပာယ် ဆွေးနွေးချက်": 2303,
    },
    "mr": {
        "मिडिया": -2,
        "विशेष": -1,
        "चर्चा": 1,
        "सदस्य": 2,
        "सदस्य चर्चा": 3,
        "विकिपीडिया": 4,
        "विकिपीडिया चर्चा": 5,
        "चित्र": 6,
        "चित्र चर्चा": 7,
        "मिडियाविकी": 8,
        "मिडियाविकी चर्चा": 9,
        "साचा": 10,
        "साचा चर्चा": 11,
        "सहाय्य": 12,
        "सहाय्य चर्चा": 13,
        "वर्ग": 14,
        "वर्ग चर्चा": 15,
        "दालन": 100,
        "दालन चर्चा": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "विभाग": 828,
        "विभाग चर्चा": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "mrj": {
        "Медиа": -2,
        "Спецӹлӹштӓш": -1,
        "Кӓнгӓшӹмӓш": 1,
        "Сирӹшӹ": 2,
        "Сирӹшӹм кӓнгӓшӹмӓш": 3,
        "Википеди": 4,
        "Википедим кӓнгӓшӹмӓш": 5,
        "Файл": 6,
        "Файлым кӓнгӓшӹмӓш": 7,
        "MediaWiki": 8,
        "MediaWiki-м кӓнгӓшӹмӓш": 9,
        "Шаблон": 10,
        "Шаблоным кӓнгӓшӹмӓш": 11,
        "Палшык": 12,
        "Палшыкым кӓнгӓшӹмӓш": 13,
        "Категори": 14,
        "Категорим кӓнгӓшӹмӓш": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "ms": {
        "Media": -2,
        "Khas": -1,
        "Perbincangan": 1,
        "Pengguna": 2,
        "Perbincangan pengguna": 3,
        "Wikipedia": 4,
        "Perbincangan Wikipedia": 5,
        "Fail": 6,
        "Perbincangan fail": 7,
        "MediaWiki": 8,
        "Perbincangan MediaWiki": 9,
        "Templat": 10,
        "Perbincangan templat": 11,
        "Bantuan": 12,
        "Perbincangan bantuan": 13,
        "Kategori": 14,
        "Perbincangan kategori": 15,
        "Portal": 100,
        "Perbincangan portal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Perbincangan modul": 829,
        "Alat": 2300,
        "Perbincangan alat": 2301,
        "Penerangan alat": 2302,
        "Perbincangan penerangan alat": 2303,
    },
    "mt": {
        "Medja": -2,
        "Speċjali": -1,
        "Diskussjoni": 1,
        "Utent": 2,
        "Diskussjoni utent": 3,
        "Wikipedija": 4,
        "Diskussjoni Wikipedija": 5,
        "Stampa": 6,
        "Diskussjoni stampa": 7,
        "MediaWiki": 8,
        "Diskussjoni MediaWiki": 9,
        "Mudell": 10,
        "Diskussjoni mudell": 11,
        "Għajnuna": 12,
        "Diskussjoni għajnuna": 13,
        "Kategorija": 14,
        "Diskussjoni kategorija": 15,
        "Portal": 100,
        "Diskussjoni portal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "mwl": {
        "Multimédia": -2,
        "Special": -1,
        "Cumbersa": 1,
        "Outelizador(a)": 2,
        "Cumbersa outelizador(a)": 3,
        "Biquipédia": 4,
        "Cumbersa Biquipédia": 5,
        "Fexeiro": 6,
        "Cumbersa fexeiro": 7,
        "Biqui": 8,
        "Cumbersa Biqui": 9,
        "Modelo": 10,
        "Cumbersa modelo": 11,
        "Ajuda": 12,
        "Cumbersa ajuda": 13,
        "Catadorie": 14,
        "Cumbersa catadorie": 15,
        "Portal": 100,
        "Cumbersa portal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Cumbersa módulo": 829,
        "Gadget": 2300,
        "Cumbersa gadget": 2301,
        "Defeniçon gadget": 2302,
        "Cumbersa defeniçon gadget": 2303,
    },
    "my": {
        "မီဒီယာ": -2,
        "အထူး": -1,
        "ဆွေးနွေးချက်": 1,
        "အသုံးပြုသူ": 2,
        "အသုံးပြုသူ ဆွေးနွေးချက်": 3,
        "ဝီကီပီးဒီးယား": 4,
        "ဝီကီပီးဒီးယား ဆွေးနွေးချက်": 5,
        "ဖိုင်": 6,
        "ဖိုင် ဆွေးနွေးချက်": 7,
        "မီဒီယာဝီကီ": 8,
        "မီဒီယာဝီကီ ဆွေးနွေးချက်": 9,
        "တမ်းပလိတ်": 10,
        "တမ်းပလိတ် ဆွေးနွေးချက်": 11,
        "အကူအညီ": 12,
        "အကူအညီ ဆွေးနွေးချက်": 13,
        "ကဏ္ဍ": 14,
        "ကဏ္ဍ ဆွေးနွေးချက်": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "မော်ဂျူး": 828,
        "မော်ဂျူး ဆွေးနွေးချက်": 829,
        "ကိရိယာငယ်": 2300,
        "ကိရိယာငယ် ဆွေးနွေးချက်": 2301,
        "ကိရိယာငယ် အဓိပ္ပာယ်": 2302,
        "ကိရိယာငယ် အဓိပ္ပာယ် ဆွေးနွေးချက်": 2303,
    },
    "myv": {
        "Медия": -2,
        "Башка тевень": -1,
        "Кортамо": 1,
        "Теиця": 2,
        "Теицянь кортамось": 3,
        "Википедиясь": 4,
        "Википедиясь кортамось": 5,
        "Артовкс": 6,
        "Артовксто кортамось": 7,
        "MediaWiki": 8,
        "MediaWiki-нь кортамось": 9,
        "ЛопаПарцун": 10,
        "ЛопаПарцундо кортамось": 11,
        "Лезкс": 12,
        "Лезкстэ кортамось": 13,
        "Категория": 14,
        "Категориядо кортамось": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "mzn": {
        "مدیا": -2,
        "شا": -1,
        "گپ": 1,
        "کارور": 2,
        "کارور گپ": 3,
        "ویکی\u200cپدیا": 4,
        "ویکی\u200cپدیا گپ": 5,
        "پرونده": 6,
        "پرونده گپ": 7,
        "مدیاویکی": 8,
        "مدیاویکی گپ": 9,
        "شابلون": 10,
        "شابلون گپ": 11,
        "رانما": 12,
        "رانما گپ": 13,
        "رج": 14,
        "رج گپ": 15,
        "پورتال": 100,
        "پورتال گپ": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "ماژول": 828,
        "ماژول گپ": 829,
        "گجت": 2300,
        "گجت گپ": 2301,
        "گجت توضیحات": 2302,
        "گجت توضیحات گپ": 2303,
    },
    "na": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "nah": {
        "Mēdiatl": -2,
        "Nōncuahquīzqui": -1,
        "Tēixnāmiquiliztli": 1,
        "Tlatequitiltilīlli": 2,
        "Tlatequitiltilīlli tēixnāmiquiliztli": 3,
        "Huiquipedia": 4,
        "Huiquipedia tēixnāmiquiliztli": 5,
        "Īxiptli": 6,
        "Īxiptli tēixnāmiquiliztli": 7,
        "Huiquimedia": 8,
        "Huiquimedia tēixnāmiquiliztli": 9,
        "Nemachiyōtīlli": 10,
        "Nemachiyōtīlli tēixnāmiquiliztli": 11,
        "Tēpalēhuiliztli": 12,
        "Tēpalēhuiliztli tēixnāmiquiliztli": 13,
        "Neneuhcāyōtl": 14,
        "Neneuhcāyōtl tēixnāmiquiliztli": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo discusión": 829,
        "Accesorio": 2300,
        "Accesorio discusión": 2301,
        "Accesorio definición": 2302,
        "Accesorio definición discusión": 2303,
    },
    "nap": {
        "Media": -2,
        "Speciàle": -1,
        "Chiàcchiera": 1,
        "Utente": 2,
        "Utente chiàcchiera": 3,
        "Wikipedia": 4,
        "Wikipedia chiàcchiera": 5,
        "Fiùra": 6,
        "Fiùra chiàcchiera": 7,
        "MediaWiki": 8,
        "MediaWiki chiàcchiera": 9,
        "Modello": 10,
        "Modello chiàcchiera": 11,
        "Ajùto": 12,
        "Ajùto chiàcchiera": 13,
        "Categurìa": 14,
        "Categurìa chiàcchiera": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Modulo chiàcchiera": 829,
        "Pazziella": 2300,
        "Pazziella chiàcchiera": 2301,
        "Pazziella definizzione": 2302,
        "Pazziella definizzione chiàcchiera": 2303,
    },
    "nds": {
        "Media": -2,
        "Spezial": -1,
        "Diskuschoon": 1,
        "Bruker": 2,
        "Bruker Diskuschoon": 3,
        "Wikipedia": 4,
        "Wikipedia Diskuschoon": 5,
        "Bild": 6,
        "Bild Diskuschoon": 7,
        "MediaWiki": 8,
        "MediaWiki Diskuschoon": 9,
        "Vörlaag": 10,
        "Vörlaag Diskuschoon": 11,
        "Hülp": 12,
        "Hülp Diskuschoon": 13,
        "Kategorie": 14,
        "Kategorie Diskuschoon": 15,
        "Portal": 100,
        "Portal Diskuschoon": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussion": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "nds-nl": {
        "Media": -2,
        "Spesiaal": -1,
        "Overleg": 1,
        "Gebruker": 2,
        "Overleg gebruker": 3,
        "Wikipedia": 4,
        "Overleg Wikipedia": 5,
        "Bestaand": 6,
        "Overleg bestaand": 7,
        "MediaWiki": 8,
        "Overleg MediaWiki": 9,
        "Mal": 10,
        "Overleg mal": 11,
        "Hulpe": 12,
        "Overleg hulpe": 13,
        "Kategorie": 14,
        "Overleg kategorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Overleg module": 829,
        "Uitbreiding": 2300,
        "Overleg uitbreiding": 2301,
        "Uitbreidingsdefinitie": 2302,
        "Overleg uitbreidingsdefinitie": 2303,
    },
    "ne": {
        "मीडिया": -2,
        "विशेष": -1,
        "वार्तालाप": 1,
        "प्रयोगकर्ता": 2,
        "प्रयोगकर्ता वार्ता": 3,
        "विकिपिडिया": 4,
        "विकिपिडिया वार्ता": 5,
        "चित्र": 6,
        "चित्र वार्ता": 7,
        "मीडियाविकि": 8,
        "मीडियाविकि वार्ता": 9,
        "ढाँचा": 10,
        "ढाँचा वार्ता": 11,
        "मद्दत": 12,
        "मद्दत वार्ता": 13,
        "श्रेणी": 14,
        "श्रेणी वार्ता": 15,
        "पोर्टल": 100,
        "पोर्टल वार्ता": 101,
        "मस्यौदा": 118,
        "मस्यौदा वार्ता": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "मोड्युल": 828,
        "मोड्युल वार्तालाप": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "new": {
        "माध्यम": -2,
        "विशेष": -1,
        "खँलाबँला": 1,
        "छ्येलेमि": 2,
        "छ्येलेमि खँलाबँला": 3,
        "विकिपिडिया": 4,
        "विकिपिडिया खँलाबँला": 5,
        "किपा": 6,
        "किपा खँलाबँला": 7,
        "मिडियाविकि": 8,
        "मिडियाविकि खँलाबँला": 9,
        "Template": 10,
        "Template talk": 11,
        "ग्वाहालि": 12,
        "ग्वाहालि खँलाबँला": 13,
        "पुचः": 14,
        "पुचः खँलाबँला": 15,
        "दबू": 100,
        "दबू खँलाबँला": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "nia": {
        "Media": -2,
        "Si tohude": -1,
        "Huhuo": 1,
        "Sangoguna": 2,
        "Huhuo zangoguna": 3,
        "Wikipedia": 4,
        "Huhuo Wikipedia": 5,
        "Berkas": 6,
        "Huhuo berkas": 7,
        "MediaWiki": 8,
        "Huhuo MediaWiki": 9,
        "Templat": 10,
        "Huhuo templat": 11,
        "Fanolo": 12,
        "Huhuo wanolo": 13,
        "Kategori": 14,
        "Huhuo kategori": 15,
        "Portal": 100,
        "Huhuo portal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pembicaraan Modul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "nl": {
        "Media": -2,
        "Speciaal": -1,
        "Overleg": 1,
        "Gebruiker": 2,
        "Overleg gebruiker": 3,
        "Wikipedia": 4,
        "Overleg Wikipedia": 5,
        "Bestand": 6,
        "Overleg bestand": 7,
        "MediaWiki": 8,
        "Overleg MediaWiki": 9,
        "Sjabloon": 10,
        "Overleg sjabloon": 11,
        "Help": 12,
        "Overleg help": 13,
        "Categorie": 14,
        "Overleg categorie": 15,
        "Portaal": 100,
        "Overleg portaal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Overleg module": 829,
        "Uitbreiding": 2300,
        "Overleg uitbreiding": 2301,
        "Uitbreidingsdefinitie": 2302,
        "Overleg uitbreidingsdefinitie": 2303,
    },
    "nn": {
        "Filpeikar": -2,
        "Spesial": -1,
        "Diskusjon": 1,
        "Brukar": 2,
        "Brukardiskusjon": 3,
        "Wikipedia": 4,
        "Wikipedia-diskusjon": 5,
        "Fil": 6,
        "Fildiskusjon": 7,
        "MediaWiki": 8,
        "MediaWiki-diskusjon": 9,
        "Mal": 10,
        "Maldiskusjon": 11,
        "Hjelp": 12,
        "Hjelpdiskusjon": 13,
        "Kategori": 14,
        "Kategoridiskusjon": 15,
        "Tema": 100,
        "Temadiskusjon": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Moduldiskusjon": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "no": {
        "Medium": -2,
        "Spesial": -1,
        "Diskusjon": 1,
        "Bruker": 2,
        "Brukerdiskusjon": 3,
        "Wikipedia": 4,
        "Wikipedia-diskusjon": 5,
        "Fil": 6,
        "Fildiskusjon": 7,
        "MediaWiki": 8,
        "MediaWiki-diskusjon": 9,
        "Mal": 10,
        "Maldiskusjon": 11,
        "Hjelp": 12,
        "Hjelpdiskusjon": 13,
        "Kategori": 14,
        "Kategoridiskusjon": 15,
        "Portal": 100,
        "Portaldiskusjon": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Moduldiskusjon": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Sak": 2600,
    },
    "nov": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "nqo": {
        "ߟߊߛߋߢߊߥߙߍ": -2,
        "ߞߙߍߞߙߍߣߍ߲": -1,
        "ߢߊߝߐߞߣߍ": 1,
        "ߟߊߓߊ߯ߙߟߊ": 2,
        "ߟߊߓߊ߯ߙߟߊ ߟߊ߫ ߢߊߝߐߞߣߍ": 3,
        "ߥߞߌߔߘߋߞߎ": 4,
        "ߥߞߌߔߘߋߞߎ ߢߊߝߐߞߣߍ": 5,
        "ߞߐߕߐ߮": 6,
        "ߞߐߕߐ߮ ߢߊߝߐߞߣߍ": 7,
        "ߡߘߌߦߊߥߞߌ": 8,
        "ߡߘߌߦߊߥߞߌ ߢߊߝߐߞߣߍ": 9,
        "ߞߙߊߞߏ": 10,
        "ߞߙߊߞߏ ߢߊߝߐߞߣߍ": 11,
        "ߡߊ߬ߘߍ߬ߡߍ߲߬ߠߌ߲": 12,
        "ߡߊ߬ߘߍ߬ߡߍ߲߬ߠߌ߲ ߢߊߝߐߞߣߍ": 13,
        "ߦߌߟߡߊ": 14,
        "ߦߌߟߡߊ ߢߊߝߐߞߣߍ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "ߗߋ߬ߞߙߊߞߏ": 828,
        "ߗߋ߬ߞߙߊߞߏ ߢߊߝߐߞߣߍ": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "nrm": {
        "Média": -2,
        "Spécial": -1,
        "Discussion": 1,
        "Utilisateur": 2,
        "Discussion utilisateur": 3,
        "Wikipedia": 4,
        "Discussion Wikipedia": 5,
        "Fichier": 6,
        "Discussion fichier": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèle": 10,
        "Discussion modèle": 11,
        "Aide": 12,
        "Discussion aide": 13,
        "Catégorie": 14,
        "Discussion catégorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "nso": {
        "Media": -2,
        "Special": -1,
        "Bolediša": 1,
        "Mošomi": 2,
        "Boledišana le Mošomi": 3,
        "Wikipedia": 4,
        "Dipolelo tša Wikipedia": 5,
        "Seswantšho": 6,
        "Poledišano ya Seswantšho": 7,
        "MediaWiki": 8,
        "Poledišano ya MediaWiki": 9,
        "Template": 10,
        "Poledišano ya Template": 11,
        "Thušo": 12,
        "Poledišano ya Thušo": 13,
        "Setensele": 14,
        "Poledišano ya Setensele": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "nv": {
        "Media": -2,
        "Special": -1,
        "Naaltsoos baa yáshtiʼ": 1,
        "Choyoołʼįįhí": 2,
        "Choyoołʼįįhí bichʼįʼ yáshtiʼ": 3,
        "Wikiibíídiiya": 4,
        "Wikiibíídiiya baa yáshtiʼ": 5,
        "Eʼelyaaígíí": 6,
        "Eʼelyaaígíí baa yáshtiʼ": 7,
        "MediaWiki": 8,
        "MediaWiki baa yáshtiʼ": 9,
        "Bee álnééhí": 10,
        "Bee álnééhí baa yáshtiʼ": 11,
        "Anáʼálwoʼ": 12,
        "Anáʼálwoʼ baa yáshtiʼ": 13,
        "Tʼááłáhági átʼéego": 14,
        "Tʼááłáhági átʼéego baa yáshtiʼ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ny": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "oc": {
        "Mèdia": -2,
        "Especial": -1,
        "Discutir": 1,
        "Utilizaire": 2,
        "Discussion Utilizaire": 3,
        "Wikipèdia": 4,
        "Discussion Wikipèdia": 5,
        "Fichièr": 6,
        "Discussion Fichièr": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèl": 10,
        "Discussion Modèl": 11,
        "Ajuda": 12,
        "Discussion Ajuda": 13,
        "Categoria": 14,
        "Discussion Categoria": 15,
        "Portal": 100,
        "Discussion Portal": 101,
        "Projècte": 102,
        "Discussion Projècte": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Mòdul": 828,
        "Mòdul Discussió": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "olo": {
        "Medii": -2,
        "Erikoine": -1,
        "Pagin": 1,
        "Käyttäi": 2,
        "Käyttäi pagin": 3,
        "Wikipedii": 4,
        "Wikipedien paginat": 5,
        "Failu": 6,
        "Failu pagin": 7,
        "MediiWiki": 8,
        "MediiWiki pagin": 9,
        "Šablonu": 10,
        "Šablonu pagin": 11,
        "Abu": 12,
        "Abu pagin": 13,
        "Kategourii": 14,
        "Kategourii pagin": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Moduuli": 828,
        "Keskustelu moduulista": 829,
        "Pienoisohjelma": 2300,
        "Keskustelu pienoisohjelmasta": 2301,
        "Pienoisohjelman määritys": 2302,
        "Keskustelu pienoisohjelman määrityksestä": 2303,
    },
    "om": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "or": {
        "ମାଧ୍ୟମ": -2,
        "ବିଶେଷ": -1,
        "ଆଲୋଚନା": 1,
        "ବ୍ୟବହାରକାରୀ": 2,
        "ବ୍ୟବହାରକାରୀଙ୍କ ଆଲୋଚନା": 3,
        "ଉଇକିପିଡ଼ିଆ": 4,
        "ଉଇକିପିଡ଼ିଆ ଆଲୋଚନା": 5,
        "ଫାଇଲ": 6,
        "ଫାଇଲ ଆଲୋଚନା": 7,
        "ମିଡ଼ିଆଉଇକି": 8,
        "ମିଡ଼ିଆଉଇକି ଆଲୋଚନା": 9,
        "ଛାଞ୍ଚ": 10,
        "ଛାଞ୍ଚ ଆଲୋଚନା": 11,
        "ସହଯୋଗ": 12,
        "ସହଯୋଗ ଆଲୋଚନା": 13,
        "ଶ୍ରେଣୀ": 14,
        "ଶ୍ରେଣୀ ଆଲୋଚନା": 15,
        "ପୋର୍ଟାଲ": 100,
        "ପୋର୍ଟାଲ ଆଲୋଚନା": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "ମଡ୍ୟୁଲ": 828,
        "ମଡ୍ୟୁଲ ଆଲୋଚନା": 829,
        "ଗ୍ୟାଜେଟ": 2300,
        "ଗ୍ୟାଜେଟ ଆଲୋଚନା": 2301,
        "ଗ୍ୟାଜେଟ ସଂଜ୍ଞା": 2302,
        "ଗ୍ୟାଜେଟ ସଂଜ୍ଞା ଆଲୋଚନା": 2303,
        "ବିଷୟ": 2600,
    },
    "os": {
        "Медиа": -2,
        "Сæрмагонд": -1,
        "Тæрхон": 1,
        "Архайæг": 2,
        "Архайæджы ныхас": 3,
        "Википеди": 4,
        "Википедийы тæрхон": 5,
        "Файл": 6,
        "Файлы тæрхон": 7,
        "MediaWiki": 8,
        "MediaWiki-йы тæрхон": 9,
        "Хуызæг": 10,
        "Хуызæджы тæрхон": 11,
        "Æххуыс": 12,
        "Æххуысы тæрхон": 13,
        "Категори": 14,
        "Категорийы тæрхон": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "pa": {
        "ਮੀਡੀਆ": -2,
        "ਖ਼ਾਸ": -1,
        "ਗੱਲ-ਬਾਤ": 1,
        "ਵਰਤੋਂਕਾਰ": 2,
        "ਵਰਤੋਂਕਾਰ ਗੱਲ-ਬਾਤ": 3,
        "ਵਿਕੀਪੀਡੀਆ": 4,
        "ਵਿਕੀਪੀਡੀਆ ਗੱਲ-ਬਾਤ": 5,
        "ਤਸਵੀਰ": 6,
        "ਤਸਵੀਰ ਗੱਲ-ਬਾਤ": 7,
        "ਮੀਡੀਆਵਿਕੀ": 8,
        "ਮੀਡੀਆਵਿਕੀ ਗੱਲ-ਬਾਤ": 9,
        "ਫਰਮਾ": 10,
        "ਫਰਮਾ ਗੱਲ-ਬਾਤ": 11,
        "ਮਦਦ": 12,
        "ਮਦਦ ਗੱਲ-ਬਾਤ": 13,
        "ਸ਼੍ਰੇਣੀ": 14,
        "ਸ਼੍ਰੇਣੀ ਗੱਲ-ਬਾਤ": 15,
        "ਫਾਟਕ": 100,
        "ਫਾਟਕ ਗੱਲ-ਬਾਤ": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "ਮੌਡਿਊਲ": 828,
        "ਮੌਡਿਊਲ ਗੱਲ-ਬਾਤ": 829,
        "ਗੈਜਟ": 2300,
        "ਗੈਜਟ ਗੱਲ-ਬਾਤ": 2301,
        "ਗੈਜਟ ਪਰਿਭਾਸ਼ਾ": 2302,
        "ਗੈਜਟ ਪਰਿਭਾਸ਼ਾ ਗੱਲ-ਬਾਤ": 2303,
        "Topic": 2600,
    },
    "pag": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "pam": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "pap": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "pcd": {
        "Média": -2,
        "Spécial": -1,
        "Discussion": 1,
        "Utilisateur": 2,
        "Discussion utilisateur": 3,
        "Wikipedia": 4,
        "Discussion Wikipedia": 5,
        "Fichier": 6,
        "Discussion fichier": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèle": 10,
        "Discussion modèle": 11,
        "Aide": 12,
        "Discussion aide": 13,
        "Catégorie": 14,
        "Discussion catégorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "pdc": {
        "Medium": -2,
        "Spezial": -1,
        "Dischbedutt": 1,
        "Yuuser": 2,
        "Yuuser Dischbedutt": 3,
        "Wikipedia": 4,
        "Wikipedia Dischbedutt": 5,
        "Feil": 6,
        "Feil Dischbedutt": 7,
        "MediaWiki": 8,
        "MediaWiki Dischbedutt": 9,
        "Moddel": 10,
        "Moddel Dischbedutt": 11,
        "Hilf": 12,
        "Hilf Dischbedutt": 13,
        "Abdeeling": 14,
        "Abdeeling Dischbedutt": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussion": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "pfl": {
        "Medium": -2,
        "Schbezial": -1,
        "Babble": 1,
        "Middawaida": 2,
        "Middawaida Dischbediere": 3,
        "Wikipedia": 4,
        "Wikipedia Dischbediere": 5,
        "Dadai": 6,
        "Dadai Dischbediere": 7,
        "MediaWiki": 8,
        "MediaWiki Dischbediere": 9,
        "Vorlach": 10,
        "Vorlach Dischbediere": 11,
        "Hilf": 12,
        "Hilf Dischbediere": 13,
        "Sachgrubb": 14,
        "Sachgrubb Dischbediere": 15,
        "Portal": 100,
        "Portal Diskussion": 101,
        "Buch": 102,
        "Buch Dischbediere": 103,
        "Wort": 104,
        "Wort Dischbediere": 105,
        "Text": 106,
        "Text Dischbediere": 107,
        "Spruch": 108,
        "Spruch Dischbediere": 109,
        "Nochricht": 110,
        "Nochricht Dischbediere": 111,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussion": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "pi": {
        "मीडिया": -2,
        "विसेस": -1,
        "सम्भासित": 1,
        "अवयव": 2,
        "अवयव सम्भासित": 3,
        "Wikipedia": 4,
        "Wikipedia सम्भासित": 5,
        "पटिमा": 6,
        "पटिमा सम्भासित": 7,
        "मीडियाविकि": 8,
        "मीडियाविकि सम्भासित": 9,
        "पटिरूप": 10,
        "पटिरूप सम्भासित": 11,
        "अवस्सय": 12,
        "अवस्सय सम्भासित": 13,
        "विभाग": 14,
        "विभाग सम्भासित": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "pih": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "pl": {
        "Media": -2,
        "Specjalna": -1,
        "Dyskusja": 1,
        "Wikipedysta": 2,
        "Dyskusja wikipedysty": 3,
        "Wikipedia": 4,
        "Dyskusja Wikipedii": 5,
        "Plik": 6,
        "Dyskusja pliku": 7,
        "MediaWiki": 8,
        "Dyskusja MediaWiki": 9,
        "Szablon": 10,
        "Dyskusja szablonu": 11,
        "Pomoc": 12,
        "Dyskusja pomocy": 13,
        "Kategoria": 14,
        "Dyskusja kategorii": 15,
        "Portal": 100,
        "Dyskusja portalu": 101,
        "Wikiprojekt": 102,
        "Dyskusja wikiprojektu": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Moduł": 828,
        "Dyskusja modułu": 829,
        "Gadżet": 2300,
        "Dyskusja gadżetu": 2301,
        "Definicja gadżetu": 2302,
        "Dyskusja definicji gadżetu": 2303,
        "Wątek": 2600,
    },
    "pms": {
        "Media": -2,
        "Special": -1,
        "Discussion": 1,
        "Utent": 2,
        "Ciaciarade": 3,
        "Wikipedia": 4,
        "Discussion ant sla Wikipedia": 5,
        "Figura": 6,
        "Discussion dla figura": 7,
        "MediaWiki": 8,
        "Discussion dla MediaWiki": 9,
        "Stamp": 10,
        "Discussion dlë stamp": 11,
        "Agiut": 12,
        "Discussion ant sl'agiut": 13,
        "Categorìa": 14,
        "Discussion ant sla categorìa": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Discussioni modulo": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "pnb": {
        "میڈیا": -2,
        "خاص": -1,
        "گل بات": 1,
        "ورتنوالا": 2,
        "ورتن گل بات": 3,
        "وکیپیڈیا": 4,
        "ویونت گل بات": 5,
        "فائل": 6,
        "فائل گل بات": 7,
        "میڈیا وکی": 8,
        "میڈیاوکی گل بات": 9,
        "سانچہ": 10,
        "سانچہ گل بات": 11,
        "ہتھونڈائی": 12,
        "ہتھونڈائی گل بات": 13,
        "گٹھ": 14,
        "گٹھ گل بات": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "ماڈیول": 828,
        "ماڈیول گل بات": 829,
        "آلہ": 2300,
        "آلہ گل بات": 2301,
        "آلہ تعریف": 2302,
        "آلہ تعریف گل بات": 2303,
    },
    "pnt": {
        "Μέσον": -2,
        "Ειδικόν": -1,
        "Καλάτσεμαν": 1,
        "Χρήστες": 2,
        "Καλάτσεμαν χρήστε": 3,
        "Βικιπαίδεια": 4,
        "Βικιπαίδεια καλάτσεμαν": 5,
        "Αρχείον": 6,
        "Καλάτσεμαν αρχείονος": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Πρότυπον": 10,
        "Καλάτσεμαν πρότυπι": 11,
        "Βοήθειαν": 12,
        "Καλάτσεμαν βοήθειας": 13,
        "Κατηγορίαν": 14,
        "Καλάτσεμαν κατηγορίας": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ps": {
        "رسنۍ": -2,
        "ځانگړی": -1,
        "خبرې اترې": 1,
        "کارن": 2,
        "د کارن خبرې اترې": 3,
        "ويکيپېډيا": 4,
        "د ويکيپېډيا خبرې اترې": 5,
        "دوتنه": 6,
        "د دوتنې خبرې اترې": 7,
        "ميډياويکي": 8,
        "د ميډياويکي خبرې اترې": 9,
        "کينډۍ": 10,
        "د کينډۍ خبرې اترې": 11,
        "لارښود": 12,
        "د لارښود خبرې اترې": 13,
        "وېشنيزه": 14,
        "د وېشنيزې خبرې اترې": 15,
        "تانبه": 100,
        "د تانبې خبرې اترې": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "pt": {
        "Multimédia": -2,
        "Especial": -1,
        "Discussão": 1,
        "Usuário(a)": 2,
        "Usuário(a) Discussão": 3,
        "Wikipédia": 4,
        "Wikipédia Discussão": 5,
        "Ficheiro": 6,
        "Ficheiro Discussão": 7,
        "MediaWiki": 8,
        "MediaWiki Discussão": 9,
        "Predefinição": 10,
        "Predefinição Discussão": 11,
        "Ajuda": 12,
        "Ajuda Discussão": 13,
        "Categoria": 14,
        "Categoria Discussão": 15,
        "Portal": 100,
        "Portal Discussão": 101,
        "Livro": 104,
        "Livro Discussão": 105,
        "Education Program": 446,
        "Education Program talk": 447,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo Discussão": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Tópico": 2600,
    },
    "pwn": {
        "mitiya": -2,
        "pinakisumaljiyan": -1,
        "kakaljavaran": 1,
        "avan a kipakamanguanguaq": 2,
        "kipakamanguanguaq kakaljavaran": 3,
        "Wikipedia": 4,
        "Wikipedia kakaljavaran": 5,
        "sineqetj a vecik": 6,
        "sineqetj a vecik kakaljavaran": 7,
        "MediaWiki": 8,
        "MediaWiki kakaljavaran": 9,
        "kakivauvaljan": 10,
        "kakivauvaljan kakaljavaran": 11,
        "remasudj": 12,
        "remasudj kakaljavaran": 13,
        "pinapapilipiliqan": 14,
        "pinapapilipiliqan kakaljavaran": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "qu": {
        "Midya": -2,
        "Sapaq": -1,
        "Rimanakuy": 1,
        "Ruraq": 2,
        "Ruraq rimanakuy": 3,
        "Wikipedia": 4,
        "Wikipedia rimanakuy": 5,
        "Rikcha": 6,
        "Rikcha rimanakuy": 7,
        "MediaWiki": 8,
        "MediaWiki rimanakuy": 9,
        "Plantilla": 10,
        "Plantilla rimanakuy": 11,
        "Yanapa": 12,
        "Yanapa rimanakuy": 13,
        "Katiguriya": 14,
        "Katiguriya rimanakuy": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo discusión": 829,
        "Accesorio": 2300,
        "Accesorio discusión": 2301,
        "Accesorio definición": 2302,
        "Accesorio definición discusión": 2303,
    },
    "rm": {
        "Multimedia": -2,
        "Spezial": -1,
        "Discussiun": 1,
        "Utilisader": 2,
        "Utilisader discussiun": 3,
        "Wikipedia": 4,
        "Wikipedia discussiun": 5,
        "Datoteca": 6,
        "Datoteca discussiun": 7,
        "MediaWiki": 8,
        "MediaWiki discussiun": 9,
        "Model": 10,
        "Model discussiun": 11,
        "Agid": 12,
        "Agid discussiun": 13,
        "Categoria": 14,
        "Categoria discussiun": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "rmy": {
        "Mediya": -2,
        "Uzalutno": -1,
        "Vakyarimata": 1,
        "Jeno": 2,
        "Jeno vakyarimata": 3,
        "Vikipidiya": 4,
        "Vikipidiyake vakyarimata": 5,
        "Chitro": 6,
        "Chitro vakyarimata": 7,
        "MediyaViki": 8,
        "MediyaViki vakyarimata": 9,
        "Sikavno": 10,
        "Sikavno vakyarimata": 11,
        "Zhutipen": 12,
        "Zhutipen vakyarimata": 13,
        "Shopni": 14,
        "Shopni vakyarimata": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Discuție Modul": 829,
        "Gadget": 2300,
        "Discuție Gadget": 2301,
        "Definiție gadget": 2302,
        "Discuție Definiție gadget": 2303,
    },
    "rn": {
        "Media": -2,
        "Vyisangije": -1,
        "Ikiyago": 1,
        "Uwukoresha": 2,
        "Ikiyago c'uwukoresha": 3,
        "Wikipedia": 4,
        "Ikiyago kuri Wikipedia": 5,
        "Dosiye": 6,
        "Ikiyago kw'idosiye": 7,
        "MediaWiki": 8,
        "Ikiyago kuri MediaWiki": 9,
        "Ingero": 10,
        "Ikiyago cerekeye ingero": 11,
        "Ubufasha": 12,
        "Ikiyago k'ubufasha": 13,
        "Umuce": 14,
        "Ikiyago cerekeye umuce": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ro": {
        "Media": -2,
        "Special": -1,
        "Discuție": 1,
        "Utilizator": 2,
        "Discuție Utilizator": 3,
        "Wikipedia": 4,
        "Discuție Wikipedia": 5,
        "Fișier": 6,
        "Discuție Fișier": 7,
        "MediaWiki": 8,
        "Discuție MediaWiki": 9,
        "Format": 10,
        "Discuție Format": 11,
        "Ajutor": 12,
        "Discuție Ajutor": 13,
        "Categorie": 14,
        "Discuție Categorie": 15,
        "Portal": 100,
        "Discuţie Portal": 101,
        "Proiect": 102,
        "Discuţie Proiect": 103,
        "Cod": 108,
        "Discuție Cod": 109,
        "Carte": 110,
        "Discuţie Carte": 111,
        "Campaign": 460,
        "Campaign talk": 461,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Discuție Modul": 829,
        "Gadget": 2300,
        "Discuție Gadget": 2301,
        "Definiție gadget": 2302,
        "Discuție Definiție gadget": 2303,
    },
    "roa-rup": {
        "Media": -2,
        "Special": -1,
        "Discuție": 1,
        "Utilizator": 2,
        "Discuție Utilizator": 3,
        "Wikipedia": 4,
        "Discuție Wikipedia": 5,
        "Fișier": 6,
        "Discuție Fișier": 7,
        "MediaWiki": 8,
        "Discuție MediaWiki": 9,
        "Format": 10,
        "Discuție Format": 11,
        "Ajutor": 12,
        "Discuție Ajutor": 13,
        "Categorie": 14,
        "Discuție Categorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Discuție Modul": 829,
        "Gadget": 2300,
        "Discuție Gadget": 2301,
        "Definiție gadget": 2302,
        "Discuție Definiție gadget": 2303,
    },
    "roa-tara": {
        "Media": -2,
        "Speciale": -1,
        "Discussione": 1,
        "Utente": 2,
        "Discussioni utente": 3,
        "Wikipedia": 4,
        "Discussioni Wikipedia": 5,
        "File": 6,
        "Discussioni file": 7,
        "MediaWiki": 8,
        "Discussioni MediaWiki": 9,
        "Template": 10,
        "Discussioni template": 11,
        "Aiuto": 12,
        "Discussioni aiuto": 13,
        "Categoria": 14,
        "Discussioni categoria": 15,
        "Portale": 100,
        "'Ngazzaminde d'u Portale": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Discussioni modulo": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "ru": {
        "Медиа": -2,
        "Служебная": -1,
        "Обсуждение": 1,
        "Участник": 2,
        "Обсуждение участника": 3,
        "Википедия": 4,
        "Обсуждение Википедии": 5,
        "Файл": 6,
        "Обсуждение файла": 7,
        "MediaWiki": 8,
        "Обсуждение MediaWiki": 9,
        "Шаблон": 10,
        "Обсуждение шаблона": 11,
        "Справка": 12,
        "Обсуждение справки": 13,
        "Категория": 14,
        "Обсуждение категории": 15,
        "Портал": 100,
        "Обсуждение портала": 101,
        "Инкубатор": 102,
        "Обсуждение Инкубатора": 103,
        "Проект": 104,
        "Обсуждение проекта": 105,
        "Арбитраж": 106,
        "Обсуждение арбитража": 107,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "rue": {
        "Медіа": -2,
        "Шпеціална": -1,
        "Діскузія": 1,
        "Хоснователь": 2,
        "Діскузія з хоснователём": 3,
        "Вікіпедія": 4,
        "Діскузія ку Вікіпедії": 5,
        "Файл": 6,
        "Діскузія ку файлу": 7,
        "MediaWiki": 8,
        "Діскузія ку MediaWiki": 9,
        "Шаблона": 10,
        "Діскузія ку шаблонї": 11,
        "Поміч": 12,
        "Діскузія ку помочі": 13,
        "Катеґорія": 14,
        "Діскузія ку катеґорії": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обговорення модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "rw": {
        "Itangazamakuru": -2,
        "Ibidasanzwe": -1,
        "Ibiganiro": 1,
        "Umukoresha": 2,
        "Ibiganiro by'umukoresha": 3,
        "Wikipedia": 4,
        "Ibiganiro kuri Wikipedia": 5,
        "Dosiye": 6,
        "Ibiganiro kuri dosiye": 7,
        "MediyaWiki": 8,
        "Ibiganiro kuri MediyaWiki": 9,
        "Inyandikorugero": 10,
        "Ibiganiro ku nyandikorugero": 11,
        "Ubufasha": 12,
        "Ibiganiro ku bufasha": 13,
        "Ikiciro": 14,
        "Ibiganiro ku byiciro": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "sa": {
        "माध्यमम्": -2,
        "विशेषः": -1,
        "सम्भाषणम्": 1,
        "सदस्यः": 2,
        "सदस्यसम्भाषणम्": 3,
        "विकिपीडिया": 4,
        "विकिपीडियासम्भाषणम्": 5,
        "सञ्चिका": 6,
        "सञ्चिकासम्भाषणम्": 7,
        "मीडियाविकि": 8,
        "मीडियाविकिसम्भाषणम्": 9,
        "फलकम्": 10,
        "फलकसम्भाषणम्": 11,
        "साहाय्यम्": 12,
        "साहाय्यसम्भाषणम्": 13,
        "वर्गः": 14,
        "वर्गसम्भाषणम्": 15,
        "प्रवेशद्वारम्": 100,
        "प्रवेशद्वारसम्भाषणम्": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "पटलम्": 828,
        "पटलसम्भाषणम्": 829,
        "गैजेट": 2300,
        "गैजेट वार्ता": 2301,
        "गैजेट परिभाषा": 2302,
        "गैजेट परिभाषा वार्ता": 2303,
    },
    "sah": {
        "Миэдьийэ": -2,
        "Аналлаах": -1,
        "Ырытыы": 1,
        "Кыттааччы": 2,
        "Кыттааччы ырытыыта": 3,
        "Бикипиэдьийэ": 4,
        "Бикипиэдьийэ ырытыыта": 5,
        "Билэ": 6,
        "Билэ ырытыыта": 7,
        "MediaWiki": 8,
        "MediaWiki-ни ырытыы": 9,
        "Халыып": 10,
        "Халыыбы ырытыы": 11,
        "Көмө": 12,
        "Көмөнү ырытыы": 13,
        "Категория": 14,
        "Категорияны ырытыы": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "sat": {
        "ᱢᱤᱰᱤᱭᱟ": -2,
        "ᱟᱥᱚᱠᱟᱭ": -1,
        "ᱜᱟᱞᱢᱟᱨᱟᱣ": 1,
        "ᱵᱮᱵᱷᱟᱨᱤᱭᱟᱹ": 2,
        "ᱵᱮᱵᱷᱟᱨᱤᱭᱟᱹ ᱜᱟᱞᱢᱟᱨᱟᱣ": 3,
        "ᱣᱤᱠᱤᱯᱤᱰᱤᱭᱟ": 4,
        "ᱣᱤᱠᱤᱯᱤᱰᱤᱭᱟ ᱨᱚᱲ": 5,
        "ᱨᱮᱫ": 6,
        "ᱨᱮᱫ ᱜᱟᱞᱢᱟᱨᱟᱣ": 7,
        "ᱢᱤᱰᱤᱭᱟᱣᱤᱠᱤ": 8,
        "ᱢᱤᱰᱤᱭᱟᱣᱤᱠᱤ ᱜᱟᱞᱢᱟᱨᱟᱣ": 9,
        "ᱪᱷᱟᱸᱪ": 10,
        "ᱪᱷᱟᱸᱪ ᱜᱟᱞᱢᱟᱨᱟᱣ": 11,
        "ᱜᱚᱸᱲᱚᱸ": 12,
        "ᱜᱚᱸᱲᱚᱸ ᱜᱟᱞᱢᱟᱨᱟᱣ": 13,
        "ᱛᱷᱚᱠ": 14,
        "ᱛᱷᱚᱠ ᱜᱟᱞᱢᱟᱨᱟᱣ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "ᱢᱳᱰᱩᱞ": 828,
        "ᱢᱳᱰᱩᱞ ᱜᱟᱞᱢᱟᱨᱟᱣ": 829,
        "ᱥᱟᱢᱟᱱᱚᱢ": 2300,
        "ᱥᱟᱢᱟᱱᱚᱢ ᱜᱟᱞᱢᱟᱨᱟᱣ": 2301,
        "ᱥᱟᱢᱟᱱᱚᱢ ᱢᱮᱱᱮᱛᱮᱫ": 2302,
        "ᱥᱟᱢᱟᱱᱚᱢ ᱢᱮᱱᱮᱛᱮᱫ ᱜᱟᱞᱢᱟᱨᱟᱣ": 2303,
    },
    "sc": {
        "Media": -2,
        "Ispetziale": -1,
        "Cuntierra": 1,
        "Usuàriu": 2,
        "Cuntierra usuàriu": 3,
        "Wikipedia": 4,
        "Cuntierra Wikipedia": 5,
        "File": 6,
        "Cuntierra file": 7,
        "MediaWiki": 8,
        "Cuntierra MediaWiki": 9,
        "Template": 10,
        "Cuntierra template": 11,
        "Agiudu": 12,
        "Cuntierra agiudu": 13,
        "Categoria": 14,
        "Cuntierra categoria": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "scn": {
        "Mèdia": -2,
        "Spiciali": -1,
        "Discussioni": 1,
        "Utenti": 2,
        "Discussioni utenti": 3,
        "Wikipedia": 4,
        "Discussioni Wikipedia": 5,
        "File": 6,
        "Discussioni file": 7,
        "MediaWiki": 8,
        "Discussioni MediaWiki": 9,
        "Template": 10,
        "Discussioni template": 11,
        "Aiutu": 12,
        "Discussioni aiutu": 13,
        "Catigurìa": 14,
        "Discussioni catigurìa": 15,
        "Purtali": 100,
        "Discussioni purtali": 101,
        "Pruggettu": 102,
        "Discussioni pruggettu": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Mòdulu": 828,
        "Discussioni mòdulu": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "sco": {
        "Media": -2,
        "Special": -1,
        "Collogue": 1,
        "Uiser": 2,
        "Uiser collogue": 3,
        "Wikipedia": 4,
        "Wikipedia collogue": 5,
        "File": 6,
        "File collogue": 7,
        "MediaWiki": 8,
        "MediaWiki collogue": 9,
        "Template": 10,
        "Template collogue": 11,
        "Help": 12,
        "Help collogue": 13,
        "Category": 14,
        "Category collogue": 15,
        "Portal": 100,
        "Portal talk": 101,
        "Define": 102,
        "Define talk": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "sd": {
        "ذريعات": -2,
        "خاص": -1,
        "بحث": 1,
        "واپرائيندڙ": 2,
        "واپرائيندڙ بحث": 3,
        "وڪيپيڊيا": 4,
        "وڪيپيڊيا بحث": 5,
        "فائل": 6,
        "فائل بحث": 7,
        "ذريعات وڪي": 8,
        "ذريعات وڪي بحث": 9,
        "سانچو": 10,
        "سانچو بحث": 11,
        "مدد": 12,
        "مدد بحث": 13,
        "زمرو": 14,
        "زمرو بحث": 15,
        "باب": 100,
        "باب بحث": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "ماڊيول": 828,
        "ماڊيول بحث": 829,
        "گيجيٽ": 2300,
        "گيجيٽ بحث": 2301,
        "گيجيٽ وصف": 2302,
        "گيجيٽ وصف بحث": 2303,
    },
    "se": {
        "Media": -2,
        "Erenoamáš": -1,
        "Ságastallan": 1,
        "Geavaheaddji": 2,
        "Geavaheaddjeságastallan": 3,
        "Wikipedia": 4,
        "Wikipedia-ságastallan": 5,
        "Fiila": 6,
        "Fiilaságastallan": 7,
        "MediaWiki": 8,
        "MediaWiki-ságastallan": 9,
        "Málle": 10,
        "Málleságastallan": 11,
        "Veahkki": 12,
        "Veahkkeságastallan": 13,
        "Kategoriija": 14,
        "Kategoriijaságastallan": 15,
        "Portála": 100,
        "Portálaságastallan": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modula": 828,
        "Modulaságastallan": 829,
        "Pienoisohjelma": 2300,
        "Keskustelu pienoisohjelmasta": 2301,
        "Pienoisohjelman määritys": 2302,
        "Keskustelu pienoisohjelman määrityksestä": 2303,
    },
    "sg": {
        "Média": -2,
        "Spécial": -1,
        "Discussion": 1,
        "Utilisateur": 2,
        "Discussion utilisateur": 3,
        "Wikipedia": 4,
        "Discussion Wikipedia": 5,
        "Fichier": 6,
        "Discussion fichier": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèle": 10,
        "Discussion modèle": 11,
        "Aide": 12,
        "Discussion aide": 13,
        "Catégorie": 14,
        "Discussion catégorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "sh": {
        "Mediji": -2,
        "Posebno": -1,
        "Razgovor": 1,
        "Korisnik": 2,
        "Razgovor sa korisnikom": 3,
        "Wikipedia": 4,
        "Razgovor o Wikipedia": 5,
        "Datoteka": 6,
        "Razgovor o datoteci": 7,
        "MediaWiki": 8,
        "Mediawiki razgovor": 9,
        "Šablon": 10,
        "Razgovor o šablonu": 11,
        "Pomoć": 12,
        "Razgovor o pomoći": 13,
        "Kategorija": 14,
        "Razgovor o kategoriji": 15,
        "Portal": 100,
        "Razgovor o portalu": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Razgovor o modulu": 829,
        "Spravica": 2300,
        "Razgovor o spravici": 2301,
        "Definicija spravice": 2302,
        "Razgovor o definiciji spravice": 2303,
    },
    "shi": {
        "Midya": -2,
        "Amẓli": -1,
        "Amsawal": 1,
        "Asmras": 2,
        "Amsawal n usmras": 3,
        "Wikipidya": 4,
        "Amsawal n Wikipidya": 5,
        "Afaylu": 6,
        "Amsawal n ufaylu": 7,
        "MidyaWiki": 8,
        "Amsawal n MidyaWiki": 9,
        "Talɣa": 10,
        "Amsawal n talɣa": 11,
        "Tiwisi": 12,
        "Amsawal n twisi": 13,
        "Taggayt": 14,
        "Amsawal n taggayt": 15,
        "Aggur": 100,
        "Amsawal n waggur": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "shn": {
        "သိုဝ်ႇၶၢဝ်ႇ": -2,
        "ၶိုၵ်ႉတွၼ်း": -1,
        "ဢုပ်ႇၵုမ်": 1,
        "ၽူႈၸႂ်ႉတိုဝ်း": 2,
        "ဢုပ်ႇၵုမ် ၽူႈၸႂ်ႉတိုဝ်း": 3,
        "ဝီႇၶီႇၽီးတီးယႃး": 4,
        "ဢုပ်ႇၵုမ် ဝီႇၶီႇၽီးတီးယႃး": 5,
        "ၾၢႆႇ": 6,
        "ဢုပ်ႇၵုမ် ၾၢႆႇ": 7,
        "သိုဝ်ႇၶၢဝ်ႇဝီႇၶီႇ": 8,
        "ဢုပ်ႇၵုမ် သိုဝ်ႇၶၢဝ်ႇဝီႇၶီႇ": 9,
        "ထႅမ်းပလဵၵ်ႉ": 10,
        "ဢုပ်ႇၵုမ် ထႅမ်းပလဵၵ်ႉ": 11,
        "လွင်ႈၸွႆႈထႅမ်": 12,
        "ဢုပ်ႇၵုမ် လွင်ႈၸွႆႈထႅမ်": 13,
        "ပိူင်ထၢၼ်ႈ": 14,
        "ဢုပ်ႇၵုမ် ပိူင်ထၢၼ်ႈ": 15,
        "ၵိူၼ်ႇတူ": 100,
        "တွၼ်ႈဢုပ်ႇ ၵိူၼ်ႇတူ": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "မေႃႇၵျူး": 828,
        "ဢုပ်ႇၵုမ် မေႃႇၵျူး": 829,
        "ၶိူင်ႈပိတ်းပွတ်း": 2300,
        "ဢုပ်ႇၵုမ် ၶိူင်ႈပိတ်းပွတ်း": 2301,
        "ပိုတ်ႇတီႈပွင်ႇ ၶိူင်ႈပိတ်းပွတ်း": 2302,
        "ဢုပ်ႇၵုမ် ပိုတ်ႇတီႈပွင်ႇ ၶိူင်ႈပိတ်းပွတ်း": 2303,
    },
    "si": {
        "මාධ්\u200dයය": -2,
        "විශේෂ": -1,
        "සාකච්ඡාව": 1,
        "පරිශීලක": 2,
        "පරිශීලක සාකච්ඡාව": 3,
        "විකිපීඩියා": 4,
        "විකිපීඩියා සාකච්ඡාව": 5,
        "ගොනුව": 6,
        "ගොනුව සාකච්ඡාව": 7,
        "මාධ්\u200dයවිකි": 8,
        "මාධ්\u200dයවිකි සාකච්ඡාව": 9,
        "සැකිල්ල": 10,
        "සැකිලි සාකච්ඡාව": 11,
        "උදවු": 12,
        "උදවු සාකච්ඡාව": 13,
        "ප්\u200dරවර්ගය": 14,
        "ප්\u200dරවර්ග සාකච්ඡාව": 15,
        "ද්වාරය": 100,
        "ද්වාරය සාකච්ඡාව": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "simple": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "sk": {
        "Médiá": -2,
        "Špeciálne": -1,
        "Diskusia": 1,
        "Redaktor": 2,
        "Diskusia s redaktorom": 3,
        "Wikipédia": 4,
        "Diskusia k Wikipédii": 5,
        "Súbor": 6,
        "Diskusia k súboru": 7,
        "MediaWiki": 8,
        "Diskusia k MediaWiki": 9,
        "Šablóna": 10,
        "Diskusia k šablóne": 11,
        "Pomoc": 12,
        "Diskusia k pomoci": 13,
        "Kategória": 14,
        "Diskusia ku kategórii": 15,
        "Portál": 100,
        "Diskusia k portálu": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Diskusia k modulu": 829,
        "Udělátko": 2300,
        "Diskuse k udělátku": 2301,
        "Definice udělátka": 2302,
        "Diskuse k definici udělátka": 2303,
    },
    "skr": {
        "میڈیا": -2,
        "خاص": -1,
        "ڳالھ مہاڑ": 1,
        "ورتݨ آلا": 2,
        "ورتݨ آلے دی ڳالھ مہاڑ": 3,
        "وکیپیڈیا": 4,
        "وکیپیڈیا ڳالھ مہاڑ": 5,
        "فائل": 6,
        "فائل ڳالھ مہاڑ": 7,
        "میڈیا وکی": 8,
        "میڈیا وکی ڳالھ مہاڑ": 9,
        "سانچہ": 10,
        "سانچہ ڳالھ مہاڑ": 11,
        "مدد": 12,
        "مدد ڳالھ مہاڑ": 13,
        "ونکی": 14,
        "ونکی ڳالھ مہاڑ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "ماڈیول": 828,
        "ماڈیول ڳالھ مہاڑ": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "sl": {
        "Datoteka": -2,
        "Posebno": -1,
        "Pogovor": 1,
        "Uporabnik": 2,
        "Uporabniški pogovor": 3,
        "Wikipedija": 4,
        "Pogovor o Wikipediji": 5,
        "Slika": 6,
        "Pogovor o sliki": 7,
        "MediaWiki": 8,
        "Pogovor o MediaWiki": 9,
        "Predloga": 10,
        "Pogovor o predlogi": 11,
        "Pomoč": 12,
        "Pogovor o pomoči": 13,
        "Kategorija": 14,
        "Pogovor o kategoriji": 15,
        "Portal": 100,
        "Pogovor o portalu": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pogovor o modulu": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "sm": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "smn": {
        "Media": -2,
        "Tooimah": -1,
        "Savâstâllâm": 1,
        "Kevttee": 2,
        "Savâstâllâm kevttest": 3,
        "Wikipedia": 4,
        "Savâstâllâm Wikipedia": 5,
        "Tiätuvuárkká": 6,
        "Savâstâllâm tiätuvuárhást": 7,
        "Systeemviestâ": 8,
        "Savâstâllâm systeemviestâst": 9,
        "Myenster": 10,
        "Savâstâllâm myensterist": 11,
        "Raavâ": 12,
        "Savâstâllâm ravvust": 13,
        "Luokka": 14,
        "Savâstâllâm luokkaast": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Mooduul": 828,
        "Savâstâllâm modulist": 829,
        "Pienoisohjelma": 2300,
        "Keskustelu pienoisohjelmasta": 2301,
        "Pienoisohjelman määritys": 2302,
        "Keskustelu pienoisohjelman määrityksestä": 2303,
    },
    "sn": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "so": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "Portal": 100,
        "Portal talk": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "sq": {
        "Media": -2,
        "Speciale": -1,
        "Diskutim": 1,
        "Përdoruesi": 2,
        "Përdoruesi diskutim": 3,
        "Wikipedia": 4,
        "Wikipedia diskutim": 5,
        "Skeda": 6,
        "Skeda diskutim": 7,
        "MediaWiki": 8,
        "MediaWiki diskutim": 9,
        "Stampa": 10,
        "Stampa diskutim": 11,
        "Ndihmë": 12,
        "Ndihmë diskutim": 13,
        "Kategoria": 14,
        "Kategoria diskutim": 15,
        "Portal": 100,
        "Portal diskutim": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Moduli": 828,
        "Moduli diskutim": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "sr": {
        "Медиј": -2,
        "Посебно": -1,
        "Разговор": 1,
        "Корисник": 2,
        "Разговор са корисником": 3,
        "Википедија": 4,
        "Разговор о Википедији": 5,
        "Датотека": 6,
        "Разговор о датотеци": 7,
        "Медијавики": 8,
        "Разговор о Медијавикију": 9,
        "Шаблон": 10,
        "Разговор о шаблону": 11,
        "Помоћ": 12,
        "Разговор о помоћи": 13,
        "Категорија": 14,
        "Разговор о категорији": 15,
        "Портал": 100,
        "Разговор о порталу": 101,
        "Нацрт": 118,
        "Разговор о нацрту": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модул": 828,
        "Разговор о модулу": 829,
        "Справица": 2300,
        "Разговор о справици": 2301,
        "Дефиниција справице": 2302,
        "Разговор о дефиницији справице": 2303,
    },
    "srn": {
        "Media": -2,
        "Spesyal": -1,
        "Taki": 1,
        "Masyin": 2,
        "Taki fu masyin": 3,
        "Wikipedia": 4,
        "Taki fu Wikipedia": 5,
        "Gefre": 6,
        "Taki fu gefre": 7,
        "MediaWiki": 8,
        "Taki fu MediaWiki": 9,
        "Ankra": 10,
        "Taki fu ankra": 11,
        "Yepi": 12,
        "Taki fu yepi": 13,
        "Guru": 14,
        "Taki fu guru": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Overleg module": 829,
        "Uitbreiding": 2300,
        "Overleg uitbreiding": 2301,
        "Uitbreidingsdefinitie": 2302,
        "Overleg uitbreidingsdefinitie": 2303,
    },
    "ss": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "st": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "stq": {
        "Media": -2,
        "Spezial": -1,
        "Diskussion": 1,
        "Benutser": 2,
        "Benutser Diskussion": 3,
        "Wikipedia": 4,
        "Wikipedia Diskussion": 5,
        "Bielde": 6,
        "Bielde Diskussion": 7,
        "MediaWiki": 8,
        "MediaWiki Diskussion": 9,
        "Foarloage": 10,
        "Foarloage Diskussion": 11,
        "Hälpe": 12,
        "Hälpe Diskussion": 13,
        "Kategorie": 14,
        "Kategorie Diskussion": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Modul Diskussion": 829,
        "Gadget": 2300,
        "Gadget Diskussion": 2301,
        "Gadget-Definition": 2302,
        "Gadget-Definition Diskussion": 2303,
    },
    "su": {
        "Média": -2,
        "Husus": -1,
        "Obrolan": 1,
        "Pamaké": 2,
        "Obrolan pamaké": 3,
        "Wikipedia": 4,
        "Obrolan Wikipedia": 5,
        "Gambar": 6,
        "Obrolan gambar": 7,
        "MédiaWiki": 8,
        "Obrolan MédiaWiki": 9,
        "Citakan": 10,
        "Obrolan citakan": 11,
        "Pitulung": 12,
        "Obrolan pitulung": 13,
        "Kategori": 14,
        "Obrolan kategori": 15,
        "Portal": 100,
        "Obrolan portal": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Pembicaraan Modul": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "sv": {
        "Media": -2,
        "Special": -1,
        "Diskussion": 1,
        "Användare": 2,
        "Användardiskussion": 3,
        "Wikipedia": 4,
        "Wikipediadiskussion": 5,
        "Fil": 6,
        "Fildiskussion": 7,
        "MediaWiki": 8,
        "MediaWiki-diskussion": 9,
        "Mall": 10,
        "Malldiskussion": 11,
        "Hjälp": 12,
        "Hjälpdiskussion": 13,
        "Kategori": 14,
        "Kategoridiskussion": 15,
        "Portal": 100,
        "Portaldiskussion": 101,
        "Education Program": 446,
        "Education Program talk": 447,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modul": 828,
        "Moduldiskussion": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Ämne": 2600,
    },
    "sw": {
        "Media": -2,
        "Maalum": -1,
        "Majadiliano": 1,
        "Mtumiaji": 2,
        "Majadiliano ya mtumiaji": 3,
        "Wikipedia": 4,
        "Majadiliano ya Wikipedia": 5,
        "Faili": 6,
        "Majadiliano ya faili": 7,
        "MediaWiki": 8,
        "Majadiliano ya MediaWiki": 9,
        "Kigezo": 10,
        "Majadiliano ya kigezo": 11,
        "Msaada": 12,
        "Majadiliano ya msaada": 13,
        "Jamii": 14,
        "Majadiliano ya jamii": 15,
        "Lango": 100,
        "Majadiliano ya lango": 101,
        "Wikichanzo": 102,
        "Majadiliano ya Wikichanzo": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "szl": {
        "Media": -2,
        "Szpecyjalna": -1,
        "Dyskusyjo": 1,
        "Używacz": 2,
        "Dyskusyjo używacza": 3,
        "Wikipedyjo": 4,
        "Dyskusyjo Wikipedyjo": 5,
        "Plik": 6,
        "Dyskusyjo plika": 7,
        "MediaWiki": 8,
        "Dyskusyjo MediaWiki": 9,
        "Muster": 10,
        "Dyskusyjo mustra": 11,
        "Půmoc": 12,
        "Dyskusyjo půmocy": 13,
        "Kategoryjo": 14,
        "Dyskusyjo kategoryji": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Moduł": 828,
        "Dyskusja modułu": 829,
        "Gadżet": 2300,
        "Dyskusja gadżetu": 2301,
        "Definicja gadżetu": 2302,
        "Dyskusja definicji gadżetu": 2303,
    },
    "szy": {
        "myiti": -2,
        "sazumaay": -1,
        "sasukamu": 1,
        "misaungayay": 2,
        "pisubelidan tu kamu ni misaungayay sapimatatengil": 3,
        "Wikipitiya": 4,
        "Wikipitiya sasukamu": 5,
        "tangan": 6,
        "pisubelidan tu kamu tu tangan sapimatatengil": 7,
        "MyitiWyici": 8,
        "matatengil tu MyitiWyici": 9,
        "taazihan mitudung": 10,
        "pisubelidan tu kamu i taazihan mitudung sapimatatengil": 11,
        "buhci tu kamu": 12,
        "matatengil tu buhci tu kamu": 13,
        "kakuniza": 14,
        "sacacayen kakuniza tu pisubelidan tu kamu sapimatatengil": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "bacu-saupu": 828,
        "pisubelidan tu kamu i bacu-saupu sapimatatengil": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ta": {
        "ஊடகம்": -2,
        "சிறப்பு": -1,
        "பேச்சு": 1,
        "பயனர்": 2,
        "பயனர் பேச்சு": 3,
        "விக்கிப்பீடியா": 4,
        "விக்கிப்பீடியா பேச்சு": 5,
        "படிமம்": 6,
        "படிமப் பேச்சு": 7,
        "மீடியாவிக்கி": 8,
        "மீடியாவிக்கி பேச்சு": 9,
        "வார்ப்புரு": 10,
        "வார்ப்புரு பேச்சு": 11,
        "உதவி": 12,
        "உதவி பேச்சு": 13,
        "பகுப்பு": 14,
        "பகுப்பு பேச்சு": 15,
        "வலைவாசல்": 100,
        "வலைவாசல் பேச்சு": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "tay": {
        "media": -2,
        "kin iniptnaq": -1,
        "spkayal": 1,
        "cinzyuwaw": 2,
        "spkayal cinzyuwaw": 3,
        "Wikibitia": 4,
        "spkayal Wikibitia": 5,
        "biru’ na zayzyuwaw": 6,
        "spkayal squ biru’ na zayzyuwaw": 7,
        "mediawiki": 8,
        "spkayal qu mediawiki": 9,
        "panmwo": 10,
        "spkayal sa panmwo": 11,
        "sni sa pinraw nya smbbaq": 12,
        "spkayal sa sni sa pinraw nya smbbaq": 13,
        "zyuwaw na": 14,
        "spkayal sa zyuwaw na": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "tcy": {
        "ಮಾದ್ಯಮೊ": -2,
        "ವಿಸೇಸೊ": -1,
        "ಪಾತೆರ": 1,
        "ಬಳಕೆದಾರೆ": 2,
        "ಬಳಕೆದಾರೆ ಪಾತೆರ": 3,
        "ವಿಕಿಪೀಡಿಯ": 4,
        "ವಿಕಿಪೀಡಿಯ ಪಾತೆರ": 5,
        "ಫೈಲ್": 6,
        "ಫೈಲ್ ಪಾತೆರ": 7,
        "ಮಾದ್ಯಮೊ ವಿಕಿ": 8,
        "ಮಾದ್ಯಮೊ ವಿಕಿ ಪಾತೆರ": 9,
        "ಟೆಂಪ್ಲೇಟ್": 10,
        "ಟೆಂಪ್ಲೇಟ್ ಪಾತೆರ": 11,
        "ಸಕಾಯೊ": 12,
        "ಸಕಾಯೊ ಪಾತೆರ": 13,
        "ವರ್ಗೊ": 14,
        "ವರ್ಗೊ ಪಾತೆರ": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "ಮೋಡ್ಯೂಲ್": 828,
        "ಮೋಡ್ಯೂಲ್ ಪಾತೆರ": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "te": {
        "మీడియా": -2,
        "ప్రత్యేక": -1,
        "చర్చ": 1,
        "వాడుకరి": 2,
        "వాడుకరి చర్చ": 3,
        "వికీపీడియా": 4,
        "వికీపీడియా చర్చ": 5,
        "దస్త్రం": 6,
        "దస్త్రంపై చర్చ": 7,
        "మీడియావికీ": 8,
        "మీడియావికీ చర్చ": 9,
        "మూస": 10,
        "మూస చర్చ": 11,
        "సహాయం": 12,
        "సహాయం చర్చ": 13,
        "వర్గం": 14,
        "వర్గం చర్చ": 15,
        "వేదిక": 100,
        "వేదిక చర్చ": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "మాడ్యూల్": 828,
        "మాడ్యూల్ చర్చ": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Topic": 2600,
    },
    "tet": {
        "Media": -2,
        "Espesiál": -1,
        "Diskusaun": 1,
        "Uza-na'in": 2,
        "Diskusaun Uza-na'in": 3,
        "Wikipedia": 4,
        "Diskusaun Wikipedia": 5,
        "Imajen": 6,
        "Diskusaun Imajen": 7,
        "MediaWiki": 8,
        "Diskusaun MediaWiki": 9,
        "Template": 10,
        "Diskusaun Template": 11,
        "Ajuda": 12,
        "Diskusaun Ajuda": 13,
        "Kategoria": 14,
        "Diskusaun Kategoria": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Módulo": 828,
        "Módulo Discussão": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "tg": {
        "Медиа": -2,
        "Вижа": -1,
        "Баҳс": 1,
        "Корбар": 2,
        "Баҳси корбар": 3,
        "Википедиа": 4,
        "Баҳси Википедиа": 5,
        "Акс": 6,
        "Баҳси акс": 7,
        "Медиавики": 8,
        "Баҳси медиавики": 9,
        "Шаблон": 10,
        "Баҳси шаблон": 11,
        "Роҳнамо": 12,
        "Баҳси роҳнамо": 13,
        "Гурӯҳ": 14,
        "Баҳси гурӯҳ": 15,
        "Портал": 100,
        "Баҳси портал": 101,
        "Лоиҳа": 102,
        "Баҳси Лоиҳа": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модул": 828,
        "Баҳси Модул": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "th": {
        "สื่อ": -2,
        "พิเศษ": -1,
        "พูดคุย": 1,
        "ผู้ใช้": 2,
        "คุยกับผู้ใช้": 3,
        "วิกิพีเดีย": 4,
        "คุยเรื่องวิกิพีเดีย": 5,
        "ไฟล์": 6,
        "คุยเรื่องไฟล์": 7,
        "มีเดียวิกิ": 8,
        "คุยเรื่องมีเดียวิกิ": 9,
        "แม่แบบ": 10,
        "คุยเรื่องแม่แบบ": 11,
        "วิธีใช้": 12,
        "คุยเรื่องวิธีใช้": 13,
        "หมวดหมู่": 14,
        "คุยเรื่องหมวดหมู่": 15,
        "สถานีย่อย": 100,
        "คุยเรื่องสถานีย่อย": 101,
        "หนังสือ": 108,
        "คุยเรื่องหนังสือ": 109,
        "ฉบับร่าง": 118,
        "คุยเรื่องฉบับร่าง": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "มอดูล": 828,
        "คุยเรื่องมอดูล": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ti": {
        "ሜድያ": -2,
        "ፍሉይ": -1,
        "ምይይጥ": 1,
        "ተጠቃሚ": 2,
        "ምይይጥ ተጠቃሚ": 3,
        "ዊኪፐድያ": 4,
        "ምይይጥ ዊኪፐድያ": 5,
        "ፋይል": 6,
        "ምይይጥ ፋይል": 7,
        "ሜድያዊኪ": 8,
        "ምይይጥ ሜድያዊኪ": 9,
        "ሞደል": 10,
        "ምይይጥ ሞደል": 11,
        "ሓገዝ": 12,
        "ምይይጥ ሓገዝ": 13,
        "መደብ": 14,
        "ምይይጥ መደብ": 15,
        "ማዕጾ": 100,
        "ምይይጥ ማዕጾ": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "ሞድዩል": 828,
        "ምይይጥ ሞድዩል": 829,
        "መሳርሒ": 2300,
        "ምይይጥ መሳርሒ": 2301,
        "መብርሂ መሳርሒ": 2302,
        "ምይይጥ መብርሂ መሳርሒ": 2303,
    },
    "tk": {
        "Media": -2,
        "Ýörite": -1,
        "Çekişme": 1,
        "Ulanyjy": 2,
        "Ulanyjy çekişme": 3,
        "Wikipediýa": 4,
        "Wikipediýa çekişme": 5,
        "Faýl": 6,
        "Faýl çekişme": 7,
        "MediaWiki": 8,
        "MediaWiki çekişme": 9,
        "Şablon": 10,
        "Şablon çekişme": 11,
        "Ýardam": 12,
        "Ýardam çekişme": 13,
        "Kategoriýa": 14,
        "Kategoriýa çekişme": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "tl": {
        "Midya": -2,
        "Natatangi": -1,
        "Usapan": 1,
        "Tagagamit": 2,
        "Usapang tagagamit": 3,
        "Wikipedia": 4,
        "Usapang Wikipedia": 5,
        "Talaksan": 6,
        "Usapang talaksan": 7,
        "MediaWiki": 8,
        "Usapang MediaWiki": 9,
        "Padron": 10,
        "Usapang padron": 11,
        "Tulong": 12,
        "Usapang tulong": 13,
        "Kategorya": 14,
        "Usapang kategorya": 15,
        "Portada": 100,
        "Usapang Portada": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "tn": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "to": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "tpi": {
        "Media": -2,
        "Sipesol": -1,
        "Toktok": 1,
        "Yusa": 2,
        "Toktok bilong yusa": 3,
        "Wikipedia": 4,
        "Wikipedia toktok": 5,
        "Fail": 6,
        "Toktok bilong fail": 7,
        "MediaWiki": 8,
        "Toktok bilong mediawiki": 9,
        "Templet": 10,
        "Toktok bilong templet": 11,
        "Halivim": 12,
        "Toktok bilong halivim": 13,
        "Grup": 14,
        "Toktok bilong grup": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "tr": {
        "Ortam": -2,
        "Özel": -1,
        "Tartışma": 1,
        "Kullanıcı": 2,
        "Kullanıcı mesaj": 3,
        "Vikipedi": 4,
        "Vikipedi tartışma": 5,
        "Dosya": 6,
        "Dosya tartışma": 7,
        "MediaWiki": 8,
        "MediaWiki tartışma": 9,
        "Şablon": 10,
        "Şablon tartışma": 11,
        "Yardım": 12,
        "Yardım tartışma": 13,
        "Kategori": 14,
        "Kategori tartışma": 15,
        "Portal": 100,
        "Portal tartışma": 101,
        "Vikiproje": 102,
        "Vikiproje tartışma": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modül": 828,
        "Modül tartışma": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "trv": {
        "Meyti": -2,
        "Kingal nanaq": -1,
        "Mpprngaw": 1,
        "Empduuy": 2,
        "Pprngagun empduuy": 3,
        "Wikipidiya": 4,
        "Pprngagun Wikipidiya": 5,
        "Patas bntasan": 6,
        "Pprngagun patas bntasan": 7,
        "MeytiWiki": 8,
        "Pprngagun MeytiWiki": 9,
        "Snluan qcinuh": 10,
        "Pprngagun snluan qcinuh": 11,
        "Dmayaw": 12,
        "Pprngagun dmayaw": 13,
        "Snakun": 14,
        "Snakun pprngagun": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ts": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "tt": {
        "Медиа": -2,
        "Махсус": -1,
        "Бәхәс": 1,
        "Кулланучы": 2,
        "Кулланучы бәхәсе": 3,
        "Википедия": 4,
        "Википедия бәхәсе": 5,
        "Файл": 6,
        "Файл бәхәсе": 7,
        "МедиаВики": 8,
        "МедиаВики бәхәсе": 9,
        "Калып": 10,
        "Калып бәхәсе": 11,
        "Ярдәм": 12,
        "Ярдәм бәхәсе": 13,
        "Төркем": 14,
        "Төркем бәхәсе": 15,
        "Портал": 100,
        "Портал бәхәсе": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "tum": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "tw": {
        "Media": -2,
        "Soronko": -1,
        "Nkitahode": 1,
        "Dwumadini": 2,
        "Dwumadini nkitahode": 3,
        "Wikipedia": 4,
        "Wikipedia nkitahode": 5,
        "File": 6,
        "File nkitahode": 7,
        "MediaWiki": 8,
        "MediaWiki nkitahode": 9,
        "Nhwɛsoɔ": 10,
        "Nhwɛsoɔ nkitahode": 11,
        "Mmoa": 12,
        "Mmoa nkitahode": 13,
        "Nkyekyεmu": 14,
        "Nkyekyεmu nkitahode": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ty": {
        "Média": -2,
        "Spécial": -1,
        "Discussion": 1,
        "Utilisateur": 2,
        "Discussion utilisateur": 3,
        "Wikipedia": 4,
        "Discussion Wikipedia": 5,
        "Fichier": 6,
        "Discussion fichier": 7,
        "MediaWiki": 8,
        "Discussion MediaWiki": 9,
        "Modèle": 10,
        "Discussion modèle": 11,
        "Aide": 12,
        "Discussion aide": 13,
        "Catégorie": 14,
        "Discussion catégorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "tyv": {
        "Медиа": -2,
        "Тускай": -1,
        "Чугаа": 1,
        "Ажыглакчы": 2,
        "Ажыглакчы чугаа": 3,
        "Википедия": 4,
        "Википедия дугайында сүмелел": 5,
        "Файл": 6,
        "Файл чугаа": 7,
        "МедиаВики": 8,
        "МедиаВики чугаа": 9,
        "Майык": 10,
        "Майык чугаа": 11,
        "Дуза": 12,
        "Дуза чугаа": 13,
        "Аңгылал": 14,
        "Аңгылал чугаа": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "udm": {
        "Медиа": -2,
        "Панель": -1,
        "Вераськон": 1,
        "Викиавтор": 2,
        "Викиавтор сярысь вераськон": 3,
        "Википедия": 4,
        "Википедия сярысь вераськон": 5,
        "Файл": 6,
        "Файл сярысь вераськон": 7,
        "MediaWiki": 8,
        "MediaWiki сярысь вераськон": 9,
        "Шаблон": 10,
        "Шаблон сярысь вераськон": 11,
        "Валэктон": 12,
        "Валэктон сярысь вераськон": 13,
        "Категория": 14,
        "Категория сярысь вераськон": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "ug": {
        "ۋاسىتە": -2,
        "ئالاھىدە": -1,
        "مۇنازىرە": 1,
        "ئىشلەتكۈچى": 2,
        "ئىشلەتكۈچى مۇنازىرىسى": 3,
        "Wikipedia": 4,
        "Wikipediaمۇنازىرىسى": 5,
        "ھۆججەت": 6,
        "ھۆججەت مۇنازىرىسى": 7,
        "MediaWiki": 8,
        "MediaWiki مۇنازىرىسى": 9,
        "قېلىپ": 10,
        "قېلىپ مۇنازىرىسى": 11,
        "ياردەم": 12,
        "ياردەم مۇنازىرىسى": 13,
        "تۈر": 14,
        "تۈر مۇنازىرىسى": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "uk": {
        "Медіа": -2,
        "Спеціальна": -1,
        "Обговорення": 1,
        "Користувач": 2,
        "Обговорення користувача": 3,
        "Вікіпедія": 4,
        "Обговорення Вікіпедії": 5,
        "Файл": 6,
        "Обговорення файлу": 7,
        "MediaWiki": 8,
        "Обговорення MediaWiki": 9,
        "Шаблон": 10,
        "Обговорення шаблону": 11,
        "Довідка": 12,
        "Обговорення довідки": 13,
        "Категорія": 14,
        "Обговорення категорії": 15,
        "Портал": 100,
        "Обговорення порталу": 101,
        "Education Program": 446,
        "Education Program talk": 447,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обговорення модуля": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ur": {
        "میڈیا": -2,
        "خاص": -1,
        "تبادلۂ خیال": 1,
        "صارف": 2,
        "تبادلۂ خیال صارف": 3,
        "ویکیپیڈیا": 4,
        "تبادلۂ خیال ویکیپیڈیا": 5,
        "فائل": 6,
        "تبادلۂ خیال فائل": 7,
        "میڈیاویکی": 8,
        "تبادلۂ خیال میڈیاویکی": 9,
        "سانچہ": 10,
        "تبادلۂ خیال سانچہ": 11,
        "معاونت": 12,
        "تبادلۂ خیال معاونت": 13,
        "زمرہ": 14,
        "تبادلۂ خیال زمرہ": 15,
        "باب": 100,
        "تبادلۂ خیال باب": 101,
        "کتاب": 102,
        "تبادلۂ خیال کتاب": 103,
        "مسودہ": 118,
        "تبادلۂ خیال مسودہ": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "ماڈیول": 828,
        "تبادلۂ خیال ماڈیول": 829,
        "آلہ": 2300,
        "تبادلۂ خیال آلہ": 2301,
        "تعریف آلہ": 2302,
        "تبادلۂ خیال تعریف آلہ": 2303,
        "موضوع": 2600,
    },
    "uz": {
        "Media": -2,
        "Maxsus": -1,
        "Munozara": 1,
        "Foydalanuvchi": 2,
        "Foydalanuvchi munozarasi": 3,
        "Vikipediya": 4,
        "Vikipediya munozarasi": 5,
        "Fayl": 6,
        "Fayl munozarasi": 7,
        "MediaWiki": 8,
        "MediaWiki munozarasi": 9,
        "Andoza": 10,
        "Andoza munozarasi": 11,
        "Yordam": 12,
        "Yordam munozarasi": 13,
        "Turkum": 14,
        "Turkum munozarasi": 15,
        "Portal": 100,
        "Portal munozarasi": 101,
        "Loyiha": 102,
        "Loyiha munozarasi": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "ve": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "vec": {
        "Mèdia": -2,
        "Speçałe": -1,
        "Discusion": 1,
        "Utensa": 2,
        "Discusion Utensa": 3,
        "Wikipedia": 4,
        "Discusion Wikipedia": 5,
        "File": 6,
        "Discusion File": 7,
        "MediaWiki": 8,
        "Discusion MediaWiki": 9,
        "Modeło": 10,
        "Discusion Modeło": 11,
        "Juto": 12,
        "Discusion Juto": 13,
        "Categoria": 14,
        "Discusion Categoria": 15,
        "Portałe": 100,
        "Discussion portałe": 101,
        "Projeto": 102,
        "Discussion projeto": 103,
        "TimedText": 710,
        "TimedText talk": 711,
        "Modulo": 828,
        "Discussioni modulo": 829,
        "Accessorio": 2300,
        "Discussioni accessorio": 2301,
        "Definizione accessorio": 2302,
        "Discussioni definizione accessorio": 2303,
    },
    "vep": {
        "Media": -2,
        "Specialine": -1,
        "Lodu": 1,
        "Kävutai": 2,
        "Lodu kävutajas": 3,
        "Vikipedii": 4,
        "Paginad Vikipedii": 5,
        "Fail": 6,
        "Lodu failas": 7,
        "MediaWiki": 8,
        "Lodu MediaWikiš": 9,
        "Šablon": 10,
        "Lodu šablonas": 11,
        "Abu": 12,
        "Lodu abus": 13,
        "Kategorii": 14,
        "Lodu kategorijas": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Moodul": 828,
        "Mooduli arutelu": 829,
        "Tööriist": 2300,
        "Tööriista arutelu": 2301,
        "Tööriista määratlus": 2302,
        "Tööriista määratluse arutelu": 2303,
    },
    "vi": {
        "Phương tiện": -2,
        "Đặc biệt": -1,
        "Thảo luận": 1,
        "Thành viên": 2,
        "Thảo luận Thành viên": 3,
        "Wikipedia": 4,
        "Thảo luận Wikipedia": 5,
        "Tập tin": 6,
        "Thảo luận Tập tin": 7,
        "MediaWiki": 8,
        "Thảo luận MediaWiki": 9,
        "Bản mẫu": 10,
        "Thảo luận Bản mẫu": 11,
        "Trợ giúp": 12,
        "Thảo luận Trợ giúp": 13,
        "Thể loại": 14,
        "Thảo luận Thể loại": 15,
        "Cổng thông tin": 100,
        "Thảo luận Cổng thông tin": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "Mô đun": 828,
        "Thảo luận Mô đun": 829,
        "Tiện ích": 2300,
        "Thảo luận Tiện ích": 2301,
        "Định nghĩa tiện ích": 2302,
        "Thảo luận Định nghĩa tiện ích": 2303,
    },
    "vls": {
        "Media": -2,
        "Specioal": -1,
        "Discuusje": 1,
        "Gebruker": 2,
        "Discuusje gebruker": 3,
        "Wikipedia": 4,
        "Discuusje Wikipedia": 5,
        "Ofbeeldienge": 6,
        "Discuusje ofbeeldienge": 7,
        "MediaWiki": 8,
        "Discuusje MediaWiki": 9,
        "Patrôon": 10,
        "Discuusje patrôon": 11,
        "Ulpe": 12,
        "Discuusje ulpe": 13,
        "Categorie": 14,
        "Discuusje categorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Overleg module": 829,
        "Uitbreiding": 2300,
        "Overleg uitbreiding": 2301,
        "Uitbreidingsdefinitie": 2302,
        "Overleg uitbreidingsdefinitie": 2303,
    },
    "vo": {
        "Nünamakanäd": -2,
        "Patikos": -1,
        "Bespik": 1,
        "Geban": 2,
        "Gebanibespik": 3,
        "Vükiped": 4,
        "Bespik dö Vükiped": 5,
        "Ragiv": 6,
        "Ragivibespik": 7,
        "Sitanuns": 8,
        "Bespik dö sitanuns": 9,
        "Samafomot": 10,
        "Samafomotibespik": 11,
        "Yuf": 12,
        "Yufibespik": 13,
        "Klad": 14,
        "Kladibespik": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "wa": {
        "Media": -2,
        "Sipeciås": -1,
        "Copene": 1,
        "Uzeu": 2,
        "Uzeu copene": 3,
        "Wikipedia": 4,
        "Wikipedia copene": 5,
        "Imådje": 6,
        "Imådje copene": 7,
        "MediaWiki": 8,
        "MediaWiki copene": 9,
        "Modele": 10,
        "Modele copene": 11,
        "Aidance": 12,
        "Aidance copene": 13,
        "Categoreye": 14,
        "Categoreye copene": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
        "Sujet": 2600,
    },
    "war": {
        "Medya": -2,
        "Pinaurog": -1,
        "Hiruhimangraw": 1,
        "Gumaramit": 2,
        "Hiruhimangaw hiton gumaramit": 3,
        "Wikipedia": 4,
        "Hiruhimangraw hiton Wikipedia": 5,
        "Paypay": 6,
        "Hiruhimangraw hiton paypay": 7,
        "MedyaWiki": 8,
        "Hiruhimangraw hiton MedyaWiki": 9,
        "Batakan": 10,
        "Hiruhimangraw hiton batakan": 11,
        "Bulig": 12,
        "Hiruhimangaw hiton bulig": 13,
        "Kaarangay": 14,
        "Hiruhimangraw hiton kaarangay": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "wo": {
        "Xibaarukaay": -2,
        "Jagleel": -1,
        "Waxtaan": 1,
        "Jëfandikukat": 2,
        "Waxtaani jëfandikukat": 3,
        "Wikipedia": 4,
        "Wikipedia waxtaan": 5,
        "Dencukaay": 6,
        "Waxtaani dencukaay": 7,
        "MediaWiki": 8,
        "Waxtaani MediaWiki": 9,
        "Royuwaay": 10,
        "Waxtaani royuwaay": 11,
        "Ndimbal": 12,
        "Waxtaani ndimbal": 13,
        "Wàll": 14,
        "Waxtaani wàll": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Discussion module": 829,
        "Gadget": 2300,
        "Discussion gadget": 2301,
        "Définition de gadget": 2302,
        "Discussion définition de gadget": 2303,
    },
    "wuu": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "Portal": 100,
        "Portal talk": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "模块": 828,
        "模块讨论": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "xal": {
        "Аһар": -2,
        "Көдлхнә": -1,
        "Меткән": 1,
        "Демнч": 2,
        "Демнчна туск меткән": 3,
        "Wikipedia": 4,
        "Wikipedia туск меткән": 5,
        "Боомг": 6,
        "Боомгин туск меткән": 7,
        "MediaWiki": 8,
        "MediaWiki туск меткән": 9,
        "Кевләр": 10,
        "Зуран туск меткән": 11,
        "Цәәлһлһн": 12,
        "Цәәлһлһин туск меткән": 13,
        "Әәшл": 14,
        "Әәшлин туск меткән": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Модуль": 828,
        "Обсуждение модуля": 829,
        "Гаджет": 2300,
        "Обсуждение гаджета": 2301,
        "Определение гаджета": 2302,
        "Обсуждение определения гаджета": 2303,
    },
    "xh": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "xmf": {
        "მედია": -2,
        "სპეციალური": -1,
        "განხილვა": 1,
        "მომხმარებელი": 2,
        "მომხმარებლის განხილვა": 3,
        "ვიკიპედია": 4,
        "ვიკიპედია სხუნუა": 5,
        "ფაილი": 6,
        "ფაილის განხილვა": 7,
        "მედიავიკი": 8,
        "მედიავიკის განხილვა": 9,
        "თარგი": 10,
        "თარგის განხილვა": 11,
        "დახმარება": 12,
        "დახმარების განხილვა": 13,
        "კატეგორია": 14,
        "კატეგორიის განხილვა": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "მოდული": 828,
        "მოდულის განხილვა": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "yi": {
        "מעדיע": -2,
        "באַזונדער": -1,
        "רעדן": 1,
        "באַניצער": 2,
        "באַניצער רעדן": 3,
        "װיקיפּעדיע": 4,
        "װיקיפּעדיע רעדן": 5,
        "טעקע": 6,
        "טעקע רעדן": 7,
        "מעדיעװיקי": 8,
        "מעדיעװיקי רעדן": 9,
        "מוסטער": 10,
        "מוסטער רעדן": 11,
        "הילף": 12,
        "הילף רעדן": 13,
        "קאַטעגאָריע": 14,
        "קאַטעגאָריע רעדן": 15,
        "פארטאל": 100,
        "פארטאל רעדן": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "יחידה": 828,
        "שיחת יחידה": 829,
        "גאדג'ט": 2300,
        "שיחת גאדג'ט": 2301,
        "הגדרת גאדג'ט": 2302,
        "שיחת הגדרת גאדג'ט": 2303,
    },
    "yo": {
        "Amóhùnmáwòrán": -2,
        "Pàtàkì": -1,
        "Ọ̀rọ̀": 1,
        "Oníṣe": 2,
        "Ọ̀rọ̀ oníṣe": 3,
        "Wikipedia": 4,
        "Ọ̀rọ̀ Wikipedia": 5,
        "Fáìlì": 6,
        "Ọ̀rọ̀ fáìlì": 7,
        "MediaWiki": 8,
        "Ọ̀rọ̀ mediaWiki": 9,
        "Àdàkọ": 10,
        "Ọ̀rọ̀ àdàkọ": 11,
        "Ìrànlọ́wọ́": 12,
        "Ọ̀rọ̀ ìrànlọ́wọ́": 13,
        "Ẹ̀ka": 14,
        "Ọ̀rọ̀ ẹ̀ka": 15,
        "Èbúté": 100,
        "Ọ̀rọ̀ èbúté": 101,
        "Ìwé": 108,
        "Ọ̀rọ̀ ìwé": 109,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "za": {
        "媒体文件": -2,
        "特殊": -1,
        "讨论": 1,
        "用户": 2,
        "用户讨论": 3,
        "Wikipedia": 4,
        "Wikipedia讨论": 5,
        "文件": 6,
        "文件讨论": 7,
        "MediaWiki": 8,
        "MediaWiki讨论": 9,
        "模板": 10,
        "模板讨论": 11,
        "帮助": 12,
        "帮助讨论": 13,
        "分类": 14,
        "分类讨论": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "模块": 828,
        "模块讨论": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "zea": {
        "Media": -2,
        "Speciaol": -1,
        "Overleg": 1,
        "Gebruker": 2,
        "Overleg gebruker": 3,
        "Wikipedia": 4,
        "Overleg Wikipedia": 5,
        "Plaetje": 6,
        "Overleg plaetje": 7,
        "MediaWiki": 8,
        "Overleg MediaWiki": 9,
        "Sjabloon": 10,
        "Overleg sjabloon": 11,
        "Ulpe": 12,
        "Overleg ulpe": 13,
        "Categorie": 14,
        "Overleg categorie": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Overleg module": 829,
        "Uitbreiding": 2300,
        "Overleg uitbreiding": 2301,
        "Uitbreidingsdefinitie": 2302,
        "Overleg uitbreidingsdefinitie": 2303,
    },
    "zh": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "Portal": 100,
        "Portal talk": 101,
        "WikiProject": 102,
        "WikiProject talk": 103,
        "Draft": 118,
        "Draft talk": 119,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
        "Topic": 2600,
    },
    "zh-classical": {
        "媒體": -2,
        "特殊": -1,
        "討論": 1,
        "用戶": 2,
        "用戶討論": 3,
        "維基大典": 4,
        "維基大典討論": 5,
        "檔案": 6,
        "檔案討論": 7,
        "MediaWiki": 8,
        "MediaWiki討論": 9,
        "模板": 10,
        "模板討論": 11,
        "幫助": 12,
        "幫助討論": 13,
        "分類": 14,
        "分類討論": 15,
        "門": 100,
        "議": 101,
        "稿": 106,
        "酌稿": 107,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "zh-min-nan": {
        "Mûi-thé": -2,
        "Tek-pia̍t": -1,
        "Thó-lūn": 1,
        "Iōng-chiá": 2,
        "Iōng-chiá thó-lūn": 3,
        "Wikipedia": 4,
        "Wikipedia thó-lūn": 5,
        "tóng-àn": 6,
        "tóng-àn thó-lūn": 7,
        "MediaWiki": 8,
        "MediaWiki thó-lūn": 9,
        "Pang-bô͘": 10,
        "Pang-bô͘ thó-lūn": 11,
        "Pang-chān": 12,
        "Pang-chān thó-lūn": 13,
        "Lūi-pia̍t": 14,
        "Lūi-pia̍t thó-lūn": 15,
        "Portal": 100,
        "Portal talk": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "zh-yue": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "Portal": 100,
        "Portal talk": 101,
        "TimedText": 710,
        "TimedText talk": 711,
        "模組": 828,
        "模組討論": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
    "zu": {
        "Media": -2,
        "Special": -1,
        "Talk": 1,
        "User": 2,
        "User talk": 3,
        "Wikipedia": 4,
        "Wikipedia talk": 5,
        "File": 6,
        "File talk": 7,
        "MediaWiki": 8,
        "MediaWiki talk": 9,
        "Template": 10,
        "Template talk": 11,
        "Help": 12,
        "Help talk": 13,
        "Category": 14,
        "Category talk": 15,
        "TimedText": 710,
        "TimedText talk": 711,
        "Module": 828,
        "Module talk": 829,
        "Gadget": 2300,
        "Gadget talk": 2301,
        "Gadget definition": 2302,
        "Gadget definition talk": 2303,
    },
}
